@@ -26,31 +26,28 @@
 #include "mainwindow.h"
 #include "configdata.h"
 #include "iconloader.h"
-#include "dotnetstyle.h"
-
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::Application */
 
 Application::Application( int& argc, char** argv ) : QApplication( argc, argv )
 {
     Q_INIT_RESOURCE( icons );
     Q_INIT_RESOURCE( resources );
 
+    // NOTE: update these paths after changing them in the project file
+
     QString path = applicationDirPath();
 #if defined( Q_WS_WIN )
     m_manualPath = QDir::cleanPath( path + "/../doc" );
     m_translationsPath = QDir::cleanPath( path + "/../translations" );
 #else
-    m_manualPath = QDir::cleanPath( path + "/../share/doc/webissues" );
+    m_manualPath = QDir::cleanPath( path + "/../share/doc/webissues/doc" );
     m_translationsPath = QDir::cleanPath( path + "/../share/webissues/translations" );
 #endif
 
     loadTranslation( "webissues", false );
     loadTranslation( "qt", true );
 
-#if !defined( WI_NO_STYLE_DOTNET )
-    setStyle( new DotNetStyle() );
+#if defined( Q_WS_WIN )
+    setStyle( "windowsmodernstyle" );
 #endif
 
     setWindowIcon( IconLoader::icon( "webissues" ) );
@@ -69,10 +66,11 @@ Application::Application( int& argc, char** argv ) : QApplication( argc, argv )
     settings->endGroup();
 
     if ( !configData->dockWindow() || configData->showAtStartup() == RestoreAlways ||
-        configData->showAtStartup() == RestoreAuto && visible )
+        ( configData->showAtStartup() == RestoreAuto && visible ) )
         m_mainWindow->show();
 
-    if ( configData->reconnectAtStartup() == RestoreAlways || configData->reconnectAtStartup() == RestoreAuto && connected )
+    if ( configData->reconnectAtStartup() == RestoreAlways ||
+        ( configData->reconnectAtStartup() == RestoreAuto && connected ) )
         m_mainWindow->reconnect();
 }
 
@@ -96,10 +94,12 @@ Application::~Application()
 
 void Application::commitData( QSessionManager& manager )
 {
+#if !defined( QT_NO_SESSIONMANAGER )
     if ( manager.allowsInteraction() ) {
         if ( viewManager && !viewManager->queryCloseViews() )
             manager.cancel();
     }
+#endif
 }
 
 void Application::about()
@@ -118,7 +118,7 @@ void Application::about()
 
 QString Application::version() const
 {
-    return QString( "0.9.2" );
+    return QString( "0.9.3" );
 }
 
 QUrl Application::manualIndex() const
