@@ -16,12 +16,6 @@
 
 class QUrl;
 
-/**
-* The main namespace of the WebIssues application.
-*/
-namespace WebIssues
-{
-
 class MainWindow;
 
 /**
@@ -82,6 +76,4 @@ private:
     QString m_translationsPath;
 };
 
-}
-
 #endif
