@@ -17,9 +17,6 @@
 
 class QWidget;
 
-namespace WebIssues
-{
-
 /**
 * Delegate for editing attribute values.
 *
@@ -74,6 +71,4 @@ private:
     QPointer<QWidget> m_widget;
 };
 
-}
-
 #endif
