@@ -14,9 +14,6 @@
 
 #include <QDateTime>
 
-namespace WebIssues
-{
-
 /**
 * Functions for formatting and parsing dates.
 *
@@ -78,6 +75,4 @@ public:
     static int compareDateTime( const QDateTime& dateTime1, const QDateTime& dateTime2 );
 };
 
-}
-
 #endif
