@@ -13,8 +13,6 @@
 
 #include <QStringList>
 
-using namespace WebIssues;
-
 DefinitionBuilder::DefinitionBuilder()
 {
     m_types.insert( DefinitionInfo::Text, "TEXT" );
@@ -36,7 +34,7 @@ QString DefinitionBuilder::build( const DefinitionInfo& info )
         return QString();
 
     if ( info.required() )
-        definition += " required=1";
+        definition += QLatin1String( " required=1" );
 
     QString defaultValue = info.defaultValue();
     if ( !defaultValue.isEmpty() )
@@ -71,10 +69,10 @@ QString DefinitionBuilder::buildStringArray( const QStringList& array )
     QString result = "{";
     for ( QStringList::const_iterator it = array.begin(); it != array.end(); ++it ) {
         if ( it != array.begin() )
-            result += ",";
+            result += QLatin1String( "," );
         result += buildString( *it );
     }
-    result += "}";
+    result += QLatin1String( "}" );
     return result;
 }
 
