@@ -14,9 +14,6 @@
 
 #include "definitioninfo.h"
 
-namespace WebIssues
-{
-
 /**
 * Attribute definition builder.
 *
@@ -79,6 +76,4 @@ private:
     QMap<DefinitionInfo::Type, QString> m_types;
 };
 
-}
-
 #endif
