@@ -14,10 +14,6 @@
 #include <QApplication>
 #include <QStringList>
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::DefinitionHelper */
-
 QString DefinitionHelper::typeName( DefinitionInfo::Type type )
 {
     switch ( type ) {
@@ -31,8 +27,9 @@ QString DefinitionHelper::typeName( DefinitionInfo::Type type )
             return tr( "Date & Time" );
         case DefinitionInfo::User:
             return tr( "User" );
+        default:
+            return QString();
     }
-    return QString();
 }
 
 QString DefinitionHelper::metadataDetails( const DefinitionInfo& info )
@@ -48,8 +45,9 @@ QString DefinitionHelper::metadataDetails( const DefinitionInfo& info )
             return dateTimeMetadataDetails( info );
         case DefinitionInfo::User:
             return userMetadataDetails( info );
+        default:
+            return QString();
     }
-    return QString();
 }
 
 QString DefinitionHelper::textMetadataDetails( const DefinitionInfo& info )
@@ -121,5 +119,5 @@ QString DefinitionHelper::userMetadataDetails( const DefinitionInfo& info )
 
 QString DefinitionHelper::tr( const char* text )
 {
-    return qApp->translate( "WebIssues::DefinitionHelper", text );
+    return qApp->translate( "DefinitionHelper", text );
 }
