@@ -14,9 +14,6 @@
 
 #include "definitioninfo.h"
 
-namespace WebIssues
-{
-
 class DefinitionInfo;
 
 /**
@@ -58,6 +55,4 @@ private:
     static QString tr( const char* text );
 };
 
-}
-
 #endif
