@@ -15,9 +15,6 @@
 #include <QVariant>
 #include <QMap>
 
-namespace WebIssues
-{
-
 /**
 * Structure storing an attribute definition.
 *
@@ -137,6 +134,4 @@ private:
     QMap<QString, QVariant> m_metadata;
 };
 
-}
-
 #endif
