@@ -13,8 +13,6 @@
 
 #include <QStringList>
 
-using namespace WebIssues;
-
 DefinitionParser::DefinitionParser()
 {
     QString string( "\"(?:\\\\[\"\\\\]|[^\"\\\\])*\"" );
@@ -58,9 +56,9 @@ DefinitionInfo DefinitionParser::parse( const QString& definition )
         QString key = m_attribute.cap( 1 );
         QString value = m_attribute.cap( 2 );
 
-        if ( value[ 0 ] == '\"' )
+        if ( value[ 0 ] == QLatin1Char( '\"' ) )
             info.setMetadata( key, parseString( value ) );
-        else if ( value[ 0 ] == '{' )
+        else if ( value[ 0 ] == QLatin1Char( '{' ) )
             info.setMetadata( key, parseStringArray( value ) );
         else
             info.setMetadata( key, value.toInt() );
@@ -108,7 +106,7 @@ QString DefinitionParser::parseString( const QString& value )
     int len = value.length() - 1;
     for ( int i = 1; i < len; i++ ) {
         QChar ch = value[ i ];
-        if ( ch == '\\' )
+        if ( ch == QLatin1Char( '\\' ) )
             ch = value[ ++i ];
         result += ch;
     }
