@@ -16,9 +16,6 @@
 
 #include "definitioninfo.h"
 
-namespace WebIssues
-{
-
 /**
 * Attribute definition parser.
 *
@@ -63,6 +60,4 @@ private:
     QMap<QString, DefinitionInfo::Type> m_types;
 };
 
-}
-
 #endif
