@@ -18,10 +18,6 @@
 
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::MetadataDialogBase */
-
 MetadataDialogBase::MetadataDialogBase( QWidget* parent ) :
     QDialog( parent ),
     m_type( DefinitionInfo::Invalid )
