@@ -19,9 +19,6 @@
 class QLabel;
 class QBoxLayout;
 
-namespace WebIssues
-{
-
 /**
 * Base class of a dialog for editing attribute definition metadata.
 *
@@ -125,6 +122,4 @@ private:
     QBoxLayout* m_mainLayout;
 };
 
-}
-
 #endif
