@@ -13,8 +13,6 @@
 
 #include "metadatadialogs.h"
 
-using namespace WebIssues;
-
 MetadataDialogBase* MetadataDialogFactory::createMetadataDialog( DefinitionInfo::Type type, QWidget* parent )
 {
     switch ( type ) {
@@ -28,7 +26,7 @@ MetadataDialogBase* MetadataDialogFactory::createMetadataDialog( DefinitionInfo:
             return new DateTimeMetadataDialog( parent );
         case DefinitionInfo::User:
             return new UserMetadataDialog( parent );
+        default:
+            return NULL;
     }
-
-    return NULL;
 }
