@@ -14,9 +14,6 @@
 
 #include "definitioninfo.h"
 
-namespace WebIssues
-{
-
 class MetadataDialogBase;
 
 /**
@@ -37,6 +34,4 @@ public:
     static MetadataDialogBase* createMetadataDialog( DefinitionInfo::Type type, QWidget* parent );
 };
 
-}
-
 #endif
