@@ -23,10 +23,6 @@
 #include "widgets/editlistbox.h"
 #include "definitioninfo.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::TextMetadataDialog */
-
 TextMetadataDialog::TextMetadataDialog( QWidget* parent ) : MetadataDialogBase( parent )
 {
     setWindowTitle( tr( "Text Attribute" ) );
@@ -84,8 +80,6 @@ bool TextMetadataDialog::updateMetadata( DefinitionInfo& info )
     return true;
 }
 
-/* TRANSLATOR WebIssues::EnumMetadataDialog */
-
 EnumMetadataDialog::EnumMetadataDialog( QWidget* parent ) : MetadataDialogBase( parent )
 {
     setWindowTitle( tr( "Dropdown List Attribute" ) );
@@ -149,8 +143,6 @@ bool EnumMetadataDialog::updateMetadata( DefinitionInfo& info )
     return true;
 }
 
-/* TRANSLATOR WebIssues::NumericMetadataDialog */
-
 NumericMetadataDialog::NumericMetadataDialog( QWidget* parent ) : MetadataDialogBase( parent )
 {
     setWindowTitle( tr( "Numeric Attribute" ) );
@@ -275,8 +267,6 @@ bool NumericMetadataDialog::updateMetadata( DefinitionInfo& info )
     return true;
 }
 
-/* TRANSLATOR WebIssues::DateTimeMetadataDialog */
-
 DateTimeMetadataDialog::DateTimeMetadataDialog( QWidget* parent ) : MetadataDialogBase( parent )
 {
     setWindowTitle( tr( "Date & Time Attribute" ) );
@@ -319,8 +309,6 @@ bool DateTimeMetadataDialog::updateMetadata( DefinitionInfo& info )
     return true;
 }
 
-/* TRANSLATOR WebIssues::UserMetadataDialog */
-
 UserMetadataDialog::UserMetadataDialog( QWidget* parent ) : MetadataDialogBase( parent )
 {
     setWindowTitle( tr( "User Attribute" ) );
