@@ -18,9 +18,6 @@ class QButtonGroup;
 class QSpinBox;
 class QLineEdit;
 
-namespace WebIssues
-{
-
 class EditListBox;
 
 /**
@@ -172,6 +169,4 @@ private:
     QButtonGroup* m_membersGroup;
 };
 
-}
-
 #endif
