@@ -14,8 +14,6 @@
 #include "definitioninfo.h"
 #include "valueeditors.h"
 
-using namespace WebIssues;
-
 AbstractValueEditor* ValueEditorFactory::createValueEditor( const DefinitionInfo& info, int projectId,
                                                        QObject* parent, QWidget* parentWidget )
 {
@@ -30,7 +28,7 @@ AbstractValueEditor* ValueEditorFactory::createValueEditor( const DefinitionInfo
             return new DateTimeValueEditor( info, parent, parentWidget );
         case DefinitionInfo::User:
             return new UserValueEditor( info, projectId, parent, parentWidget );
+        default:
+            return NULL;
     }
-
-    return NULL;
 }
