@@ -15,9 +15,6 @@
 class QObject;
 class QWidget;
 
-namespace WebIssues
-{
-
 class DefinitionInfo;
 class AbstractValueEditor;
 
@@ -44,6 +41,4 @@ public:
                                                    QObject* parent, QWidget* parentWidget );
 };
 
-}
-
 #endif
