@@ -22,14 +22,11 @@
 #include <QDateEdit>
 #include <QDateTimeEdit>
 
-#include "data/rdb/tableiterators.h"
 #include "data/datamanager.h"
-#include "data/rowhelpers.h"
+#include "rdb/utilities.h"
 #include "definitioninfo.h"
 #include "datetimehelper.h"
 
-using namespace WebIssues;
-
 TextValueEditor::TextValueEditor( const DefinitionInfo& info, QObject* parent, QWidget* parentWidget ) :
     AbstractValueEditor( parent )
 {
@@ -252,7 +249,7 @@ UserValueEditor::UserValueEditor( const DefinitionInfo& info, int projectId, QOb
     QVariant members = info.metadata( "members" );
     bool onlyMembers = ( members.isValid() ? members.toBool() : false ) && projectId != 0;
 
-    RDB::TableConstIterator<UserRow> it( dataManager->users() );
+    RDB::IndexConstIterator<UserRow> it( dataManager->users()->index() );
     QList<const UserRow*> users = localeAwareSortRows( it, &UserRow::name );
 
     for ( int i = 0; i < users.count(); i++ ) {
