@@ -14,9 +14,6 @@
 
 #include "abstractvalueeditor.h"
 
-namespace WebIssues
-{
-
 class DefinitionInfo;
 
 /**
@@ -167,6 +164,4 @@ public: // overrides
     QString value();
 };
 
-}
-
 #endif
