@@ -14,9 +14,6 @@
 
 #include <QObject>
 
-namespace WebIssues
-{
-
 class Command;
 
 /**
@@ -84,6 +81,4 @@ private:
     int m_priority;
 };
 
-}
-
 #endif
