@@ -18,9 +18,6 @@
 
 #include "reply.h"
 
-namespace WebIssues
-{
-
 /**
 * Class storing information about a command to execute.
 *
@@ -215,6 +212,4 @@ private:
     QList<ReplyRule> m_rules;
 };
 
-}
-
 #endif
