@@ -14,17 +14,22 @@
 #include <QHttp>
 #include <QRegExp>
 
+#if defined( HAVE_OPENSSL )
+#include <QSslSocket>
+#include <QSslCipher>
+#endif
+
 #include "command.h"
 #include "abstractbatch.h"
 #include "formdatamessage.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::CommandManager */
-
-CommandManager* WebIssues::commandManager = NULL;
+CommandManager* commandManager = NULL;
 
 CommandManager::CommandManager() :
+#if defined( HAVE_OPENSSL )
+    m_sslSocket( NULL ),
+#endif
+    m_mode( InvalidMode ),
     m_currentRequest( 0 ),
     m_currentBatch( NULL ),
     m_currentCommand( NULL ),
@@ -42,6 +47,11 @@ CommandManager::CommandManager() :
 
     connect( m_http, SIGNAL( requestFinished( int, bool ) ),
         this, SLOT( requestFinished( int, bool ) ) );
+
+#if defined( HAVE_OPENSSL )
+    connect( m_http, SIGNAL( sslErrors( const QList<QSslError>& ) ),
+        this, SIGNAL( sslErrors( const QList<QSslError>& ) ) );
+#endif
 }
 
 CommandManager::~CommandManager()
@@ -53,6 +63,11 @@ CommandManager::~CommandManager()
         AbstractBatch* batch = m_batches.takeFirst();
         delete batch;
     }
+
+#if defined( HAVE_OPENSSL )
+    delete m_sslSocket;
+    m_sslSocket = NULL;
+#endif
 }
 
 void CommandManager::setServerUrl( const QUrl& url )
@@ -81,7 +96,7 @@ void CommandManager::abort( AbstractBatch* batch )
     if ( batch == m_currentBatch ) {
         m_http->abort();
     } else {
-        setError( Aborted, 0, QString() );
+        setError( Aborted );
         m_batches.removeAt( m_batches.indexOf( batch ) );
         batch->setCompleted( false );
         delete batch;
@@ -92,7 +107,7 @@ void CommandManager::abortAll()
 {
     m_http->abort();
 
-    setError( Aborted, 0, QString() );
+    setError( Aborted );
 
     while ( !m_batches.isEmpty() ) {
         AbstractBatch* batch = m_batches.takeFirst();
@@ -109,6 +124,12 @@ QString CommandManager::errorMessage( const QString& whatFailed )
         case Aborted:
             message = tr( "Operation aborted" );
             break;
+        case InvalidUrl:
+            message = tr( "Invalid server URL" );
+            break;
+        case UnknownUrlScheme:
+            message = tr( "Unsupported URL scheme" );
+            break;
         case ConnectionError:
             message = tr( "Connection failed" );
             break;
@@ -127,6 +148,8 @@ QString CommandManager::errorMessage( const QString& whatFailed )
         case HttpError:
             message = tr( "Server error" );
             break;
+        default:
+            break;
     }
 
     if ( m_error == CommandManager::WebIssuesError || m_error == CommandManager::HttpError )
@@ -162,13 +185,36 @@ void CommandManager::checkPendingCommand()
 
 void CommandManager::sendSetHostRequest()
 {
+    if ( !m_url.isValid() || m_url.scheme().isEmpty() || m_url.host().isEmpty() ) {
+        m_http->setHost( QString(), 0 );
+        m_mode = InvalidMode;
+        return;
+    }
+
+    QString scheme = m_url.scheme().toLower();
     QString host = m_url.host();
-
     int port = m_url.port();
-    if ( port < 0 )
-        port = 80;
 
-    m_http->setHost( host, port );
+    if ( scheme == QLatin1String( "http" ) ) {
+        m_http->setSocket( NULL );
+        m_http->setHost( host, ( port < 0 ) ? 80 : port );
+        m_mode = HttpMode;
+        return;
+    }
+
+#if defined( HAVE_OPENSSL )
+    if ( scheme == QLatin1String( "https" ) && QSslSocket::supportsSsl() ) {
+        if ( !m_sslSocket )
+            m_sslSocket = new QSslSocket();
+        m_http->setSocket( m_sslSocket );
+        m_http->setHost( host, QHttp::ConnectionModeHttps, ( port < 0 ) ? 443 : port );
+        m_mode = HttpsMode;
+        return;
+    }
+#endif
+
+    m_http->setHost( QString(), 0 );
+    m_mode = UnknownMode;
 }
 
 void CommandManager::sendCommandRequest( Command* command )
@@ -188,7 +234,7 @@ void CommandManager::sendCommandRequest( Command* command )
     QString commandLine = command->keyword();
 
     for ( int i = 0; i < command->args().count(); i++ ) {
-        commandLine += ' ';
+        commandLine += QLatin1Char( ' ' );
         QVariant arg = command->args().at( i );
         if ( arg.type() == QVariant::String )
             commandLine += quoteString( arg.toString() );
@@ -224,7 +270,8 @@ void CommandManager::dataReadProgress( int done, int total )
 
 void CommandManager::readyRead( const QHttpResponseHeader& response )
 {
-    if ( m_currentCommand && m_currentCommand->acceptBinaryResponse() && response.contentType() == "application/octet-stream" ) {
+    if ( m_currentCommand && m_currentCommand->acceptBinaryResponse()
+        && response.contentType() == QLatin1String( "application/octet-stream" ) ) {
         int length;
         char buffer[ 8192 ];
         while ( ( length = m_http->read( buffer, 8192 ) ) > 0 )
@@ -267,13 +314,22 @@ void CommandManager::requestFinished( int id, bool error )
 bool CommandManager::handleCommandResponse( const QHttpResponseHeader& response )
 {
     if ( m_http->error() != QHttp::NoError ) {
-        if ( m_http->error() == QHttp::Aborted )
-            setError( Aborted, 0, QString() );
+        if ( m_mode == InvalidMode )
+            setError( InvalidUrl );
+        else if ( m_mode == UnknownMode )
+            setError( UnknownUrlScheme );
+        else if ( m_http->error() == QHttp::Aborted )
+            setError( Aborted );
         else
             setError( ConnectionError, m_http->error(), m_http->errorString() );
         return false;
     }
 
+    if ( !response.isValid() ) {
+        setError( InvalidResponse );
+        return false;
+    }
+
     if ( response.statusCode() != 200 ) {
         setError( HttpError, response.statusCode(), response.reasonPhrase() );
         return false;
@@ -287,40 +343,40 @@ bool CommandManager::handleCommandResponse( const QHttpResponseHeader& response
     m_serverVersion = response.value( "X-WebIssues-Server" );
 
     if ( m_protocolVersion.isEmpty() ) {
-        setError( InvalidServer, 0, QString() );
+        setError( InvalidServer );
         return false;
     }
 
-    if ( m_protocolVersion != "0.8" ) {
+    if ( m_protocolVersion != QLatin1String( "0.8" ) ) {
         setError( InvalidVersion, 0, m_protocolVersion );
         return false;
     }
 
-    if ( response.contentType() == "text/plain" ) {
+    if ( response.contentType() == QLatin1String( "text/plain" ) ) {
         QByteArray body = m_http->readAll();
 
         QString string = QString::fromUtf8( body.data(), body.size() );
 
         Reply reply;
         if ( !parseReply( string, reply ) ) {
-            setError( InvalidResponse, 0, QString() );
+            setError( InvalidResponse );
             return false;
         }
 
         return handleCommandReply( reply );
     }
 
-    if ( response.contentType() == "application/octet-stream" ) {
+    if ( response.contentType() == QLatin1String( "application/octet-stream" ) ) {
         if ( !m_currentCommand->acceptBinaryResponse() ) {
-            setError( InvalidResponse, 0, QString() );
+            setError( InvalidResponse );
             return false;
         }
 
-        setError( NoError, 0, QString() );
+        setError( NoError );
         return true;
     }
 
-    setError( InvalidResponse, 0, QString() );
+    setError( InvalidResponse );
     return false;
 }
 
@@ -332,26 +388,26 @@ bool CommandManager::handleCommandReply( const Reply& reply )
         ReplyLine line = reply.lines().at( 0 );
         QString signature = makeSignature( line );
 
-        if ( signature == "ERROR is" ) {
+        if ( signature == QLatin1String( "ERROR is" ) ) {
             setError( WebIssuesError, line.argInt( 0 ), line.argString( 1 ) );
             return false;
         }
 
-        if ( signature == "NULL" )
+        if ( signature == QLatin1String( "NULL" ) )
             isNull = true;
     }
 
     bool isValid = isNull ? m_currentCommand->acceptNullReply() : validateReply( reply );
 
     if ( !isValid ) {
-        setError( InvalidResponse, 0, QString() );
+        setError( InvalidResponse );
         return false;
     }
 
     if ( !isNull )
         m_currentCommand->setCommandReply( reply );
 
-    setError( NoError, 0, QString() );
+    setError( NoError );
     return true;
 }
 
@@ -372,7 +428,7 @@ bool CommandManager::parseReply( const QString& string, Reply& reply )
         int pos = 0;
         while ( ( pos = argumentRegExp.indexIn( *it, pos ) ) >= 0 ) {
             QString argument = argumentRegExp.cap( 0 );
-            if ( argument[ 0 ] == '\'' )
+            if ( argument[ 0 ] == QLatin1Char( '\'' ) )
                 line.addArg( unquoteString( argument ) );
             else
                 line.addArg( argument.toInt() );
@@ -425,10 +481,13 @@ QString CommandManager::makeSignature( const ReplyLine& line )
     for ( int i = 0; i < line.args().count(); i++ ) {
         switch ( line.args().at( i ).type() ) {
             case QVariant::Int:
-                signature += 'i';
+                signature += QLatin1Char( 'i' );
                 break;
             case QVariant::String:
-                signature += 's';
+                signature += QLatin1Char( 's' );
+                break;
+            default:
+                signature += QLatin1Char( '?' );
                 break;
         }
     }
@@ -442,14 +501,14 @@ QString CommandManager::quoteString( const QString& string )
     int length = string.length();
     for ( int i = 0; i < length; i++ ) {
         QChar ch = string[ i ];
-        if  ( ch == '\\' || ch == '\'' || ch == '\n' ) {
-            result += '\\';
-            if ( ch == '\n' )
-                ch = 'n';
+        if  ( ch == QLatin1Char( '\\' ) || ch == QLatin1Char( '\'' ) || ch == QLatin1Char( '\n' ) ) {
+            result += QLatin1Char( '\\' );
+            if ( ch == QLatin1Char( '\n' ) )
+                ch = QLatin1Char( 'n' );
         }
         result += ch;
     }
-    result += '\'';
+    result += QLatin1Char( '\'' );
     return result;
 }
 
@@ -459,19 +518,42 @@ QString CommandManager::unquoteString( const QString& string )
     int length = string.length();
     for ( int i = 1; i < length - 1; i++ ) {
         QChar ch = string[ i ];
-        if ( ch == '\\' ) {
+        if ( ch == QLatin1Char( '\\' ) ) {
             ch = string[ ++i ];
-            if ( ch == 'n' )
-                ch = '\n';
+            if ( ch == QLatin1Char( 'n' ) )
+                ch = QLatin1Char( '\n' );
         }
         result += ch;
     }
     return result;
 }
 
-void CommandManager::setError( Error error, int code, const QString& string )
+void CommandManager::setError( Error error, int code /*= 0*/, const QString& string /*= QString()*/ )
 {
     m_error = error;
     m_errorCode = code;
     m_errorString = string;
 }
+
+#if defined( HAVE_OPENSSL )
+
+QList<QSslCertificate> CommandManager::certificateChain()
+{
+    if ( m_mode != HttpsMode )
+        return QList<QSslCertificate>();
+    return m_sslSocket->peerCertificateChain();
+}
+
+QSslCipher CommandManager::sessionCipher()
+{
+    if ( m_mode != HttpsMode )
+        return QSslCipher();
+    return m_sslSocket->sessionCipher();
+}
+
+void CommandManager::ignoreSslErrors()
+{
+    m_http->ignoreSslErrors();
+}
+
+#endif // defined( HAVE_OPENSSL )
