@@ -19,8 +19,12 @@
 class QHttp;
 class QHttpResponseHeader;
 
-namespace WebIssues
-{
+#if defined( HAVE_OPENSSL )
+class QSslSocket;
+class QSslCertificate;
+class QSslCipher;
+class QSslError;
+#endif
 
 class AbstractBatch;
 class Command;
@@ -49,6 +53,10 @@ public:
     {
         /** No error. */
         NoError,
+        /** The URL passed to the command manager is invalid. */
+        InvalidUrl,
+        /** The URL passed to the command manager has an unsupported scheme. */
+        UnknownUrlScheme,
         /** Connection to the server failed. The errorCode() method returns a QHttp::Error flag. */
         ConnectionError,
         /** The server returned an HTTP error. The errorCode() method returns the HTTP status. */
@@ -65,6 +73,21 @@ public:
         Aborted
     };
 
+    /**
+    * Mode of connection with the server.
+    */
+    enum Mode
+    {
+        /** No URL or invalid URL specified. */
+        InvalidMode,
+        /** URL scheme not supported. */
+        UnknownMode,
+        /** Regular http connection. */
+        HttpMode,
+        /** Secure https connection. */
+        HttpsMode
+    };
+
 public:
     /**
     * Default constructor.
@@ -89,6 +112,11 @@ public:
     */
     const QUrl& serverUrl() const { return m_url; }
 
+    /**
+    * Return the mode of connection with the server.
+    */
+    Mode connectionMode() const { return m_mode; }
+
     /**
     * Append the batch to the execution queue.
     *
@@ -132,6 +160,31 @@ public:
     */
     const QString& serverVersion() const { return m_serverVersion; }    
 
+#if defined( HAVE_OPENSSL )
+    /**
+    * Return server's chain of certificates.
+    */
+    QList<QSslCertificate> certificateChain();
+
+    /**
+    * Return the session's cryptographic cipher.
+    */
+    QSslCipher sessionCipher();
+
+    /**
+    * Ignore SSL errors when called from the sslErrors() signal handler.
+    */
+    void ignoreSslErrors();
+#endif // defined( HAVE_OPENSSL )
+
+signals:
+#if defined( HAVE_OPENSSL )
+    /**
+    * Forwards the sslErrors signal from the QSslSocket.
+    */
+    void sslErrors( const QList<QSslError>& );
+#endif // defined( HAVE_OPENSSL )
+
 private:
     void checkPendingCommand();
 
@@ -149,7 +202,7 @@ private:
     QString quoteString( const QString& string );
     QString unquoteString( const QString& string );
 
-    void setError( Error error, int code, const QString& string );
+    void setError( Error error, int code = 0, const QString& string = QString() );
 
 private slots:
     void dataSendProgress( int done, int total );
@@ -162,8 +215,14 @@ private slots:
 private:
     QHttp* m_http;
 
+#if defined( HAVE_OPENSSL )
+    QSslSocket* m_sslSocket;
+#endif
+
     QList<AbstractBatch*> m_batches;
 
+    Mode m_mode;
+
     QUrl m_url;
     QString m_cookie;
 
@@ -184,6 +243,4 @@ private:
 */
 extern CommandManager* commandManager;
 
-}
-
 #endif
