@@ -15,9 +15,6 @@
 #include <QString>
 #include <QBuffer>
 
-namespace WebIssues
-{
-
 /**
 * Class encapsulating a form data message.
 *
@@ -96,6 +93,4 @@ private:
     QBuffer m_buffer;
 };
 
-}
-
 #endif
