@@ -16,9 +16,6 @@
 #include <QList>
 #include <QVariant>
 
-namespace WebIssues
-{
-
 /**
 * Structure representing a single line of the server's reply.
 */
@@ -193,6 +190,4 @@ private:
     Multiplicity m_multiplicity;
 };
 
-}
-
 #endif
