@@ -17,9 +17,7 @@
 #include <QDir>
 #endif
 
-using namespace WebIssues;
-
-ConfigData* WebIssues::configData = NULL;
+ConfigData* configData = NULL;
 
 ConfigData::ConfigData()
 {
@@ -39,7 +37,7 @@ void ConfigData::loadSettings()
     m_dockWindow = m_settings->value( "DockWindow", false ).toBool();
     m_showAtStartup = (RestoreOption)m_settings->value( "ShowAtStartup", (RestoreOption)RestoreAuto ).toInt();
     QVariant reconnect = m_settings->value( "ReconnectAtStartup" );
-    if ( reconnect.toString() == "true" )
+    if ( reconnect.toString() == QLatin1String( "true" ) )
         m_reconnectAtStartup = RestoreAuto;
     else
         m_reconnectAtStartup = (RestoreOption)reconnect.toInt();
