@@ -17,9 +17,6 @@
 
 class QSettings;
 
-namespace WebIssues
-{
-
 /**
 * Action performed on an attachment.
 */
@@ -199,6 +196,4 @@ private:
 */
 extern ConfigData* configData;
 
-}
-
 #endif
