@@ -29,9 +29,7 @@
 #include "viewmanager.h"
 #include "configdata.h"
 
-using namespace WebIssues;
-
-ConnectionManager* WebIssues::connectionManager = NULL;
+ConnectionManager* connectionManager = NULL;
 
 ConnectionManager::ConnectionManager() :
     m_info( NULL ),
@@ -44,7 +42,7 @@ ConnectionManager::ConnectionManager() :
     char appDataPath[ MAX_PATH ];
     if ( SHGetSpecialFolderPathA( 0, appDataPath, CSIDL_APPDATA, FALSE ) ) {
         m_dataPath = QDir::fromNativeSeparators( QString::fromLocal8Bit( appDataPath ) );
-        m_dataPath += "/WebIssues";
+        m_dataPath += QLatin1String( "/WebIssues" );
     } else {
         m_dataPath = homePath + "/WebIssues";
     }
@@ -52,14 +50,14 @@ ConnectionManager::ConnectionManager() :
     char localAppDataPath[ MAX_PATH ];
     if ( SHGetSpecialFolderPathA( 0, localAppDataPath, CSIDL_LOCAL_APPDATA, FALSE ) ) {
         m_cachePath = QDir::fromNativeSeparators( QString::fromLocal8Bit( localAppDataPath ) );
-        m_cachePath += "/WebIssues";
+        m_cachePath += QLatin1String( "/WebIssues" );
     } else {
         m_cachePath = m_dataPath + "/.cache";
     }
 #else
     char* dataHome = getenv( "XDG_DATA_HOME" );
     if ( dataHome ) {
-        if ( dataHome[ 0 ] == '/' )
+        if ( dataHome[ 0 ] == QLatin1Char( '/' ) )
             m_dataPath = dataHome;
         else
             m_dataPath = homePath + '/' + dataHome;
@@ -67,11 +65,11 @@ ConnectionManager::ConnectionManager() :
         m_dataPath = homePath + "/.local/share";
     }
 
-    m_dataPath += "/webissues";
+    m_dataPath += QLatin1String( "/webissues" );
 
     char* cacheHome = getenv( "XDG_CACHE_HOME" );
     if ( cacheHome ) {
-        if ( cacheHome[ 0 ] == '/' )
+        if ( cacheHome[ 0 ] == QLatin1Char( '/' ) )
             m_cachePath = cacheHome;
         else
             m_cachePath = homePath + '/' + cacheHome;
@@ -79,7 +77,7 @@ ConnectionManager::ConnectionManager() :
         m_cachePath = homePath + "/.cache";
     }
 
-    m_cachePath += "/webissues";
+    m_cachePath += QLatin1String( "/webissues" );
 #endif
 }
 
@@ -208,7 +206,7 @@ void ConnectionManager::copyAllKeys( QSettings* dest, const QSettings* src )
     QStringList keys = src->allKeys();
 
     for ( int i = 0; i < keys.count(); i++ ) {
-        if ( keys[ i ] == "ServerUuid" )
+        if ( keys[ i ] == QLatin1String( "ServerUuid" ) )
             continue;
         dest->setValue( keys[ i ], src->value( keys[ i ] ) );
     }
