@@ -16,9 +16,6 @@
 
 class QSettings;
 
-namespace WebIssues
-{
-
 class ConnectionInfo;
 class AttachmentsCache;
 
@@ -157,6 +154,4 @@ private:
 */
 extern ConnectionManager* connectionManager;
 
-}
-
 #endif
