@@ -15,9 +15,6 @@
 #include <QObject>
 #include <QList>
 
-namespace WebIssues
-{
-
 /**
 * Class for caching downloaded attachments.
 */
@@ -88,6 +85,4 @@ private:
     Item m_allocatedItem;
 };
 
-}
-
 #endif
