@@ -14,9 +14,6 @@
 
 #include <QString>
 
-namespace WebIssues
-{
-
 /**
 * Structure storing information about a bookmark.
 */
@@ -74,6 +71,4 @@ private:
     QString m_password;
 };
 
-}
-
 #endif
