@@ -14,9 +14,6 @@
 
 #include "datarows.h"
 
-namespace WebIssues
-{
-
 /**
 * Structure storing information about a connection to the WebIssues server.
 */
@@ -62,6 +59,4 @@ private:
     Access m_access;
 };
 
-}
-
 #endif
