@@ -15,28 +15,34 @@
 #include <QFile>
 
 #include "commands/command.h"
-#include "rdb/tableiterators.h"
 #include "connectionmanager.h"
 
-using namespace WebIssues;
+DataManager* dataManager = NULL;
 
-DataManager* WebIssues::dataManager = NULL;
-
-DataManager::DataManager() :
-    m_users( 251 ),
-    m_members( 251, 31 ),
-    m_types( 31 ),
-    m_attributes( 251, 31 ),
-    m_projects( 31 ),
-    m_folders( 127, 31 ),
-    m_issues( 8191, 1021 ),
-    m_values( 251, 8191 ),
-    m_comments( 251, 127 ),
-    m_attachments( 251, 127 ),
-    m_changes( 1021, 127 ),
-    m_foldersState( 127 ),
-    m_issuesState( 8191 )
+DataManager::DataManager()
 {
+    m_users.initIndex( 251, &UserRow::userId );
+    m_members.initFirstIndex( 251, &MemberRow::userId );
+    m_members.initSecondIndex( 31, &MemberRow::projectId );
+    m_types.initIndex( 31, &TypeRow::typeId );
+    m_attributes.initIndex( 251, &AttributeRow::attributeId );
+    m_attributes.initParentIndex( 31, &AttributeRow::typeId );
+    m_projects.initIndex( 31, &ProjectRow::projectId );
+    m_folders.initIndex( 127, &FolderRow::folderId );
+    m_folders.initParentIndex( 31, &FolderRow::projectId );
+    m_issues.initIndex( 8191, &IssueRow::issueId );
+    m_issues.initParentIndex( 1021, &IssueRow::folderId );
+    m_values.initFirstIndex( 251, &ValueRow::attributeId );
+    m_values.initSecondIndex( 8191, &ValueRow::issueId );
+    m_comments.initIndex( 251, &CommentRow::commentId );
+    m_comments.initParentIndex( 127, &CommentRow::issueId );
+    m_attachments.initIndex( 251, &AttachmentRow::attachmentId );
+    m_attachments.initParentIndex( 127, &AttachmentRow::issueId );
+    m_changes.initIndex( 1021, &ChangeRow::changeId );
+    m_changes.initParentIndex( 127, &ChangeRow::issueId );
+    m_foldersState.initIndex( 127, &FolderState::folderId );
+    m_issuesState.initIndex( 8191, &IssueState::issueId );
+
     loadWatchCache();
 }
 
@@ -58,7 +64,7 @@ void DataManager::removeObserver( QObject* observer )
 
 void DataManager::notifyObservers( UpdateEvent::Unit unit, int id )
 {
-    for ( uint i = 0; i < m_observers.count(); i++ ) {
+    for ( int i = 0; i < m_observers.count(); i++ ) {
         UpdateEvent* updateEvent = new UpdateEvent( unit, id );
         QApplication::postEvent( m_observers.at( i ), updateEvent );
     }
@@ -143,7 +149,7 @@ void DataManager::flushIssueCache()
         int oldestIssueId = 0;
         QDateTime oldestTime = QDateTime::currentDateTime().addSecs( 1 );
 
-        RDB::TableIterator<IssueState> it( &m_issuesState );
+        RDB::IndexIterator<IssueState> it( m_issuesState.index() );
         while ( it.next() ) {
             IssueState* state = it.get();
             if ( state->detailsStamp() != 0 ) {
@@ -306,10 +312,10 @@ void DataManager::updateUsersReply( const Reply& reply )
 
     for ( int i = 0; i < reply.lines().count(); i++ ) {
         ReplyLine line = reply.lines().at( i );
-        if ( line.keyword() == "U" ) {
+        if ( line.keyword() == QLatin1String( "U" ) ) {
             UserRow* user = readUserRow( line );
             m_users.insert( user );
-        } else {
+        } else { // "M"
             MemberRow* member = readMemberRow( line );
             m_members.insert( member );
         }
@@ -325,10 +331,10 @@ void DataManager::updateTypesReply( const Reply& reply )
 
     for ( int i = 0; i < reply.lines().count(); i++ ) {
         ReplyLine line = reply.lines().at( i );
-        if ( line.keyword() == "T" ) {
+        if ( line.keyword() == QLatin1String( "T" ) ) {
             TypeRow* type = readTypeRow( line );
             m_types.insert( type );
-        } else {
+        } else { // "A"
             AttributeRow* attribute = readAttributeRow( line );
             m_attributes.insert( attribute );
         }
@@ -344,10 +350,10 @@ void DataManager::updateProjectsReply( const Reply& reply )
 
     for ( int i = 0; i < reply.lines().count(); i++ ) {
         ReplyLine line = reply.lines().at( i );
-        if ( line.keyword() == "P" ) {
+        if ( line.keyword() == QLatin1String( "P" ) ) {
             ProjectRow* project = readProjectRow( line );
             m_projects.insert( project );
-        } else {
+        } else { // "F"
             FolderRow* folder = readFolderRow( line );
             m_folders.insert( folder );
         }
@@ -363,7 +369,7 @@ void DataManager::updateFolderReply( const Reply& reply )
 
     for ( int i = 0; i < reply.lines().count(); i++ ) {
         ReplyLine line = reply.lines().at( i );
-        if ( line.keyword() == "I" ) {
+        if ( line.keyword() == QLatin1String( "I" ) ) {
             IssueRow* issue = readIssueRow( line );
 
             folderId = issue->folderId();
@@ -373,8 +379,8 @@ void DataManager::updateFolderReply( const Reply& reply )
             m_issues.remove( issue->issueId() );
             m_issues.insert( issue );
 
-            m_values.removeAll( 1, issue->issueId() );
-        } else {
+            m_values.removeSecond( issue->issueId() );
+        } else { // "V"
             ValueRow* value = readValueRow( line );
             m_values.insert( value );
         }
@@ -396,23 +402,23 @@ void DataManager::updateIssueReply( const Reply& reply )
     m_issues.remove( issueId );
     m_issues.insert( issue );
 
-    m_values.removeAll( 1, issueId );
+    m_values.removeSecond( issueId );
 
     IssueState* state = issueState( issueId );
     state->setDetailsStamp( issue->stamp() );
 
     for ( int i = 1; i < reply.lines().count(); i++ ) {
         ReplyLine line = reply.lines().at( i );
-        if ( line.keyword() == "V" ) {
+        if ( line.keyword() == QLatin1String( "V" ) ) {
             ValueRow* value = readValueRow( line );
             m_values.insert( value );
-        } else if ( line.keyword() == "C" ) {
+        } else if ( line.keyword() == QLatin1String( "C" ) ) {
             CommentRow* comment = readCommentRow( line );
             m_comments.insert( comment );
-        } else if ( line.keyword() == "A" ) {
+        } else if ( line.keyword() == QLatin1String( "A" ) ) {
             AttachmentRow* attachment = readAttachmentRow( line );
             m_attachments.insert( attachment );
-        } else {
+        } else { // "H"
             ChangeRow* change = readChangeRow( line );
             m_changes.insert( change );
         }
@@ -633,9 +639,9 @@ void DataManager::readFolderCache( int folderId )
 
 void DataManager::saveFolderCache()
 {
-    RDB::TableConstIterator<FolderRow> it( &m_folders );
+    RDB::IndexConstIterator<FolderRow> it( m_folders.index() );
     while ( it.next() )
-        writeFolderCache( it.get()->folderId() );
+        writeFolderCache( it.key() );
 }
 
 void DataManager::writeFolderCache( int folderId )
@@ -670,7 +676,7 @@ void DataManager::writeFolderCache( int folderId )
         stream << issue->modifiedDate();
         stream << (qint32)issue->modifiedUser();
 
-        RDB::ForeignConstIterator<ValueRow> it2( m_values.otherIndex(), issue->issueId() );
+        RDB::ForeignConstIterator<ValueRow> it2( m_values.index().second(), issue->issueId() );
         while ( it2.next() ) {
             const ValueRow* value = it2.get();
             stream << (qint32)value->attributeId();
@@ -732,9 +738,9 @@ void DataManager::saveWatchCache()
 
     stream << (qint32)1; // increment version when adding/changing fields
 
-    RDB::TableConstIterator<FolderRow> itf( &m_folders );
+    RDB::IndexConstIterator<FolderRow> itf( m_folders.index() );
     while ( itf.next() ) {
-        int folderId = itf.get()->folderId();
+        int folderId = itf.key();
         FolderState* fstate = folderState( folderId );
 
         if ( fstate->watchState() != NotWatched ) {
