@@ -15,14 +15,11 @@
 #include <QObject>
 #include <QList>
 
-#include "rdb/tabletemplates.h"
+#include "rdb/rdb.h"
 #include "datarows.h"
 #include "staterows.h"
 #include "updateevent.h"
 
-namespace WebIssues
-{
-
 class Command;
 class Reply;
 class ReplyLine;
@@ -355,6 +352,4 @@ private:
 */
 extern DataManager* dataManager;
 
-}
-
 #endif
