@@ -11,12 +11,10 @@
 
 #include "datarows.h"
 
-using namespace WebIssues;
-
 ProjectRow::ProjectRow( int projectId, const QString& name ) :
+    m_projectId( projectId ),
     m_name( name )
 {
-    setKey( 0, projectId );
 }
 
 ProjectRow::~ProjectRow()
@@ -24,12 +22,12 @@ ProjectRow::~ProjectRow()
 }
 
 FolderRow::FolderRow( int folderId, int projectId, const QString& name, int typeId, int stamp ) :
+    m_folderId( folderId ),
+    m_projectId( projectId ),
     m_name( name ),
     m_typeId( typeId ),
     m_stamp( stamp )
 {
-    setKey( 0, folderId );
-    setKey( 1, projectId );
 }
 
 FolderRow::~FolderRow()
@@ -37,11 +35,11 @@ FolderRow::~FolderRow()
 }
 
 UserRow::UserRow( int userId, const QString& login, const QString& name, Access access ) :
+    m_userId( userId ),
     m_login( login ),
     m_name( name ),
     m_access( access )
 {
-    setKey( 0, userId );
 }
 
 UserRow::~UserRow()
@@ -49,10 +47,10 @@ UserRow::~UserRow()
 }
 
 MemberRow::MemberRow( int userId, int projectId, Access access ) :
+    m_userId( userId ),
+    m_projectId( projectId ),
     m_access( access )
 {
-    setKey( 0, userId );
-    setKey( 1, projectId );
 }
 
 MemberRow::~MemberRow()
@@ -60,9 +58,9 @@ MemberRow::~MemberRow()
 }
 
 TypeRow::TypeRow( int typeId, const QString& name ) :
+    m_typeId( typeId ),
     m_name( name )
 {
-    setKey( 0, typeId );
 }
 
 TypeRow::~TypeRow()
@@ -70,11 +68,11 @@ TypeRow::~TypeRow()
 }
 
 AttributeRow::AttributeRow( int attributeId, int typeId, const QString& name, const QString& definition ) :
+    m_attributeId( attributeId ),
+    m_typeId( typeId ),
     m_name( name ),
     m_definition( definition )
 {
-    setKey( 0, attributeId );
-    setKey( 1, typeId );
 }
 
 AttributeRow::~AttributeRow()
@@ -83,6 +81,8 @@ AttributeRow::~AttributeRow()
 
 IssueRow::IssueRow( int issueId, int folderId, const QString& name, int stamp, const QDateTime& createdDate,
         int createdUser, const QDateTime& modifiedDate, int modifiedUser ) :
+    m_issueId( issueId ),
+    m_folderId( folderId ),
     m_name( name ),
     m_stamp( stamp ),
     m_createdDate( createdDate ),
@@ -90,8 +90,6 @@ IssueRow::IssueRow( int issueId, int folderId, const QString& name, int stamp, c
     m_modifiedDate( modifiedDate ),
     m_modifiedUser( modifiedUser )
 {
-    setKey( 0, issueId );
-    setKey( 1, folderId );
 }
 
 IssueRow::~IssueRow()
@@ -99,10 +97,10 @@ IssueRow::~IssueRow()
 }
 
 ValueRow::ValueRow( int attributeId, int issueId, const QString& value ) :
+    m_attributeId( attributeId ),
+    m_issueId( issueId ),
     m_value( value )
 {
-    setKey( 0, attributeId );
-    setKey( 1, issueId );
 }
 
 ValueRow::~ValueRow()
@@ -111,12 +109,12 @@ ValueRow::~ValueRow()
 
 CommentRow::CommentRow( int commentId, int issueId, const QDateTime& createdDate, int createdUser,
         const QString& text ) :
+    m_commentId( commentId ),
+    m_issueId( issueId ),
     m_createdDate( createdDate ),
     m_createdUser( createdUser ),
     m_text( text )
 {
-    setKey( 0, commentId );
-    setKey( 1, issueId );
 }
 
 CommentRow::~CommentRow()
@@ -125,14 +123,14 @@ CommentRow::~CommentRow()
 
 AttachmentRow::AttachmentRow( int attachmentId, int issueId, const QString& name, const QDateTime& createdDate,
         int createdUser, int size, const QString& description ) :
+    m_attachmentId( attachmentId ),
+    m_issueId( issueId ),
     m_name( name ),
     m_createdDate( createdDate ),
     m_createdUser( createdUser ),
     m_size( size ),
     m_description( description )
 {
-    setKey( 0, attachmentId );
-    setKey( 1, issueId );
 }
 
 AttachmentRow::~AttachmentRow()
@@ -141,14 +139,14 @@ AttachmentRow::~AttachmentRow()
 
 ChangeRow::ChangeRow( int changeId, int issueId, const QDateTime& modifiedDate, int modifiedUser,
         int attributeId, const QString& oldValue, const QString& newValue ) :
+    m_changeId( changeId ),
+    m_issueId( issueId ),
     m_modifiedDate( modifiedDate ),
     m_modifiedUser( modifiedUser ),
     m_attributeId( attributeId ),
     m_oldValue( oldValue ),
     m_newValue( newValue )
 {
-    setKey( 0, changeId );
-    setKey( 1, issueId );
 }
 
 ChangeRow::~ChangeRow()
