@@ -15,11 +15,6 @@
 #include <QString>
 #include <QDateTime>
 
-#include "rdb/rowbase.h"
-
-namespace WebIssues
-{
-
 /**
 * Access level for user or member.
 */
@@ -46,7 +41,7 @@ enum Access
 /**
 * A row of the users table.
 */
-class UserRow : public RDB::RowBase< 1 >
+class UserRow
 {
 public:
     /**
@@ -63,7 +58,7 @@ public:
     /**
     * Return the identifier of the user.
     */
-    int userId() const { return key( 0 ); }
+    int userId() const { return m_userId; }
 
     /**
     * Return the login of the user.
@@ -81,6 +76,7 @@ public:
     Access access() const { return m_access; }
 
 private:
+    int m_userId;
     QString m_login;
     QString m_name;
     Access m_access;
@@ -89,7 +85,7 @@ private:
 /**
 * A row of the members table.
 */
-class MemberRow : public RDB::RowBase< 2 >
+class MemberRow
 {
 public:
     /**
@@ -106,12 +102,12 @@ public:
     /**
     * Return the idenifier of the user.
     */
-    int userId() const { return key( 0 ); }
+    int userId() const { return m_userId; }
 
     /**
     * Return the identifier of the project.
     */
-    int projectId() const { return key( 1 ); }
+    int projectId() const { return m_projectId; }
 
     /**
     * Return the user's access level to the project.
@@ -119,13 +115,15 @@ public:
     Access access() const { return m_access; }
 
 private:
+    int m_userId;
+    int m_projectId;
     Access m_access;
 };
 
 /**
 * A row of the issue types table.
 */
-class TypeRow : public RDB::RowBase< 1 >
+class TypeRow
 {
 public:
     /**
@@ -142,7 +140,7 @@ public:
     /**
     * Return the identifier of the issue type.
     */
-    int typeId() const { return key( 0 ); }
+    int typeId() const { return m_typeId; }
 
     /**
     * Return the name of the issue type.
@@ -150,13 +148,14 @@ public:
     const QString& name() const { return m_name; }
 
 private:
+    int m_typeId;
     QString m_name;
 };
 
 /**
 * A row of the attribute definitions table.
 */
-class AttributeRow : public RDB::RowBase< 2 >
+class AttributeRow
 {
 public:
     /**
@@ -173,12 +172,12 @@ public:
     /**
     * Return the identifier of the attribute.
     */
-    int attributeId() const { return key( 0 ); }
+    int attributeId() const { return m_attributeId; }
 
     /**
     * Return the identifier of the issue type.
     */
-    int typeId() const { return key( 1 ); }
+    int typeId() const { return m_typeId; }
 
     /**
     * Return the name of the attribute.
@@ -191,6 +190,8 @@ public:
     const QString& definition() const { return m_definition; }
 
 private:
+    int m_attributeId;
+    int m_typeId;
     QString m_name;
     QString m_definition;
 };
@@ -198,7 +199,7 @@ private:
 /**
 * A row of the projects table.
 */
-class ProjectRow : public RDB::RowBase< 1 >
+class ProjectRow
 {
 public:
     /**
@@ -215,7 +216,7 @@ public:
     /**
     * Return the identifier of the project.
     */
-    int projectId() const { return key( 0 ); }
+    int projectId() const { return m_projectId; }
 
     /**
     * Return the name of the project.
@@ -223,13 +224,14 @@ public:
     const QString& name() const { return m_name; }
 
 private:
+    int m_projectId;
     QString m_name;
 };
 
 /**
 * A row of the folders table.
 */
-class FolderRow : public RDB::RowBase< 2 >
+class FolderRow
 {
 public:
     /**
@@ -246,12 +248,12 @@ public:
     /**
     * Return the identifier of the folder.
     */
-    int folderId() const { return key( 0 ); }
+    int folderId() const { return m_folderId; }
 
     /**
     * Return the identifier of the folder's project.
     */
-    int projectId() const { return key( 1 ); }
+    int projectId() const { return m_projectId; }
 
     /**
     * Return the folder name.
@@ -269,6 +271,8 @@ public:
     int stamp() const { return m_stamp; }
 
 private:
+    int m_folderId;
+    int m_projectId;
     QString m_name;
     int m_typeId;
     int m_stamp;
@@ -277,7 +281,7 @@ private:
 /**
 * A row of the issues table.
 */
-class IssueRow : public RDB::RowBase< 2 >
+class IssueRow
 {
 public:
     /**
@@ -295,12 +299,12 @@ public:
     /**
     * Return the identifier of the issue.
     */
-    int issueId() const { return key( 0 ); }
+    int issueId() const { return m_issueId; }
 
     /**
     * Return the identifier of the issue's folder.
     */
-    int folderId() const { return key( 1 ); }
+    int folderId() const { return m_folderId; }
 
     /**
     * Return the issue name.
@@ -333,6 +337,8 @@ public:
     int modifiedUser() const { return m_modifiedUser; }
 
 private:
+    int m_issueId;
+    int m_folderId;
     QString m_name;
     int m_stamp;
     QDateTime m_createdDate;
@@ -344,7 +350,7 @@ private:
 /**
 * A row of the attribute values table.
 */
-class ValueRow : public RDB::RowBase< 2 >
+class ValueRow
 {
 public:
     /**
@@ -361,12 +367,12 @@ public:
     /**
     * Return the identifier of the attribute.
     */
-    int attributeId() const { return key( 0 ); }
+    int attributeId() const { return m_attributeId; }
 
     /**
     * Return the identifier of the issue.
     */
-    int issueId() const { return key( 1 ); }
+    int issueId() const { return m_issueId; }
 
     /**
     * Return the attribute value.
@@ -374,13 +380,15 @@ public:
     const QString& value() const { return m_value; }
 
 private:
+    int m_attributeId;
+    int m_issueId;
     QString m_value;
 };
 
 /**
 * A row of the comments table.
 */
-class CommentRow : public RDB::RowBase< 2 >
+class CommentRow
 {
 public:
     /**
@@ -398,12 +406,12 @@ public:
     /**
     * Return the identifier of the comment.
     */
-    int commentId() const { return key( 0 ); }
+    int commentId() const { return m_commentId; }
 
     /**
     * Return the identifier of the issue.
     */
-    int issueId() const { return key( 1 ); }
+    int issueId() const { return m_issueId; }
 
     /**
     * Return the creation date.
@@ -421,6 +429,8 @@ public:
     const QString& text() const { return m_text; }
 
 private:
+    int m_commentId;
+    int m_issueId;
     QDateTime m_createdDate;
     int m_createdUser;
     QString m_text;
@@ -429,7 +439,7 @@ private:
 /**
 * A row of the attachments table.
 */
-class AttachmentRow : public RDB::RowBase< 2 >
+class AttachmentRow
 {
 public:
     /**
@@ -447,12 +457,12 @@ public:
     /**
     * Return the identifier of the attachment.
     */
-    int attachmentId() const { return key( 0 ); }
+    int attachmentId() const { return m_attachmentId; }
 
     /**
     * Return the identifier of the issue.
     */
-    int issueId() const { return key( 1 ); }
+    int issueId() const { return m_issueId; }
 
     /**
     * Return the name of the attachment.
@@ -480,6 +490,8 @@ public:
     const QString& description() const { return m_description; }
 
 private:
+    int m_attachmentId;
+    int m_issueId;
     QString m_name;
     QDateTime m_createdDate;
     int m_createdUser;
@@ -490,7 +502,7 @@ private:
 /**
 * A row of the changes table.
 */
-class ChangeRow : public RDB::RowBase< 2 >
+class ChangeRow
 {
 public:
     /**
@@ -508,12 +520,12 @@ public:
     /**
     * Return the identifier of the change.
     */
-    int changeId() const { return key( 0 ); }
+    int changeId() const { return m_changeId; }
 
     /**
     * Return the identifier of the issue.
     */
-    int issueId() const { return key( 1 ); }
+    int issueId() const { return m_issueId; }
 
     /**
     * Return the date of the change.
@@ -541,6 +553,8 @@ public:
     const QString& newValue() const { return m_newValue; }
 
 private:
+    int m_changeId;
+    int m_issueId;
     QDateTime m_modifiedDate;
     int m_modifiedUser;
     int m_attributeId;
@@ -548,6 +562,4 @@ private:
     QString m_newValue;
 };
 
-}
-
 #endif
