@@ -15,9 +15,6 @@
 #include "commands/abstractbatch.h"
 #include "batchjob.h"
 
-namespace WebIssues
-{
-
 class Reply;
 
 /**
@@ -64,6 +61,4 @@ private:
     int m_issueId;
 };
 
-}
-
 #endif
