@@ -16,8 +16,6 @@
 #include "commands/command.h"
 #include "datamanager.h"
 
-using namespace WebIssues;
-
 IssueBatch::IssueBatch( int issueId ) : AbstractBatch( 0 ),
     m_issueId( issueId ),
     m_update( false ),
@@ -252,7 +250,7 @@ void IssueBatch::sendProgress( int done, int total )
         emit uploadProgress( sent );
 }
 
-void IssueBatch::readProgress( int done, int total )
+void IssueBatch::readProgress( int done, int /*total*/ )
 {
     emit downloadProgress( done );
 }
