@@ -17,9 +17,6 @@
 
 class QFile;
 
-namespace WebIssues
-{
-
 class Reply;
 
 /**
@@ -176,6 +173,4 @@ private:
     int m_fileSize;
 };
 
-}
-
 #endif
