@@ -14,8 +14,6 @@
 #include "commands/command.h"
 #include "connectioninfo.h"
 
-using namespace WebIssues;
-
 LoginBatch::LoginBatch( const QString& login, const QString& password ) : AbstractBatch( 127 ),
     m_userId( 0 ),
     m_access( NoAccess )
@@ -48,7 +46,7 @@ Command* LoginBatch::fetchNext()
     return NULL;
 }
 
-Command* LoginBatch::helloJob( const Job& job )
+Command* LoginBatch::helloJob( const Job& /*job*/ )
 {
     Command* command = new Command();
 
