@@ -16,9 +16,6 @@
 #include "batchjob.h"
 #include "datarows.h"
 
-namespace WebIssues
-{
-
 class ConnectionInfo;
 class Reply;
 
@@ -79,6 +76,4 @@ private:
     Access m_access;
 };
 
-}
-
 #endif
