@@ -15,9 +15,6 @@
 #include "commands/abstractbatch.h"
 #include "batchjob.h"
 
-namespace WebIssues
-{
-
 /**
 * Batch for operations on projects and folders.
 *
@@ -115,6 +112,4 @@ private:
     bool m_update;
 };
 
-}
-
 #endif
