@@ -11,14 +11,12 @@
 
 #include "staterows.h"
 
-using namespace WebIssues;
-
 FolderState::FolderState( int folderId ) :
+    m_folderId( folderId ),
     m_listStamp( 0 ),
     m_cached( false ),
     m_watchState( NotWatched )
 {
-    setKey( 0, folderId );
 }
 
 FolderState::~FolderState()
@@ -26,11 +24,11 @@ FolderState::~FolderState()
 }
 
 IssueState::IssueState( int issueId ) :
+    m_issueId( issueId ),
     m_detailsStamp( 0 ),
     m_lockCount( 0 ),
     m_watchStamp( 0 )
 {
-    setKey( 0, issueId );
 }
 
 IssueState::~IssueState()
