@@ -14,11 +14,6 @@
 
 #include <QDateTime>
 
-#include "rdb/rowbase.h"
-
-namespace WebIssues
-{
-
 /**
 * The watch state of a folder or issue.
 */
@@ -35,7 +30,7 @@ enum WatchState
 *
 * This table is used by the DataManager for tracking the state of folders.
 */
-class FolderState : public RDB::RowBase< 1 >
+class FolderState
 {
 public:
     /**
@@ -52,7 +47,7 @@ public:
     /**
     * Return the identifier of the folder.
     */
-    int folderId() const { return key( 0 ); }
+    int folderId() const { return m_folderId; }
 
     /**
     * Set the stamp of the last <tt>LIST ISSUES</tt> command.
@@ -91,10 +86,9 @@ public:
     WatchState watchState() const { return m_watchState; }
 
 private:
+    int m_folderId;
     int m_listStamp;
-
     bool m_cached;
-
     WatchState m_watchState;
 };
 
@@ -103,7 +97,7 @@ private:
 *
 * This table is used by the DataManager for tracking the state of issues.
 */
-class IssueState : public RDB::RowBase< 1 >
+class IssueState
 {
 public:
     /**
@@ -120,7 +114,7 @@ public:
     /**
     * Return the identifier of the issue.
     */
-    int issueId() const { return key( 0 ); }
+    int issueId() const { return m_issueId; }
 
     /**
     * Set the stamp of the last <tt>GET DETAILS</tt> command.
@@ -173,14 +167,11 @@ public:
     int watchStamp() const { return m_watchStamp; }
 
 private:
+    int m_issueId;
     int m_detailsStamp;
-
     int m_lockCount;
     QDateTime m_usedTime;
-
     int m_watchStamp;
 };
 
-}
-
 #endif
