@@ -15,9 +15,6 @@
 #include "commands/abstractbatch.h"
 #include "batchjob.h"
 
-namespace WebIssues
-{
-
 /**
 * Batch for operations on types and attributes.
 *
@@ -125,6 +122,4 @@ private:
     bool m_update;
 };
 
-}
-
 #endif
