@@ -17,9 +17,6 @@
 #include "commands/abstractbatch.h"
 #include "updateevent.h"
 
-namespace WebIssues
-{
-
 /**
 * Batch for retrieving data from the server.
 */
@@ -93,6 +90,4 @@ private:
     int m_next;
 };
 
-}
-
 #endif
