@@ -14,9 +14,6 @@
 
 #include <QEvent>
 
-namespace WebIssues
-{
-
 /**
 * Event sent to data observers when data is updated.
 *
@@ -79,6 +76,4 @@ private:
     int m_id;
 };
 
-}
-
 #endif
