@@ -16,9 +16,6 @@
 #include "batchjob.h"
 #include "datarows.h"
 
-namespace WebIssues
-{
-
 /**
 * Batch for operations on users.
 *
@@ -113,6 +110,4 @@ private:
     bool m_update;
 };
 
-}
-
 #endif
