@@ -26,10 +26,6 @@
 #include "widgets/gradientwidget.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::AttributeSettingsDialog */
-
 AttributeSettingsDialog::AttributeSettingsDialog( QWidget* parent ) : QDialog( parent )
 {
     setWindowTitle( tr( "Attribute Settings" ) );
