@@ -19,9 +19,6 @@ class QToolButton;
 class QListWidget;
 class QDialogButtonBox;
 
-namespace WebIssues
-{
-
 /**
 * Dialog for modifying attribute settings.
 */
@@ -83,6 +80,4 @@ private:
     QDialogButtonBox* m_buttonBox;
 };
 
-}
-
 #endif
