@@ -18,10 +18,6 @@
 #include <QDialogButtonBox>
 #include <QAccessible>
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::CheckMessageBox */
-
 CheckMessageBox::CheckMessageBox( QWidget* parent ) : QDialog( parent ),
     m_icon( QMessageBox::NoIcon )
 {
