@@ -19,9 +19,6 @@ class QLabel;
 class QCheckBox;
 class QDialogButtonBox;
 
-namespace WebIssues
-{
-
 /**
 * Message box with a checkbox.
 */
@@ -105,6 +102,4 @@ private:
     QMessageBox::Icon m_icon;
 };
 
-}
-
 #endif
