@@ -26,10 +26,6 @@
 #include "widgets/gradientwidget.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::ColumnSettingsDialog */
-
 ColumnSettingsDialog::ColumnSettingsDialog( QWidget* parent ) : QDialog( parent )
 {
     setWindowTitle( tr( "Column Settings" ) );
@@ -152,27 +148,27 @@ void ColumnSettingsDialog::setPrompt( const QString& text )
     m_promptLabel->setFixedHeight( m_promptLabel->heightForWidth( m_promptLabel->minimumWidth() ) );
 }
 
-void ColumnSettingsDialog::setAvailableColumns( const QList<Column>& columns )
+void ColumnSettingsDialog::setAvailableColumns( const QList<int>& columns )
 {
     m_availableColumns = columns;
 }
 
-void ColumnSettingsDialog::setDefaultColumns( const QList<Column>& columns )
+void ColumnSettingsDialog::setDefaultColumns( const QList<int>& columns )
 {
     m_defaultColumns = columns;
 }
 
-void ColumnSettingsDialog::setFixedColumns( const QList<Column>& columns )
+void ColumnSettingsDialog::setFixedColumns( const QList<int>& columns )
 {
     m_fixedColumns = columns;
 }
 
-void ColumnSettingsDialog::setColumns( const QList<Column>& columns )
+void ColumnSettingsDialog::setColumns( const QList<int>& columns )
 {
     m_availableList->clear();
 
     for ( int i = 0; i < m_availableColumns.count(); i++ ) {
-        Column column = m_availableColumns.at( i );
+        int column = m_availableColumns.at( i );
         if ( !columns.contains( column ) ) {
             QListWidgetItem* item = new QListWidgetItem( m_availableList );
             item->setText( TableModelsHelper::columnName( column ) );
@@ -186,7 +182,7 @@ void ColumnSettingsDialog::setColumns( const QList<Column>& columns )
     m_currentList->clear();
 
     for ( int i = 0; i < columns.count(); i++ ) {
-        Column column = columns.at( i );
+        int column = columns.at( i );
         QListWidgetItem* item = new QListWidgetItem( m_currentList );
         item->setText( TableModelsHelper::columnName( column ) );
         item->setData( Qt::DecorationRole, IconLoader::pixmap( "attribute" ) );
@@ -201,13 +197,13 @@ void ColumnSettingsDialog::setColumns( const QList<Column>& columns )
     m_downButton->setEnabled( false );
 }
 
-QList<Column> ColumnSettingsDialog::columns() const
+QList<int> ColumnSettingsDialog::columns() const
 {
-    QList<Column> columns;
+    QList<int> columns;
 
     for ( int i = 0; i < m_currentList->count(); i++ ) {
         QListWidgetItem* item = m_currentList->item( i );
-        Column column = (Column)item->data( Qt::UserRole ).toInt();
+        int column = item->data( Qt::UserRole ).toInt();
         columns.append( column );
     }
 
@@ -226,7 +222,7 @@ void ColumnSettingsDialog::currentSelected()
 {
     QListWidgetItem* item = m_currentList->currentItem();
     if ( item ) {
-        Column column = (Column)item->data( Qt::UserRole ).toInt();
+        int column = item->data( Qt::UserRole ).toInt();
         int row = m_currentList->row( item );
 
         if ( !m_fixedColumns.contains( column ) )
@@ -274,7 +270,7 @@ void ColumnSettingsDialog::removeClicked()
 {
     QListWidgetItem* item = m_currentList->currentItem();
 
-    Column column = (Column)item->data( Qt::UserRole ).toInt();
+    int column = item->data( Qt::UserRole ).toInt();
 
     if ( m_fixedColumns.contains( column ) )
         return;
