@@ -14,16 +14,11 @@
 
 #include <QDialog>
 
-#include "models/abstracttablemodel.h"
-
 class QLabel;
 class QToolButton;
 class QListWidget;
 class QDialogButtonBox;
 
-namespace WebIssues
-{
-
 /**
 * Dialog for modifying column settings for a list.
 */
@@ -52,29 +47,29 @@ public:
     /**
     * Set a list of all available columns.
     */
-    void setAvailableColumns( const QList<Column>& columns );
+    void setAvailableColumns( const QList<int>& columns );
 
     /**
     * Set the default list of columns.
     */
-    void setDefaultColumns( const QList<Column>& columns );
+    void setDefaultColumns( const QList<int>& columns );
 
     /**
     * Set the list of fixed columns.
     *
     * Fixed columns cannot be removed from the list.
     */
-    void setFixedColumns( const QList<Column>& columns );
+    void setFixedColumns( const QList<int>& columns );
 
     /**
     * Initialize the dialog with a list of columns.
     */
-    void setColumns( const QList<Column>& columns );
+    void setColumns( const QList<int>& columns );
 
     /**
     * Read the list of columns from the dialog.
     */
-    QList<Column> columns() const;
+    QList<int> columns() const;
 
 signals:
     /**
@@ -97,10 +92,10 @@ private slots:
     void downClicked();
 
 private:
-    QList<Column> m_availableColumns;
-    QList<Column> m_defaultColumns;
+    QList<int> m_availableColumns;
+    QList<int> m_defaultColumns;
 
-    QList<Column> m_fixedColumns;
+    QList<int> m_fixedColumns;
 
     QLabel* m_promptLabel;
 
@@ -115,6 +110,4 @@ private:
     QDialogButtonBox* m_buttonBox;
 };
 
-}
-
 #endif
