@@ -22,10 +22,6 @@
 #include "widgets/gradientwidget.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::CommandDialog */
-
 CommandDialog::CommandDialog( QWidget* parent ) : QDialog( parent ),
     m_promptPixmap( NULL ),
     m_contentLayout( NULL ),
@@ -209,7 +205,7 @@ void CommandDialog::batchCompleted( bool successful )
     m_batch = NULL;
 }
 
-bool CommandDialog::batchSuccessful( AbstractBatch* batch )
+bool CommandDialog::batchSuccessful( AbstractBatch* /*batch*/ )
 {
     return true;
 }
