@@ -20,9 +20,6 @@ class QProgressBar;
 class QDialogButtonBox;
 class QLayoutItem;
 
-namespace WebIssues
-{
-
 class AbstractBatch;
 
 /**
@@ -163,6 +160,4 @@ private:
     AbstractBatch* m_batch;
 };
 
-}
-
 #endif
