@@ -14,8 +14,7 @@
 
 #include <QDialog>
 
-namespace WebIssues
-{
+class QPushButton;
 
 class PropertyPanel;
 
@@ -38,13 +37,17 @@ public:
     */
     ~ConnectionInfoDialog();
 
+private slots:
+    void viewCertificates();
+
 private:
     void updateInformation();
 
 private:
-    PropertyPanel* m_panel;
+    PropertyPanel* m_serverPanel;
+    PropertyPanel* m_userPanel;
+
+    QPushButton* m_certificatesButton;
 };
 
-}
-
 #endif
