@@ -27,10 +27,6 @@
 #include "widgets/gradientwidget.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::FilterDialog */
-
 FilterDialog::FilterDialog( int projectId, QWidget* parent ) : QDialog( parent ),
     m_projectId( projectId ),
     m_filterMode( false )
@@ -139,17 +135,17 @@ void FilterDialog::setPrompt( const QString& text )
     m_promptLabel->setFixedHeight( m_promptLabel->heightForWidth( m_promptLabel->minimumWidth() ) );
 }
 
-void FilterDialog::setAvailableColumns( const QList<Column>& columns )
+void FilterDialog::setAvailableColumns( const QList<int>& columns )
 {
-    QMap<QString, Column> map;
+    QMap<QString, int> map;
     for ( int i = 0; i < columns.count(); i++ ) {
-        Column column = columns.at( i );
+        int column = columns.at( i );
         map.insert( TableModelsHelper::columnName( column ).toLower(), column );
     }
 
     m_columns.clear();
 
-    for ( QMap<QString, Column>::iterator it = map.begin(); it != map.end(); ++it )
+    for ( QMap<QString, int>::iterator it = map.begin(); it != map.end(); ++it )
         m_columns.append( it.value() );
 }
 
@@ -225,7 +221,7 @@ void FilterDialog::accept()
 void FilterDialog::addRow()
 {
     ColumnCondition condition;
-    condition.setColumn( (Column)-1 );
+    condition.setColumn( -1 );
     condition.setCondition( (ColumnCondition::Condition)-1 );
 
     createRow( condition );
@@ -326,7 +322,7 @@ void FilterDialog::createRow( const ColumnCondition& condition )
     m_rows.append( row );
 }
 
-void FilterDialog::selectColumn( FilterRow& row, Column column )
+void FilterDialog::selectColumn( FilterRow& row, int column )
 {
     int item = -1;
     for ( int i = 0; i < m_columns.count(); i++ ) {
