@@ -24,9 +24,6 @@ class QGridLayout;
 class QPushButton;
 class QDialogButtonBox;
 
-namespace WebIssues
-{
-
 class AbstractValueEditor;
 
 /**
@@ -59,7 +56,7 @@ public:
     /**
     * Set a list of available columns for filtering.
     */
-    void setAvailableColumns( const QList<Column>& columns );
+    void setAvailableColumns( const QList<int>& columns );
 
     /**
     * Initialize the dialog with a list of conditions.
@@ -141,7 +138,7 @@ private:
 
     void createRow( const ColumnCondition& condition );
 
-    void selectColumn( FilterRow& row, Column column );
+    void selectColumn( FilterRow& row, int column );
     void selectCondition( FilterRow& row, int index, ColumnCondition::Condition condition );
 
 private:
@@ -164,11 +161,9 @@ private:
 
     QDialogButtonBox* m_buttonBox;
 
-    QList<Column> m_columns;
+    QList<int> m_columns;
 
     QList<FilterRow> m_rows;
 };
 
-}
-
 #endif
