@@ -19,10 +19,6 @@
 #include "data/finditembatch.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::FindItemDialog */
-
 FindItemDialog::FindItemDialog( QWidget* parent ) : CommandDialog( parent ),
     m_itemId( 0 ),
     m_issueId( 0 )
