@@ -16,9 +16,6 @@
 
 class QSpinBox;
 
-namespace WebIssues
-{
-
 class FindItemBatch;
 
 /**
@@ -71,6 +68,4 @@ private:
     int m_issueId;
 };
 
-}
-
 #endif
