@@ -21,14 +21,11 @@
 #include "attributes/abstractvalueeditor.h"
 #include "attributes/valueeditorfactory.h"
 #include "attributes/definitionparser.h"
-#include "data/rdb/tableiterators.h"
 #include "data/datamanager.h"
 #include "data/issuebatch.h"
 #include "models/tablemodelshelper.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
 IssueDialog::IssueDialog( QWidget* parent ) : CommandDialog( parent )
 {
 }
@@ -37,8 +34,6 @@ IssueDialog::~IssueDialog()
 {
 }
 
-/* TRANSLATOR WebIssues::AddIssueDialog */
-
 AddIssueDialog::AddIssueDialog( int folderId, QWidget* parent ) : IssueDialog( parent ),
     m_folderId( folderId )
 {
@@ -91,8 +86,6 @@ bool AddIssueDialog::batchSuccessful( AbstractBatch* batch )
     return true;
 }
 
-/* TRANSLATOR WebIssues::RenameIssueDialog */
-
 RenameIssueDialog::RenameIssueDialog( int issueId, QWidget* parent ) : IssueDialog( parent ),
     m_issueId( issueId )
 {
@@ -144,8 +137,6 @@ void RenameIssueDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::SetValueDialog */
-
 SetValueDialog::SetValueDialog( int issueId, int attributeId, QWidget* parent ) : IssueDialog( parent ),
     m_issueId( issueId ),
     m_attributeId( attributeId )
@@ -235,8 +226,6 @@ void SetValueDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::AddAttachmentDialog */
-
 AddAttachmentDialog::AddAttachmentDialog( int issueId, const QString& path, const QString& url, QWidget* parent ) :
     IssueDialog( parent ),
     m_issueId( issueId ),
@@ -320,8 +309,6 @@ bool AddAttachmentDialog::batchSuccessful( AbstractBatch* batch )
     return true;
 }
 
-/* TRANSLATOR WebIssues::GetAttachmentDialog */
-
 GetAttachmentDialog::GetAttachmentDialog( int attachmentId, const QString& path, const QString& url, QWidget* parent ) :
     IssueDialog( parent ),
     m_attachmentId( attachmentId ),
