@@ -17,9 +17,6 @@
 class QButtonGroup;
 class QLineEdit;
 
-namespace WebIssues
-{
-
 class AbstractValueEditor;
 
 /**
@@ -64,6 +61,9 @@ public:
     ~AddIssueDialog();
 
 public:
+    /**
+    * Return the identifier of the created issue.
+    */
     int issueId() const { return m_issueId; }
 
 public: // overrides
@@ -237,6 +237,4 @@ private:
     int m_size;
 };
 
-}
-
 #endif
