@@ -26,15 +26,20 @@
 #include "configdata.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::LoginDialog */
+#if defined( HAVE_OPENSSL )
+#include "dialogs/sslerrorsdialog.h"
+#endif
 
 LoginDialog::LoginDialog( QWidget* parent ) : CommandDialog( parent ),
     m_successful( false )
 {
     connectionManager->createCommandManager();
 
+#if defined( HAVE_OPENSSL )
+    connect( commandManager, SIGNAL( sslErrors( const QList<QSslError>& ) ),
+        this, SLOT( sslErrors( const QList<QSslError>& ) ) );
+#endif
+
     setWindowTitle( tr( "Login" ) );
     setPrompt( tr( "Enter server address and login information:" ) );
     setPromptPixmap( IconLoader::pixmap( "connection-open", 22 ) );
@@ -148,3 +153,17 @@ bool LoginDialog::batchSuccessful( AbstractBatch* batch )
 
     return true;
 }
+
+#if defined( HAVE_OPENSSL )
+
+void LoginDialog::sslErrors( const QList<QSslError>& errors )
+{
+    SslErrorsDialog dialog( this );
+    dialog.setErrors( errors );
+    dialog.setCertificates( commandManager->certificateChain() );
+
+    if ( dialog.exec() == QDialog::Accepted )
+        commandManager->ignoreSslErrors();
+}
+
+#endif // defined( HAVE_OPENSSL )
