@@ -17,8 +17,9 @@
 class QCheckBox;
 class QLineEdit;
 
-namespace WebIssues
-{
+#if defined( HAVE_OPENSSL )
+class QSslError;
+#endif
 
 class Bookmark;
 
@@ -57,6 +58,11 @@ protected: // overrides
 
     bool batchSuccessful( AbstractBatch* batch );
 
+private slots:
+#if defined( HAVE_OPENSSL )
+    void sslErrors( const QList<QSslError>& errors );
+#endif
+
 private:
     QLineEdit* m_urlEdit;
     QLineEdit* m_loginEdit;
@@ -67,6 +73,4 @@ private:
     bool m_successful;
 };
 
-}
-
 #endif
