@@ -20,9 +20,6 @@ class QListWidgetItem;
 class QDialogButtonBox;
 class QMenu;
 
-namespace WebIssues
-{
-
 class ColumnConditionSettings;
 
 /**
@@ -70,6 +67,4 @@ private:
     QMenu* m_menu;
 };
 
-}
-
 #endif
