@@ -16,16 +16,11 @@
 #include <QLineEdit>
 #include <QComboBox>
 
-#include "data/rdb/tableiterators.h"
 #include "data/datamanager.h"
 #include "data/projectsbatch.h"
-#include "data/rowhelpers.h"
+#include "rdb/utilities.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::ProjectsDialog */
-
 ProjectsDialog::ProjectsDialog( QWidget* parent ) : CommandDialog( parent )
 {
 }
@@ -41,7 +36,7 @@ bool ProjectsDialog::checkProjectName( const QString& name )
         return false;
     }
 
-    RDB::TableConstIterator<ProjectRow> it( dataManager->projects() );
+    RDB::IndexConstIterator<ProjectRow> it( dataManager->projects()->index() );
     while ( it.next() ) {
         if ( it.get()->name() == name ) {
             showWarning( tr( "A project with this name already exists" ) );
@@ -70,8 +65,6 @@ bool ProjectsDialog::checkFolderName( int projectId, const QString& name )
     return true;
 }
 
-/* TRANSLATOR WebIssues::AddProjectDialog */
-
 AddProjectDialog::AddProjectDialog( QWidget* parent ) : ProjectsDialog( parent )
 {
     setWindowTitle( tr( "Add Project" ) );
@@ -112,8 +105,6 @@ void AddProjectDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::RenameProjectDialog */
-
 RenameProjectDialog::RenameProjectDialog( int projectId, QWidget* parent ) : ProjectsDialog( parent ),
     m_projectId( projectId )
 {
@@ -163,8 +154,6 @@ void RenameProjectDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::DeleteProjectDialog */
-
 DeleteProjectDialog::DeleteProjectDialog( int projectId, QWidget* parent ) : ProjectsDialog( parent ),
     m_projectId( projectId )
 {
@@ -192,8 +181,6 @@ void DeleteProjectDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::AddFolderDialog */
-
 AddFolderDialog::AddFolderDialog( int projectId, QWidget* parent ) : ProjectsDialog( parent ),
     m_projectId( projectId )
 {
@@ -223,7 +210,7 @@ AddFolderDialog::AddFolderDialog( int projectId, QWidget* parent ) : ProjectsDia
 
     typeLabel->setBuddy( m_typeCombo );
 
-    RDB::TableConstIterator<TypeRow> it( dataManager->types() );
+    RDB::IndexConstIterator<TypeRow> it( dataManager->types()->index() );
     QList<const TypeRow*> types = localeAwareSortRows( it, &TypeRow::name );
 
     for ( int i = 0; i < types.count(); i++ )
@@ -249,7 +236,7 @@ void AddFolderDialog::accept()
     QString type = m_typeCombo->currentText();
     int typeId = 0;
 
-    RDB::TableConstIterator<TypeRow> it( dataManager->types() );
+    RDB::IndexConstIterator<TypeRow> it( dataManager->types()->index() );
     while ( it.next() ) {
         if ( it.get()->name() == type ) {
             typeId = it.get()->typeId();
@@ -263,8 +250,6 @@ void AddFolderDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::RenameFolderDialog */
-
 RenameFolderDialog::RenameFolderDialog( int folderId, QWidget* parent ) : ProjectsDialog( parent ),
     m_folderId( folderId )
 {
@@ -317,8 +302,6 @@ void RenameFolderDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::DeleteFolderDialog */
-
 DeleteFolderDialog::DeleteFolderDialog( int folderId, QWidget* parent ) : ProjectsDialog( parent ),
     m_folderId( folderId )
 {
