@@ -17,9 +17,6 @@
 class QLineEdit;
 class QComboBox;
 
-namespace WebIssues
-{
-
 /**
 * Base class for dialogs for executing commands related to projects.
 */
@@ -242,6 +239,4 @@ private:
     int m_folderId;
 };
 
-}
-
 #endif
