@@ -27,10 +27,6 @@
 #include "connectionmanager.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::SettingsDialog */
-
 SettingsDialog::SettingsDialog( QWidget* parent ) : QDialog( parent )
 {
     setWindowTitle( tr( "Settings" ) );
