@@ -23,11 +23,10 @@
 #include "data/bookmark.h"
 #include "application.h"
 #include "iconloader.h"
-#include "dotnetstyle.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::StartPage */
+#if defined( Q_WS_WIN )
+#include "windowsmodernstyle.h"
+#endif
 
 StartPage::StartPage( QWidget* parent ) : QWidget( parent )
 {
@@ -36,10 +35,14 @@ StartPage::StartPage( QWidget* parent ) : QWidget( parent )
     topLayout->setSpacing( 0 );
 
     QWidget* headerWidget = new QWidget( this );
-#if defined( WI_NO_STYLE_DOTNET )
-    headerWidget->setPalette( QPalette( QColor( 255, 255, 255 ) ) );
-    headerWidget->setAutoFillBackground( true );
+#if defined( Q_WS_WIN ) && !defined( NO_STYLE_WINDOWSMODERN )
+    if ( !qobject_cast<WindowsModernStyle*>( style() ) ) {
+#else
+    if ( true ) {
 #endif
+        headerWidget->setPalette( QPalette( QColor( 255, 255, 255 ) ) );
+        headerWidget->setAutoFillBackground( true );
+    }
     topLayout->addWidget( headerWidget );
 
     QHBoxLayout* headerLayout = new QHBoxLayout( headerWidget );
@@ -74,8 +77,8 @@ StartPage::StartPage( QWidget* parent ) : QWidget( parent )
     QString manualUrl = ( (Application*)qApp )->manualIndex().toString();
 
     QString links;
-    links += "<a style=\"text-decoration: none\" href=\"http://webissues.mimec.org/\">webissues.mimec.org</a>";
-    links += " &middot; ";
+    links += QLatin1String( "<a style=\"text-decoration: none\" href=\"http://webissues.mimec.org/\">webissues.mimec.org</a>" );
+    links += QLatin1String( " &middot; " );
     links += QString( "<a style=\"text-decoration: none\" href=\"%1\">%2</a>" ).arg( manualUrl, tr( "Manual" ) );
 
     QLabel* linksLabel = new QLabel( links, headerWidget );
@@ -144,6 +147,8 @@ StartPage::StartPage( QWidget* parent ) : QWidget( parent )
     m_menu->addAction( actionRemove );
 
     populateList();
+
+    setFocusProxy( m_list );
 }
 
 StartPage::~StartPage()
