@@ -22,9 +22,6 @@ class QListWidgetItem;
 class QPushButton;
 class QMenu;
 
-namespace WebIssues
-{
-
 /**
 * Page displayed in the main window in disconnected state.
 */
@@ -93,6 +90,4 @@ private:
     QMenu* m_menu;
 };
 
-}
-
 #endif
