@@ -28,16 +28,11 @@
 #include "attributes/definitionparser.h"
 #include "attributes/metadatadialogbase.h"
 #include "attributes/metadatadialogfactory.h"
-#include "data/rdb/tableiterators.h"
 #include "data/datamanager.h"
 #include "data/typesbatch.h"
 #include "widgets/popeditbox.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::TypesDialog */
-
 TypesDialog::TypesDialog( QWidget* parent ) : CommandDialog( parent )
 {
 }
@@ -53,7 +48,7 @@ bool TypesDialog::checkTypeName( const QString& name )
         return false;
     }
 
-    RDB::TableConstIterator<TypeRow> it( dataManager->types() );
+    RDB::IndexConstIterator<TypeRow> it( dataManager->types()->index() );
     while ( it.next() ) {
         if ( it.get()->name() == name ) {
             showWarning( tr( "A type with this name already exists" ) );
@@ -82,8 +77,6 @@ bool TypesDialog::checkAttributeName( int typeId, const QString& name )
     return true;
 }
 
-/* TRANSLATOR WebIssues::AddTypeDialog */
-
 AddTypeDialog::AddTypeDialog( QWidget* parent ) : TypesDialog( parent )
 {
     setWindowTitle( tr( "Add Type" ) );
@@ -124,8 +117,6 @@ void AddTypeDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::RenameTypeDialog */
-
 RenameTypeDialog::RenameTypeDialog( int typeId, QWidget* parent ) : TypesDialog( parent ),
     m_typeId( typeId )
 {
@@ -175,8 +166,6 @@ void RenameTypeDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::DeleteTypeDialog */
-
 DeleteTypeDialog::DeleteTypeDialog( int typeId, QWidget* parent ) : TypesDialog( parent ),
     m_typeId( typeId )
 {
@@ -204,8 +193,6 @@ void DeleteTypeDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::AttributeDialog */
-
 AttributeDialog::AttributeDialog( QWidget* parent ) : TypesDialog( parent ),
     m_nameEdit( NULL ),
     m_typeCombo( NULL ),
@@ -406,8 +393,6 @@ void AttributeDialog::updateMetadata()
     m_editor->widget()->show();
 }
 
-/* TRANSLATOR WebIssues::AddAttributeDialog */
-
 AddAttributeDialog::AddAttributeDialog( int typeId, QWidget* parent ) : AttributeDialog( parent ),
     m_typeId( typeId )
 {
@@ -444,8 +429,6 @@ void AddAttributeDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::ModifyAttributeDialog */
-
 ModifyAttributeDialog::ModifyAttributeDialog( int attributeId, QWidget* parent ) : AttributeDialog( parent ),
     m_attributeId( attributeId )
 {
@@ -484,8 +467,6 @@ void ModifyAttributeDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::RenameAttributeDialog */
-
 RenameAttributeDialog::RenameAttributeDialog( int attributeId, QWidget* parent ) : TypesDialog( parent ),
     m_attributeId( attributeId )
 {
@@ -538,8 +519,6 @@ void RenameAttributeDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::DeleteAttributeDialog */
-
 DeleteAttributeDialog::DeleteAttributeDialog( int attributeId, QWidget* parent ) : TypesDialog( parent ),
     m_attributeId( attributeId )
 {
