@@ -21,9 +21,6 @@ class QRadioButton;
 class QButtonGroup;
 class QComboBox;
 
-namespace WebIssues
-{
-
 class AbstractValueEditor;
 class PopEditBox;
 
@@ -341,6 +338,4 @@ private:
     int m_attributeId;
 };
 
-}
-
 #endif
