@@ -18,18 +18,13 @@
 #include <QLineEdit>
 #include <QListWidget>
 
-#include "data/rdb/tableiterators.h"
 #include "data/datamanager.h"
 #include "data/usersbatch.h"
-#include "data/rowhelpers.h"
 #include "data/connectioninfo.h"
+#include "rdb/utilities.h"
 #include "connectionmanager.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::UsersDialog */
-
 UsersDialog::UsersDialog( QWidget* parent ) : CommandDialog( parent )
 {
 }
@@ -45,7 +40,7 @@ bool UsersDialog::checkUserLogin( const QString& login )
         return false;
     }
 
-    RDB::TableConstIterator<UserRow> it( dataManager->users() );
+    RDB::IndexConstIterator<UserRow> it( dataManager->users()->index() );
     while ( it.next() ) {
         if ( it.get()->login() == login ) {
             showWarning( tr( "A user with this login already exists" ) );
@@ -63,7 +58,7 @@ bool UsersDialog::checkUserName( const QString& name )
         return false;
     }
 
-    RDB::TableConstIterator<UserRow> it( dataManager->users() );
+    RDB::IndexConstIterator<UserRow> it( dataManager->users()->index() );
     while ( it.next() ) {
         if ( it.get()->name() == name ) {
             showWarning( tr( "A user with this name already exists" ) );
@@ -89,8 +84,6 @@ bool UsersDialog::checkPassword( const QString& password, const QString& passwor
     return true;
 }
 
-/* TRANSLATOR WebIssues::AddUserDialog */
-
 AddUserDialog::AddUserDialog( QWidget* parent ) : UsersDialog( parent )
 {
     setWindowTitle( tr( "Add User" ) );
@@ -172,8 +165,6 @@ void AddUserDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::SetPasswordDialog */
-
 SetPasswordDialog::SetPasswordDialog( int userId, QWidget* parent ) : UsersDialog( parent ),
     m_userId( userId )
 {
@@ -232,8 +223,6 @@ void SetPasswordDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::ChangeUserAccessDialog */
-
 ChangeUserAccessDialog::ChangeUserAccessDialog( int userId, QWidget* parent ) : UsersDialog( parent ),
     m_userId( userId )
 {
@@ -295,8 +284,6 @@ void ChangeUserAccessDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::RenameUserDialog */
-
 RenameUserDialog::RenameUserDialog( int userId, QWidget* parent ) : UsersDialog( parent ),
     m_userId( userId )
 {
@@ -346,8 +333,6 @@ void RenameUserDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::AddMemberDialog */
-
 AddMemberDialog::AddMemberDialog( int projectId, QWidget* parent ) : UsersDialog( parent ),
     m_projectId( projectId )
 {
@@ -368,7 +353,7 @@ AddMemberDialog::AddMemberDialog( int projectId, QWidget* parent ) : UsersDialog
 
     userLabel->setBuddy( m_list );
 
-    RDB::TableConstIterator<UserRow> it( dataManager->users() );
+    RDB::IndexConstIterator<UserRow> it( dataManager->users()->index() );
     QList<const UserRow*> users = localeAwareSortRows( it, &UserRow::name );
 
     for ( int i = 0; i < users.count(); i++ ) {
@@ -438,8 +423,6 @@ void AddMemberDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::ChangeMemberAccessDialog */
-
 ChangeMemberAccessDialog::ChangeMemberAccessDialog( const QList<int>& users, int projectId, QWidget* parent ) :
     UsersDialog( parent ),
     m_users( users ),
@@ -520,8 +503,6 @@ void ChangeMemberAccessDialog::accept()
     executeBatch( batch );
 }
 
-/* TRANSLATOR WebIssues::RemoveMemberDialog */
-
 RemoveMemberDialog::RemoveMemberDialog( const QList<int>& users, int projectId, QWidget* parent ) : UsersDialog( parent ),
     m_users( users ),
     m_projectId( projectId )
