@@ -18,9 +18,6 @@ class QLineEdit;
 class QButtonGroup;
 class QListWidget;
 
-namespace WebIssues
-{
-
 /**
 * Base class for dialogs for executing commands related to users.
 */
@@ -303,6 +300,4 @@ private:
     int m_projectId;
 };
 
-}
-
 #endif
