@@ -18,9 +18,6 @@ class QLabel;
 class QListWidget;
 class QDialogButtonBox;
 
-namespace WebIssues
-{
-
 class ColumnConditionSettings;
 
 /**
@@ -63,6 +60,4 @@ private:
     ColumnConditionSettings* m_settings;
 };
 
-}
-
 #endif
