@@ -15,9 +15,6 @@
 #include <QPixmap>
 #include <QIcon>
 
-namespace WebIssues
-{
-
 /**
 * Class for loading icons and pixmaps.
 *
@@ -56,6 +53,4 @@ public:
     static QIcon icon( const QString& name );
 };
 
-}
-
 #endif
