@@ -18,6 +18,8 @@
 #include <QTabWidget>
 #include <QFileDialog>
 #include <QMessageBox>
+#include <QToolBar>
+#include <QLayout>
 
 #include "data/datamanager.h"
 #include "data/connectioninfo.h"
@@ -38,9 +40,9 @@
 #include "connectionmanager.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::MainWindow */
+#if defined( HAVE_OPENSSL )
+#include "dialogs/sslerrorsdialog.h"
+#endif
 
 #if defined( Q_WS_WIN )
 static const int TrayIconSize = 16;
@@ -109,12 +111,14 @@ MainWindow::MainWindow() :
     setTitle( "menuHelp", tr( "&Help" ) );
     setTitle( "toolbarMain", tr( "Main Toolbar" ) );
 
-    loadXmlFile( ":/resources/mainwindow.xml" );
+    loadXmlUiFile( ":/resources/mainwindow.xml" );
 
     m_builder = new XmlUi::Builder( this );
+    connect( m_builder, SIGNAL( toolBarCreated( QToolBar* ) ), this, SLOT( toolBarCreated( QToolBar* ) ) );
+
     m_builder->addClient( this );
 
-    setStatusBar( new WebIssues::StatusBar( this ) );
+    setStatusBar( new ::StatusBar( this ) );
 
     qRegisterMetaType<Bookmark>( "Bookmark" );
 
@@ -214,7 +218,12 @@ void MainWindow::closeConnection()
 
 void MainWindow::initializeView()
 {
-    m_tabWidget = new QTabWidget( this );
+    QWidget* widget = new QWidget( this );
+    m_tabWidget = new QTabWidget( widget );
+
+    QVBoxLayout* layout = new QVBoxLayout( widget );
+    layout->setContentsMargins( 0, 1, 0, 0 );
+    layout->addWidget( m_tabWidget );
 
     connect( m_tabWidget, SIGNAL( currentChanged( int ) ), this, SLOT( tabChanged( int ) ) );
 
@@ -238,8 +247,8 @@ void MainWindow::initializeView()
     m_tabWidget->addTab( m_view->mainWidget(), IconLoader::icon( "project" ), tr( "Projects" ) );
     m_tabWidget->addTab( m_dashboard->mainWidget(), IconLoader::icon( "view-dashboard" ), tr( "Dashboard" ) );
 
-    setCentralWidget( m_tabWidget );
-    m_tabWidget->show();
+    setCentralWidget( widget );
+    widget->show();
 
     action( "newConnection" )->setVisible( false );
     action( "closeConnection" )->setVisible( true );
@@ -300,11 +309,14 @@ void MainWindow::showStartPage()
 
     setCentralWidget( m_startPage );
     m_startPage->show();
+
+    m_startPage->setFocus();
 }
 
 void MainWindow::tabChanged( int index )
 {
-    m_view->setPageActive( index == 0 );
+    if ( m_tabWidget->count() == 2 )
+        m_view->setPageActive( index == 0 );
 }
 
 void MainWindow::configure()
@@ -327,11 +339,17 @@ void MainWindow::openConnection( const Bookmark& bookmark )
 
     m_bookmark = bookmark;
 
+    connectionManager->createCommandManager();
+
+#if defined( HAVE_OPENSSL )
+    connect( commandManager, SIGNAL( sslErrors( const QList<QSslError>& ) ),
+        this, SLOT( sslErrors( const QList<QSslError>& ) ) );
+#endif
+
     m_batch = new LoginBatch( bookmark.login(), bookmark.password() );
 
     connect( m_batch, SIGNAL( completed( bool ) ), this, SLOT( loginCompleted( bool ) ) );
 
-    connectionManager->createCommandManager();
     commandManager->setServerUrl( bookmark.url() ); 
     commandManager->execute( m_batch );
 
@@ -497,7 +515,26 @@ void MainWindow::captionChanged( const QString& caption )
     setWindowTitle( tr( "%1 - WebIssues" ).arg( caption ) );
 }
 
+void MainWindow::toolBarCreated( QToolBar* toolBar )
+{
+    toolBar->setIconSize( QSize( 22, 22 ) );
+}
+
 void MainWindow::builderReset()
 {
     m_trayIcon->setContextMenu( m_builder->contextMenu( "contextTray" ) );
 }
+
+#if defined( HAVE_OPENSSL )
+
+void MainWindow::sslErrors( const QList<QSslError>& errors )
+{
+    SslErrorsDialog dialog( this );
+    dialog.setErrors( errors );
+    dialog.setCertificates( commandManager->certificateChain() );
+
+    if ( dialog.exec() == QDialog::Accepted )
+        commandManager->ignoreSslErrors();
+}
+
+#endif // defined( HAVE_OPENSSL )
