@@ -15,13 +15,14 @@
 #include <QMainWindow>
 #include <QSystemTrayIcon>
 
-class QTabWidget;
-
 #include "xmlui/client.h"
 #include "data/bookmark.h"
 
-namespace WebIssues
-{
+class QTabWidget;
+
+#if defined( HAVE_OPENSSL )
+class QSslError;
+#endif
 
 class StartPage;
 class ProjectsView;
@@ -92,8 +93,13 @@ private slots:
 
     void captionChanged( const QString& caption );
 
+    void toolBarCreated( QToolBar* toolBar );
     void builderReset();
 
+#if defined( HAVE_OPENSSL )
+    void sslErrors( const QList<QSslError>& errors );
+#endif
+
 private:
     void showLoginDialog( const Bookmark& bookmark, bool editable );
 
@@ -119,6 +125,4 @@ private:
     Bookmark m_bookmark;
 };
 
-}
-
 #endif
