@@ -16,9 +16,6 @@
 #include <QList>
 #include <QStringList>
 
-namespace WebIssues
-{
-
 class Bookmark;
 
 /**
@@ -81,6 +78,4 @@ private:
     QList<Bookmark> m_bookmarks;
 };
 
-}
-
 #endif
