@@ -18,10 +18,6 @@
 #include "tablemodelshelper.h"
 #include "connectionmanager.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::ColumnCondition */
-
 ColumnCondition::ColumnCondition()
 {
 }
@@ -230,5 +226,5 @@ QString ColumnCondition::name( Condition condition )
 
 QString ColumnCondition::tr( const char* text )
 {
-    return qApp->translate( "WebIssues::ColumnCondition", text );
+    return qApp->translate( "ColumnCondition", text );
 }
