@@ -14,11 +14,6 @@
 
 #include <QString>
 
-#include "abstracttablemodel.h"
-
-namespace WebIssues
-{
-
 /**
 * Structure representing a condition for a single column.
 *
@@ -77,12 +72,12 @@ public:
     /**
     * Set the column to filter.
     */
-    void setColumn( Column column ) { m_column = column; }
+    void setColumn( int column ) { m_column = column; }
 
     /**
     * Return the filtered column.
     */
-    Column column() const { return m_column; }
+    int column() const { return m_column; }
 
     /**
     * Set the type of the condition.
@@ -132,11 +127,9 @@ private:
     static QString tr( const char* text );
 
 private:
-    Column m_column;
+    int m_column;
     Condition m_condition;
     QString m_operand;
 };
 
-}
-
 #endif
