@@ -17,10 +17,9 @@
 #include "data/datamanager.h"
 #include "data/datarows.h"
 #include "filtervalueeditors.h"
+#include "tablemodels.h"
 
-using namespace WebIssues;
-
-DefinitionInfo ColumnConditionHelper::columnDefinition( Column column )
+DefinitionInfo ColumnConditionHelper::columnDefinition( int column )
 {
     if ( column > Column_UserDefined ) {
         int attributeId = column - Column_UserDefined;
@@ -106,6 +105,9 @@ QList<ColumnCondition::Condition> ColumnConditionHelper::availableConditions( co
             conditions.append( ColumnCondition::Check_IsMe );
             conditions.append( ColumnCondition::Check_IsNotMe );
             break;
+
+        default:
+            break;
     }
 
     if ( !info.required() ) {
@@ -151,6 +153,9 @@ AbstractValueEditor* ColumnConditionHelper::createValueEditor( const DefinitionI
         case ColumnCondition::Check_IsMe:
         case ColumnCondition::Check_IsNotMe:
             return NULL;
+
+        default:
+            break;
     }
 
     return ValueEditorFactory::createValueEditor( info, projectId, parent, parentWidget );
