@@ -19,9 +19,6 @@
 class QObject;
 class QWidget;
 
-namespace WebIssues
-{
-
 class DefinitionInfo;
 class AbstractValueEditor;
 
@@ -38,7 +35,7 @@ public:
     *
     * @return The attribute definition for a user column or a definition of a system column.
     */
-    static DefinitionInfo columnDefinition( Column column );
+    static DefinitionInfo columnDefinition( int column );
 
     /**
     * Get available conditions for a column.
@@ -68,6 +65,4 @@ public:
                                                    int projectId, QObject* parent, QWidget* parentWidget );
 };
 
-}
-
 #endif
