@@ -15,10 +15,7 @@
 
 #include "connectionmanager.h"
 #include "columncondition.h"
-
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::ColumnConditionSettings */
+#include "tablemodels.h"
 
 ColumnConditionSettings::ColumnConditionSettings()
 {
@@ -201,7 +198,7 @@ const QList<ColumnCondition> ColumnConditionSettings::deserializeConditions( con
     QStringList::const_iterator it = list.begin();
     while ( it != list.end() ) {
         ColumnCondition condition;
-        condition.setColumn( (Column)( *it++ ).toInt() );
+        condition.setColumn( ( *it++ ).toInt() );
         condition.setCondition( (ColumnCondition::Condition)( *it++ ).toInt() );
         if ( it != list.end() )
             condition.setOperand( *it++ );
