@@ -18,9 +18,6 @@
 
 class QSettings;
 
-namespace WebIssues
-{
-
 class ColumnCondition;
 
 /**
@@ -108,6 +105,4 @@ private:
     QStringList m_names;
 };
 
-}
-
 #endif
