@@ -13,10 +13,6 @@
 
 #include <QSpinBox>
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::AgeValueEditor */
-
 AgeValueEditor::AgeValueEditor( QObject* parent, QWidget* parentWidget ) :
     AbstractValueEditor( parent )
 {
