@@ -14,9 +14,6 @@
 
 #include "attributes/abstractvalueeditor.h"
 
-namespace WebIssues
-{
-
 /**
 * Editor delegate for the operand of the age filter conditions.
 */
@@ -43,6 +40,4 @@ public: // overrides
     QString value();
 };
 
-}
-
 #endif
