@@ -14,19 +14,15 @@
 #include <QtAlgorithms>
 
 #include "attributes/datetimehelper.h"
-#include "data/rdb/tableiterators.h"
 #include "data/datamanager.h"
 #include "data/datarows.h"
 #include "tablemodelshelper.h"
 #include "linklocator.h"
-#include "htmlhistorywriter.h"
-
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::IssueHistoryProvider */
+#include "issuehistorywriter.h"
 
 IssueHistoryProvider::IssueHistoryProvider() :
-    m_issueId( 0 )
+    m_issueId( 0 ),
+    m_writer( NULL )
 {
 }
 
@@ -65,8 +61,10 @@ void IssueHistoryProvider::extractIssueHistory( int issueId )
     }
 }
 
-void IssueHistoryProvider::write( HTMLHistoryWriter* writer )
+void IssueHistoryProvider::write( IssueHistoryWriter* writer )
 {
+    m_writer = writer;
+
     writer->begin();
 
     const IssueRow* issue = dataManager->issues()->find( m_issueId );
@@ -110,7 +108,7 @@ void IssueHistoryProvider::write( HTMLHistoryWriter* writer )
         const CommentRow* comment = dataManager->comments()->find( id );
         if ( comment != NULL ) {
             QString header = headerComment( id, comment->createdUser(), comment->createdDate() );
-            writer->writeComment( header, comment->text(), id );
+            writer->writeComment( header, writer->comment( comment->text() ), id );
             continue;
         }
 
@@ -131,16 +129,16 @@ void IssueHistoryProvider::write( HTMLHistoryWriter* writer )
 
 QString IssueHistoryProvider::headerCreated( int userId, const QDateTime& date )
 {
-    QString userArg = HTMLHistoryWriter::name( TableModelsHelper::userName( userId ) );
-    QString dateArg = HTMLHistoryWriter::date( DateTimeHelper::formatDateTime( date ) );
+    QString userArg = m_writer->name( TableModelsHelper::userName( userId ) );
+    QString dateArg = m_writer->date( DateTimeHelper::formatDateTime( date ) );
 
     return tr( "Created by %1 on %2" ).arg( userArg, dateArg );
 }
 
 QString IssueHistoryProvider::headerModified( int userId, const QDateTime& date )
 {
-    QString userArg = HTMLHistoryWriter::name( TableModelsHelper::userName( userId ) );
-    QString dateArg = HTMLHistoryWriter::date( DateTimeHelper::formatDateTime( date ) );
+    QString userArg = m_writer->name( TableModelsHelper::userName( userId ) );
+    QString dateArg = m_writer->date( DateTimeHelper::formatDateTime( date ) );
 
     return tr( "Modified by %1 on %2" ).arg( userArg, dateArg );
 }
@@ -148,8 +146,8 @@ QString IssueHistoryProvider::headerModified( int userId, const QDateTime& date
 QString IssueHistoryProvider::headerComment( int commentId, int userId, const QDateTime& date )
 {
     QString idArg = TableModelsHelper::formatId( commentId );
-    QString userArg = HTMLHistoryWriter::name( TableModelsHelper::userName( userId ) );
-    QString dateArg = HTMLHistoryWriter::date( DateTimeHelper::formatDateTime( date ) );
+    QString userArg = m_writer->name( TableModelsHelper::userName( userId ) );
+    QString dateArg = m_writer->date( DateTimeHelper::formatDateTime( date ) );
 
     return tr( "Comment %1 added by %2 on %3" ).arg( idArg, userArg, dateArg );
 }
@@ -157,28 +155,28 @@ QString IssueHistoryProvider::headerComment( int commentId, int userId, const QD
 QString IssueHistoryProvider::headerAttachment( int attachmentId, int userId, const QDateTime& date )
 {
     QString idArg = TableModelsHelper::formatId( attachmentId );
-    QString userArg = HTMLHistoryWriter::name( TableModelsHelper::userName( userId ) );
-    QString dateArg = HTMLHistoryWriter::date( DateTimeHelper::formatDateTime( date ) );
+    QString userArg = m_writer->name( TableModelsHelper::userName( userId ) );
+    QString dateArg = m_writer->date( DateTimeHelper::formatDateTime( date ) );
 
     return tr( "Attachment %1 added by %2 on %3" ).arg( idArg, userArg, dateArg );
 }
 
 QString IssueHistoryProvider::itemInitialName( const QString& name )
 {
-    QString nameArg = HTMLHistoryWriter::value( name );
+    QString nameArg = m_writer->value( name );
 
     return tr( "Item named \"%1\"" ).arg( nameArg );
 }
 
 QString IssueHistoryProvider::itemChange( int attributeId, const QString& oldValue, const QString& newValue )
 {
-    QString oldValueArg = HTMLHistoryWriter::value( oldValue );
-    QString newValueArg = HTMLHistoryWriter::value( newValue );
+    QString oldValueArg = m_writer->value( oldValue );
+    QString newValueArg = m_writer->value( newValue );
 
     if ( attributeId == 0 )
         return tr( "Issue renamed from \"%1\" to \"%2\"" ).arg( oldValueArg, newValueArg );
 
-    QString attributeArg = HTMLHistoryWriter::name( TableModelsHelper::attributeName( attributeId ) );
+    QString attributeArg = m_writer->name( TableModelsHelper::attributeName( attributeId ) );
 
     if ( oldValue.isEmpty() )
         return tr( "Attribute %1 changed from empty to \"%2\"" ).arg( attributeArg, newValueArg );
@@ -191,12 +189,12 @@ QString IssueHistoryProvider::itemChange( int attributeId, const QString& oldVal
 
 QString IssueHistoryProvider::itemAttachment( int attachmentId, const QString& name, int size, const QString& description )
 {
-    QString result = HTMLHistoryWriter::attachment( attachmentId, name );
+    QString result = m_writer->attachment( attachmentId, name );
 
     result += " (" + TableModelsHelper::formatSize( size ) + ')';
 
     if ( !description.isEmpty() )
-        result += " - " + HTMLHistoryWriter::description( description );
+        result += " - " + m_writer->description( description );
 
     return result;
 }
