@@ -17,18 +17,15 @@
 
 class QDateTime;
 
-namespace WebIssues
-{
-
-class HTMLHistoryWriter;
+class IssueHistoryWriter;
 
 /**
-* Class providing issue history to the HTMLHistoryWriter.
+* Class providing issue history to the IssueHistoryWriter.
 *
 * This class extracts the history of an issue, formats it into localized text
-* and outputs it to the HTMLHistoryWriter.
+* and outputs it to the IssueHistoryWriter.
 */
-class IssueHistoryProvider : QObject
+class IssueHistoryProvider : public QObject
 {
     Q_OBJECT
 public:
@@ -51,7 +48,7 @@ public:
     /**
     * Output the extracted history to the writer.
     */
-    void write( HTMLHistoryWriter* writer );
+    void write( IssueHistoryWriter* writer );
 
 private:
     QString headerCreated( int userId, const QDateTime& date );
@@ -69,8 +66,8 @@ private:
     QList<int> m_items;
 
     QString m_initialName;
+
+    IssueHistoryWriter* m_writer;
 };
 
-}
-
 #endif
