@@ -16,12 +16,9 @@
 
 #include "data/datamanager.h"
 #include "data/datarows.h"
-#include "data/rowhelpers.h"
-#include "data/rdb/tableiterators.h"
+#include "rdb/utilities.h"
 #include "connectionmanager.h"
 
-using namespace WebIssues;
-
 IssueViewSettings::IssueViewSettings() :
     m_typeId( 0 )
 {
