@@ -15,13 +15,8 @@
 #include <QObject>
 #include <QMap>
 
-#include "abstracttablemodel.h"
-
 class QSettings;
 
-namespace WebIssues
-{
-
 class DefinitionInfo;
 
 /**
@@ -65,6 +60,4 @@ private:
     int m_typeId;
 };
 
-}
-
 #endif
