@@ -14,8 +14,6 @@
 #include <QRegExp>
 #include <QCoreApplication>
 
-using namespace WebIssues;
-
 static QRegExp* linkExp = NULL;
 
 static void postRoutine()
@@ -64,8 +62,8 @@ QString LinkLocator::convertToHtml( const QString& text, int flags )
         QString link = linkExp->cap( 0 );
 
         QString href;
-        if ( link[ 0 ] == '#' )
-            href = "id://" + link.mid( 1 );
+        if ( link[ 0 ] == QLatin1Char( '#' ) )
+            href = ( ( flags & NoInternalLinks ) ? "#id" : "id://" ) + link.mid( 1 );
         else if ( linkExp->cap( 1 ).isEmpty() )
             href = "mailto:" + link;
         else if ( link.startsWith( "www." ) )
@@ -92,14 +90,14 @@ QString LinkLocator::escape( const QString& text )
     QString result;
     for ( int i = 0; i < text.length(); i++ ) {
         QChar ch = text[ i ];
-        if ( ch == '<' )
-            result += "&lt;";
-        else if ( ch == '>' )
-            result += "&gt;";
-        else if ( ch == '&' )
-            result += "&amp;";
-        else if ( ch == '"' )
-            result += "&quot;";
+        if ( ch == QLatin1Char( '<' ) )
+            result += QLatin1String( "&lt;" );
+        else if ( ch == QLatin1Char( '>' ) )
+            result += QLatin1String( "&gt;" );
+        else if ( ch == QLatin1Char( '&' ) )
+            result += QLatin1String( "&amp;" );
+        else if ( ch == QLatin1Char( '"' ) )
+            result += QLatin1String( "&quot;" );
         else
             result += ch;
     }
@@ -112,41 +110,41 @@ void LinkLocator::append( const QString& text )
         QChar ch = text[ i ];
 
         if ( m_flags & PreserveSpaces ) {
-            if ( ch == ' ' ) {
+            if ( ch == QLatin1Char( ' ' ) ) {
                 if ( m_space || m_column == 0 ) {
-                    m_result += "&nbsp;";
+                    m_result += QLatin1String( "&nbsp;" );
                     m_space = false;
                 } else {
-                    m_result += ' ';
+                    m_result += QLatin1Char( ' ' );
                     m_space = true;
                 }
                 m_column++;
                 continue;
             }
-            if ( ch == '\t' ) {
+            if ( ch == QLatin1Char( '\t' ) ) {
                 do {
-                    m_result += "&nbsp;";
+                    m_result += QLatin1String( "&nbsp;" );
                     m_column++;
                 } while ( ( m_column & 7 ) != 0 );
                 m_space = false;
                 continue;
             }
-            if ( ch == '\n' ) {
-                m_result += "<br>";
+            if ( ch == QLatin1Char( '\n' ) ) {
+                m_result += QLatin1String( "<br>" );
                 m_space = false;
                 m_column = 0;
                 continue;
             }
         }
 
-        if ( ch == '<' )
-            m_result += "&lt;";
-        else if ( ch == '>' )
-            m_result += "&gt;";
-        else if ( ch == '&' )
-            m_result += "&amp;";
-        else if ( ch == '"' )
-            m_result += "&quot;";
+        if ( ch == QLatin1Char( '<' ) )
+            m_result += QLatin1String( "&lt;" );
+        else if ( ch == QLatin1Char( '>' ) )
+            m_result += QLatin1String( "&gt;" );
+        else if ( ch == QLatin1Char( '&' ) )
+            m_result += QLatin1String( "&amp;" );
+        else if ( ch == QLatin1Char( '"' ) )
+            m_result += QLatin1String( "&quot;" );
         else
             m_result += ch;
 
