@@ -16,9 +16,6 @@
 
 class QRegExp;
 
-namespace WebIssues
-{
-
 /**
 * Text to HTML converter creating links for URLs and items.
 *
@@ -43,7 +40,11 @@ public:
         /**
         * Do not collapse whitespaces.
         */
-        PreserveSpaces = 1
+        PreserveSpaces = 1,
+        /**
+        * Use anchors instead of internal id:// links.
+        */
+        NoInternalLinks = 2
     };
 
 protected:
@@ -103,6 +104,4 @@ private:
     bool m_space;
 };
 
-}
-
 #endif
