@@ -14,10 +14,9 @@
 #include "attributes/datetimehelper.h"
 #include "data/datamanager.h"
 #include "data/datarows.h"
+#include "tablemodels.h"
 #include "tablemodelshelper.h"
 
-using namespace WebIssues;
-
 IssueRowFilter::IssueRowFilter( QObject* parent ) : AbstractRowFilter( parent ),
     m_searchColumn( Column_Name )
 {
@@ -34,7 +33,7 @@ void IssueRowFilter::setConditions( const QList<ColumnCondition>& conditions )
     emit conditionsChanged();
 } 
 
-void IssueRowFilter::setQuickSearch( Column column, const QString& text )
+void IssueRowFilter::setQuickSearch( int column, const QString& text )
 {
     m_searchColumn = column;
     m_searchText = text;
@@ -63,7 +62,7 @@ bool IssueRowFilter::filterRow( int id )
     return true;
 }
 
-QString IssueRowFilter::extractValue( const IssueRow* row, Column column )
+QString IssueRowFilter::extractValue( const IssueRow* row, int column )
 {
     if ( column > Column_UserDefined ) {
         int attributeId = column - Column_UserDefined;
