@@ -14,12 +14,9 @@
 
 #include <QList>
 
-#include "abstractrowfilter.h"
+#include "rdb/abstractrowfilter.h"
 #include "columncondition.h"
 
-namespace WebIssues
-{
-
 class IssueRow;
 
 /**
@@ -28,7 +25,7 @@ class IssueRow;
 * Issue rows can be filtered using a list of conditions for column values
 * and a quick search string. Either of them can be empty.
 */
-class IssueRowFilter : public AbstractRowFilter
+class IssueRowFilter : public RDB::AbstractRowFilter
 {
     Q_OBJECT
 public:
@@ -58,12 +55,12 @@ public:
     /**
     * Set the string to search in given column.
     */
-    void setQuickSearch( Column column, const QString& text );
+    void setQuickSearch( int column, const QString& text );
 
     /**
     * Return the quick search column.
     */
-    Column searchColumn() const { return m_searchColumn; }
+    int searchColumn() const { return m_searchColumn; }
 
     /**
     * Return the quick search text.
@@ -74,15 +71,13 @@ public: // overrides
     bool filterRow( int id );
 
 private:
-    QString extractValue( const IssueRow* row, Column column );
+    QString extractValue( const IssueRow* row, int column );
 
 private:
     QList<ColumnCondition> m_conditions;
 
-    Column m_searchColumn;
+    int m_searchColumn;
     QString m_searchText;
 };
 
-}
-
 #endif
