@@ -17,23 +17,44 @@
 #include "attributes/definitionparser.h"
 #include "attributes/definitionhelper.h"
 #include "attributes/datetimehelper.h"
-#include "data/rdb/tableiterators.h"
 #include "data/datamanager.h"
 #include "data/datarows.h"
-#include "data/rowhelpers.h"
 #include "data/updateevent.h"
 #include "data/connectioninfo.h"
+#include "rdb/utilities.h"
 #include "connectionmanager.h"
 #include "tablemodelshelper.h"
 #include "issueviewsettings.h"
 #include "linklocator.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
+BaseTableModel::BaseTableModel( QObject* parent ) : RDB::AbstractTableModel( parent )
+{
+    dataManager->addObserver( this );
+}
 
-/* TRANSLATOR WebIssues::UsersTableModel */
+BaseTableModel::~BaseTableModel()
+{
+    if ( dataManager )
+        dataManager->removeObserver( this );
+}
 
-UsersTableModel::UsersTableModel( QObject* parent ) : AbstractTableModel( parent )
+QString BaseTableModel::columnName( int column ) const
+{
+    return TableModelsHelper::columnName( column );
+}
+
+void BaseTableModel::updateEvent( UpdateEvent* /*e*/ )
+{
+}
+
+void BaseTableModel::customEvent( QEvent* e )
+{
+    if ( e->type() == UpdateEvent::Type )
+        updateEvent( (UpdateEvent*)e );
+}
+
+UsersTableModel::UsersTableModel( QObject* parent ) : BaseTableModel( parent )
 {
 }
 
@@ -41,7 +62,7 @@ UsersTableModel::~UsersTableModel()
 {
 }
 
-QString UsersTableModel::text( int id, Column column ) const
+QString UsersTableModel::text( int id, int column ) const
 {
     const UserRow* row = dataManager->users()->find( id );
     if ( !row )
@@ -63,8 +84,11 @@ QString UsersTableModel::text( int id, Column column ) const
     }
 }
 
-QPixmap UsersTableModel::icon( int id ) const
+QPixmap UsersTableModel::icon( int id, int column ) const
 {
+    if ( column != Column_Name )
+        return QPixmap();
+
     const UserRow* row = dataManager->users()->find( id );
     if ( row ) {
         if ( row->access() == AdminAccess )
@@ -78,12 +102,10 @@ QPixmap UsersTableModel::icon( int id ) const
 void UsersTableModel::updateEvent( UpdateEvent* e )
 {
     if ( e->unit() == UpdateEvent::Users )
-        emit tableChanged();
+        emit dataChanged();
 }
 
-/* TRANSLATOR WebIssues::MembersTableModel */
-
-MembersTableModel::MembersTableModel( int projectId, QObject* parent ) : AbstractTableModel( parent ),
+MembersTableModel::MembersTableModel( int projectId, QObject* parent ) : BaseTableModel( parent ),
     m_projectId( projectId )
 {
 }
@@ -92,7 +114,7 @@ MembersTableModel::~MembersTableModel()
 {
 }
 
-QString MembersTableModel::text( int id, Column column ) const
+QString MembersTableModel::text( int id, int column ) const
 {
     const MemberRow* row = dataManager->members()->find( id, m_projectId );
     if ( !row )
@@ -112,8 +134,11 @@ QString MembersTableModel::text( int id, Column column ) const
     }
 }
 
-QPixmap MembersTableModel::icon( int id ) const
+QPixmap MembersTableModel::icon( int id, int column ) const
 {
+    if ( column != Column_Name )
+        return QPixmap();
+
     const MemberRow* row = dataManager->members()->find( id, m_projectId );
     if ( row && row->access() == AdminAccess )
         return IconLoader::overlayedPixmap( "user", "overlay-admin" );
@@ -124,12 +149,10 @@ QPixmap MembersTableModel::icon( int id ) const
 void MembersTableModel::updateEvent( UpdateEvent* e )
 {
     if ( e->unit() == UpdateEvent::Users )
-        emit tableChanged();
+        emit dataChanged();
 }
 
-/* TRANSLATOR WebIssues::TypesTableModel */
-
-TypesTableModel::TypesTableModel( QObject* parent ) : AbstractTableModel( parent )
+TypesTableModel::TypesTableModel( QObject* parent ) : BaseTableModel( parent )
 {
 }
 
@@ -137,7 +160,7 @@ TypesTableModel::~TypesTableModel()
 {
 }
 
-QString TypesTableModel::text( int id, Column column ) const
+QString TypesTableModel::text( int id, int column ) const
 {
     const TypeRow* row = dataManager->types()->find( id );
     if ( !row )
@@ -151,20 +174,20 @@ QString TypesTableModel::text( int id, Column column ) const
     }
 }
 
-QPixmap TypesTableModel::icon( int id ) const
+QPixmap TypesTableModel::icon( int /*id*/, int column ) const
 {
+    if ( column != Column_Name )
+        return QPixmap();
     return IconLoader::pixmap( "type" );
 }
 
 void TypesTableModel::updateEvent( UpdateEvent* e )
 {
     if ( e->unit() == UpdateEvent::Types )
-        emit tableChanged();
+        emit dataChanged();
 }
 
-/* TRANSLATOR WebIssues::AttributesTableModel */
-
-AttributesTableModel::AttributesTableModel( QObject* parent ) : AbstractTableModel( parent )
+AttributesTableModel::AttributesTableModel( QObject* parent ) : BaseTableModel( parent )
 {
 }
 
@@ -172,7 +195,7 @@ AttributesTableModel::~AttributesTableModel()
 {
 }
 
-QString AttributesTableModel::text( int id, Column column ) const
+QString AttributesTableModel::text( int id, int column ) const
 {
     const AttributeRow* row = dataManager->attributes()->find( id );
     if ( !row )
@@ -198,18 +221,18 @@ QString AttributesTableModel::text( int id, Column column ) const
     }
 }
 
-QPixmap AttributesTableModel::icon( int id ) const
+QPixmap AttributesTableModel::icon( int /*id*/, int column ) const
 {
+    if ( column != Column_Name )
+        return QPixmap();
     return IconLoader::pixmap( "attribute" );
 }
 
-void AttributesTableModel::updateEvent( UpdateEvent* e )
+void AttributesTableModel::updateEvent( UpdateEvent* /*e*/ )
 {
 }
 
-/* TRANSLATOR WebIssues::ProjectsTableModel */
-
-ProjectsTableModel::ProjectsTableModel( QObject* parent ) : AbstractTableModel( parent )
+ProjectsTableModel::ProjectsTableModel( QObject* parent ) : BaseTableModel( parent )
 {
 }
 
@@ -217,7 +240,7 @@ ProjectsTableModel::~ProjectsTableModel()
 {
 }
 
-QString ProjectsTableModel::text( int id, Column column ) const
+QString ProjectsTableModel::text( int id, int column ) const
 {
     const ProjectRow* row = dataManager->projects()->find( id );
     if ( !row )
@@ -231,8 +254,11 @@ QString ProjectsTableModel::text( int id, Column column ) const
     }
 }
 
-QPixmap ProjectsTableModel::icon( int id ) const
+QPixmap ProjectsTableModel::icon( int id, int column ) const
 {
+    if ( column != Column_Name )
+        return QPixmap();
+
     if ( connectionManager->connectionInfo()->access() == AdminAccess )
         return IconLoader::overlayedPixmap( "project", "overlay-admin" );
 
@@ -247,14 +273,12 @@ QPixmap ProjectsTableModel::icon( int id ) const
 void ProjectsTableModel::updateEvent( UpdateEvent* e )
 {
     if ( e->unit() == UpdateEvent::Projects )
-        emit tableChanged();
+        emit dataChanged();
     if ( e->unit() == UpdateEvent::Types )
-        emit rowsChanged();
+        emit dataChanged();
 }
 
-/* TRANSLATOR WebIssues::FoldersTableModel */
-
-FoldersTableModel::FoldersTableModel( QObject* parent ) : AbstractTableModel( parent )
+FoldersTableModel::FoldersTableModel( QObject* parent ) : BaseTableModel( parent )
 {
 }
 
@@ -262,7 +286,7 @@ FoldersTableModel::~FoldersTableModel()
 {
 }
 
-QString FoldersTableModel::text( int id, Column column ) const
+QString FoldersTableModel::text( int id, int column ) const
 {
     const FolderRow* row = dataManager->folders()->find( id );
     if ( !row )
@@ -278,8 +302,11 @@ QString FoldersTableModel::text( int id, Column column ) const
     }
 }
 
-QPixmap FoldersTableModel::icon( int id ) const
+QPixmap FoldersTableModel::icon( int id, int column ) const
 {
+    if ( column != Column_Name )
+        return QPixmap();
+
     WatchState state = dataManager->folderWatchState( id );
     switch ( state ) {
         case WatchNormal:
@@ -296,12 +323,10 @@ QPixmap FoldersTableModel::icon( int id ) const
 void FoldersTableModel::updateEvent( UpdateEvent* e )
 {
     if ( e->unit() == UpdateEvent::Folder )
-        emit rowChanged( e->id() );
+        emit dataChanged();
 }
 
-/* TRANSLATOR WebIssues::IssuesTableModel */
-
-IssuesTableModel::IssuesTableModel( int folderId, QObject* parent ) : AbstractTableModel( parent ),
+IssuesTableModel::IssuesTableModel( int folderId, QObject* parent ) : BaseTableModel( parent ),
     m_folderId( folderId )
 {
 }
@@ -310,7 +335,7 @@ IssuesTableModel::~IssuesTableModel()
 {
 }
 
-QString IssuesTableModel::text( int id, Column column ) const
+QString IssuesTableModel::text( int id, int column ) const
 {
     const IssueRow* row = dataManager->issues()->find( id );
     if ( !row )
@@ -340,8 +365,11 @@ QString IssuesTableModel::text( int id, Column column ) const
     }
 }
 
-QPixmap IssuesTableModel::icon( int id ) const
+QPixmap IssuesTableModel::icon( int id, int column ) const
 {
+    if ( column != Column_Name )
+        return QPixmap();
+
     WatchState state = dataManager->issueWatchState( id );
     switch ( state ) {
         case WatchUpdated:
@@ -353,7 +381,7 @@ QPixmap IssuesTableModel::icon( int id ) const
     }
 }
 
-QString IssuesTableModel::toolTip( int id ) const
+QString IssuesTableModel::toolTip( int id, int /*column*/ ) const
 {
     const IssueRow* issue = dataManager->issues()->find( id );
     const FolderRow* folder = issue ? dataManager->folders()->find( issue->folderId() ) : NULL;
@@ -367,40 +395,40 @@ QString IssuesTableModel::toolTip( int id ) const
 
     QString tip = "<table cellspacing=\"3\" cellpadding=\"0\" width=\"400\">";
 
-    tip += "<tr><td><b>";
+    tip += QLatin1String( "<tr><td><b>" );
     tip += QString( "%1: %2" ).arg( TableModelsHelper::formatId( id ), LinkLocator::convertToHtml( issue->name(), 0 ) );
-    tip += "</b></td></tr>";
+    tip += QLatin1String( "</b></td></tr>" );
 
-    tip += "<tr><td>";
+    tip += QLatin1String( "<tr><td>" );
     tip += tr( "Created by %1 on %2" ).arg( TableModelsHelper::userName( issue->createdUser() ), DateTimeHelper::formatDateTime( issue->createdDate() ) );
-    tip += "</td></tr>";
+    tip += QLatin1String( "</td></tr>" );
 
     if ( issue->stamp() > id ) {
-        tip += "<tr><td>";
+        tip += QLatin1String( "<tr><td>" );
         tip += tr( "Modified by %1 on %2" ).arg( TableModelsHelper::userName( issue->modifiedUser() ), DateTimeHelper::formatDateTime( issue->modifiedDate() ) );
-        tip += "</td></tr>";
+        tip += QLatin1String( "</td></tr>" );
     }
 
-    tip += "</table><table cellspacing=\"3\" cellpadding=\"0\">";
+    tip += QLatin1String( "</table><table cellspacing=\"3\" cellpadding=\"0\">" );
 
     for ( int i = 0; i < attributes.count(); i++ ) {
         int attributeId = attributes.at( i );
         const ValueRow* value = dataManager->values()->find( attributeId, id );
         if ( value ) {
-            tip += "<tr><td>";
+            tip += QLatin1String( "<tr><td>" );
             tip += LinkLocator::escape( TableModelsHelper::attributeName( attributeId ) );
-            tip += ":</td><td>";
+            tip += QLatin1String( ":</td><td>" );
             tip += LinkLocator::convertToHtml( value->value(), 0 );
-            tip += "</td></tr>";
+            tip += QLatin1String( "</td></tr>" );
         }
     }
 
-    tip += "</table>";
+    tip += QLatin1String( "</table>" );
 
     return tip;
 }
 
-int IssuesTableModel::compare( int id1, int id2, Column column ) const
+int IssuesTableModel::compare( int id1, int id2, int column ) const
 {
     if ( column == Column_ID )
         return id1 - id2;
@@ -424,21 +452,19 @@ int IssuesTableModel::compare( int id1, int id2, Column column ) const
 void IssuesTableModel::updateEvent( UpdateEvent* e )
 {
     if ( e->unit() == UpdateEvent::Folder && e->id() == m_folderId )
-        emit tableChanged();
+        emit dataChanged();
 
     if ( e->unit() == UpdateEvent::Issue ) {
         const IssueRow* row = dataManager->issues()->find( e->id() );
         if ( row && row->folderId() == m_folderId )
-            emit rowChanged( e->id() );
+            emit dataChanged();
     }
 
     if ( e->unit() == UpdateEvent::Users )
-        emit rowsChanged();
+        emit dataChanged();
 }
 
-/* TRANSLATOR WebIssues::AttachmentsTableModel */
-
-AttachmentsTableModel::AttachmentsTableModel( int issueId, QObject* parent ) : AbstractTableModel( parent ),
+AttachmentsTableModel::AttachmentsTableModel( int issueId, QObject* parent ) : BaseTableModel( parent ),
     m_issueId( issueId )
 {
 }
@@ -447,7 +473,7 @@ AttachmentsTableModel::~AttachmentsTableModel()
 {
 }
 
-QString AttachmentsTableModel::text( int id, Column column ) const
+QString AttachmentsTableModel::text( int id, int column ) const
 {
     const AttachmentRow* row = dataManager->attachments()->find( id );
     if ( !row )
@@ -471,7 +497,7 @@ QString AttachmentsTableModel::text( int id, Column column ) const
     }
 }
 
-int AttachmentsTableModel::compare( int id1, int id2, Column column ) const
+int AttachmentsTableModel::compare( int id1, int id2, int column ) const
 {
     if ( column == Column_ID )
         return id1 - id2;
@@ -492,16 +518,19 @@ int AttachmentsTableModel::compare( int id1, int id2, Column column ) const
     return AbstractTableModel::compare( id1, id2, column );
 }
 
-QPixmap AttachmentsTableModel::icon( int id ) const
+QPixmap AttachmentsTableModel::icon( int /*id*/, int column ) const
 {
+    if ( column != Column_Name )
+        return QPixmap();
+
     return IconLoader::pixmap( "file" );
 }
 
 void AttachmentsTableModel::updateEvent( UpdateEvent* e )
 {
     if ( e->unit() == UpdateEvent::Issue && e->id() == m_issueId )
-        emit tableChanged();
+        emit dataChanged();
 
     if ( e->unit() == UpdateEvent::Users )
-        emit rowsChanged();
+        emit dataChanged();
 }
