@@ -12,15 +12,74 @@
 #ifndef TABLEMODELS_H
 #define TABLEMODELS_H
 
-#include "abstracttablemodel.h"
+#include "rdb/abstracttablemodel.h"
 
-namespace WebIssues
+class UpdateEvent;
+
+/**
+* Column type.
+*/
+enum Column
 {
+    Column_Name,
+    Column_ID,
+    Column_CreatedDate,
+    Column_CreatedBy,
+    Column_ModifiedDate,
+    Column_ModifiedBy,
+    Column_Size,
+    Column_Description,
+    Column_Login,
+    Column_Access,
+    Column_Required,
+    Column_Details,
+    Column_DefaultValue,
+    Column_OldValue,
+    Column_NewValue,
+    Column_Type,
+
+    /**
+    * The value added to attribute identifier to create user defined columns.
+    */
+    Column_UserDefined = 1000
+};
+
+/**
+* Base class for all table models.
+*/
+class BaseTableModel : public RDB::AbstractTableModel
+{
+    Q_OBJECT
+public:
+    /**
+    * Constructor.
+    *
+    * @param parent The parent object.
+    */
+    BaseTableModel( QObject* parent );
+
+    /**
+    * Destructor.
+    */
+    ~BaseTableModel();
+
+public: // overrides
+    QString columnName( int column ) const;
+
+protected:
+    /**
+    * Handle the event indicating that some data was updated.
+    */
+    virtual void updateEvent( UpdateEvent* e );
+
+protected: // overrides
+    void customEvent( QEvent* e );
+};
 
 /**
 * Model providing information for the rows of the users table.
 */
-class UsersTableModel : public AbstractTableModel
+class UsersTableModel : public BaseTableModel
 {
     Q_OBJECT
 public:
@@ -37,9 +96,9 @@ public:
     ~UsersTableModel();
 
 public: // overrides
-    QString text( int id, Column column ) const;
+    QString text( int id, int column ) const;
 
-    QPixmap icon( int id ) const;
+    QPixmap icon( int id, int column ) const;
 
 protected: // overrides
     void updateEvent( UpdateEvent* e );
@@ -48,7 +107,7 @@ protected: // overrides
 /**
 * Model providing information for the rows of the members table.
 */
-class MembersTableModel : public AbstractTableModel
+class MembersTableModel : public BaseTableModel
 {
     Q_OBJECT
 public:
@@ -67,9 +126,9 @@ public:
     ~MembersTableModel();
 
 public: // overrides
-    QString text( int id, Column column ) const;
+    QString text( int id, int column ) const;
 
-    QPixmap icon( int id ) const;
+    QPixmap icon( int id, int column ) const;
 
 protected: // overrides
     void updateEvent( UpdateEvent* e );
@@ -81,7 +140,7 @@ private:
 /**
 * Model providing information for the rows of the issue types table.
 */
-class TypesTableModel : public AbstractTableModel
+class TypesTableModel : public BaseTableModel
 {
     Q_OBJECT
 public:
@@ -98,9 +157,9 @@ public:
     ~TypesTableModel();
 
 public: // overrides
-    QString text( int id, Column column ) const;
+    QString text( int id, int column ) const;
 
-    QPixmap icon( int id ) const;
+    QPixmap icon( int id, int column ) const;
 
 protected: // overrides
     void updateEvent( UpdateEvent* e );
@@ -109,7 +168,7 @@ protected: // overrides
 /**
 * Model providing information for the rows of the attributes table.
 */
-class AttributesTableModel : public AbstractTableModel
+class AttributesTableModel : public BaseTableModel
 {
     Q_OBJECT
 public:
@@ -126,9 +185,9 @@ public:
     ~AttributesTableModel();
 
 public: // overrides
-    QString text( int id, Column column ) const;
+    QString text( int id, int column ) const;
 
-    QPixmap icon( int id ) const;
+    QPixmap icon( int id, int column ) const;
 
 protected: // overrides
     void updateEvent( UpdateEvent* e );
@@ -137,7 +196,7 @@ protected: // overrides
 /**
 * Model providing information for the rows of the projects table.
 */
-class ProjectsTableModel : public AbstractTableModel
+class ProjectsTableModel : public BaseTableModel
 {
     Q_OBJECT
 public:
@@ -154,9 +213,9 @@ public:
     ~ProjectsTableModel();
 
 public: // overrides
-    QString text( int id, Column column ) const;
+    QString text( int id, int column ) const;
 
-    QPixmap icon( int id ) const;
+    QPixmap icon( int id, int column ) const;
 
 protected: // overrides
     void updateEvent( UpdateEvent* e );
@@ -165,7 +224,7 @@ protected: // overrides
 /**
 * Model providing information for the rows of the folders table.
 */
-class FoldersTableModel : public AbstractTableModel
+class FoldersTableModel : public BaseTableModel
 {
     Q_OBJECT
 public:
@@ -182,9 +241,9 @@ public:
     ~FoldersTableModel();
 
 public: // overrides
-    QString text( int id, Column column ) const;
+    QString text( int id, int column ) const;
 
-    QPixmap icon( int id ) const;
+    QPixmap icon( int id, int column ) const;
 
 protected: // overrides
     void updateEvent( UpdateEvent* e );
@@ -193,7 +252,7 @@ protected: // overrides
 /**
 * Model providing information for the rows of the issues table.
 */
-class IssuesTableModel : public AbstractTableModel
+class IssuesTableModel : public BaseTableModel
 {
     Q_OBJECT
 public:
@@ -212,13 +271,13 @@ public:
     ~IssuesTableModel();
 
 public: // overrides
-    QString text( int id, Column column ) const;
+    QString text( int id, int column ) const;
 
-    QPixmap icon( int id ) const;
+    QPixmap icon( int id, int column ) const;
 
-    QString toolTip( int id ) const;
+    QString toolTip( int id, int column ) const;
 
-    int compare( int id1, int id2, Column column ) const;
+    int compare( int id1, int id2, int column ) const;
 
 protected: // overrides
     void updateEvent( UpdateEvent* e );
@@ -230,7 +289,7 @@ private:
 /**
 * Model providing information for the rows of the attachments table.
 */
-class AttachmentsTableModel : public AbstractTableModel
+class AttachmentsTableModel : public BaseTableModel
 {
     Q_OBJECT
 public:
@@ -249,11 +308,11 @@ public:
     ~AttachmentsTableModel();
 
 public: // overrides
-    QString text( int id, Column column ) const;
+    QString text( int id, int column ) const;
 
-    QPixmap icon( int id ) const;
+    QPixmap icon( int id, int column ) const;
 
-    int compare( int id1, int id2, Column column ) const;
+    int compare( int id1, int id2, int column ) const;
 
 protected: // overrides
     void updateEvent( UpdateEvent* e );
@@ -262,6 +321,4 @@ private:
     int m_issueId;
 };
 
-}
-
 #endif
