@@ -15,10 +15,7 @@
 
 #include "data/datamanager.h"
 #include "data/datarows.h"
-
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::TableModelsHelper */
+#include "tablemodels.h"
 
 QString TableModelsHelper::formatId( int id )
 {
@@ -62,7 +59,7 @@ QString TableModelsHelper::attributeName( int attributeId )
     return row->name();
 }
 
-QString TableModelsHelper::columnName( Column column )
+QString TableModelsHelper::columnName( int column )
 {
     switch ( column ) {
         case Column_Name:
@@ -109,5 +106,5 @@ QString TableModelsHelper::columnName( Column column )
 
 QString TableModelsHelper::tr( const char* text )
 {
-    return qApp->translate( "WebIssues::TableModelsHelper", text );
+    return qApp->translate( "TableModelsHelper", text );
 }
