@@ -14,11 +14,6 @@
 
 #include <QString>
 
-#include "abstracttablemodel.h"
-
-namespace WebIssues
-{
-
 /**
 * Functions for formatting various values.
 *
@@ -61,12 +56,10 @@ public:
     /**
     * Return the name of the given column.
     */
-    static QString columnName( Column column );
+    static QString columnName( int column );
 
 private:
     static QString tr( const char* text );
 };
 
-}
-
 #endif
