@@ -14,20 +14,18 @@
 #include <QTreeView>
 #include <QHeaderView>
 
-#include "tableitemmodel.h"
+#include "rdb/tableitemmodel.h"
 
-using namespace WebIssues;
-
-QMap<Column, int> TreeViewHelper::readColumnWidths( QTreeView* view )
+QMap<int, int> TreeViewHelper::readColumnWidths( QTreeView* view )
 {
-    QMap<Column, int> widths;
+    QMap<int, int> widths;
 
     int count = view->model()->columnCount();
     if ( view->header()->stretchLastSection() )
         count--;
 
     for ( int i = 0; i < count; i++ ) {
-        Column column = (Column)view->model()->headerData( i, Qt::Horizontal, TableItemModel::ColumnRole ).toInt();
+        int column = view->model()->headerData( i, Qt::Horizontal, RDB::TableItemModel::ColumnRole ).toInt();
         int width = view->columnWidth( i );
         widths.insert( column, width );
     }
@@ -35,10 +33,10 @@ QMap<Column, int> TreeViewHelper::readColumnWidths( QTreeView* view )
     return widths;
 }
 
-void TreeViewHelper::applyColumnWidths( QTreeView* view, const QMap<Column, int>& widths )
+void TreeViewHelper::applyColumnWidths( QTreeView* view, const QMap<int, int>& widths )
 {
     for ( int i = 0; i < view->model()->columnCount(); i++ ) {
-        Column column = (Column)view->model()->headerData( i, Qt::Horizontal, TableItemModel::ColumnRole ).toInt();
+        int column = view->model()->headerData( i, Qt::Horizontal, RDB::TableItemModel::ColumnRole ).toInt();
         int width = widths.value( column, 100 );
         view->setColumnWidth( i, width );
     }
@@ -53,7 +51,7 @@ QList<int> TreeViewHelper::readExpandedNodes( QTreeView* view )
     for ( int i = 0; i < view->model()->rowCount(); i++ ) {
         QModelIndex index = view->model()->index( i, 0 );
         if ( view->isExpanded( index ) )
-            nodes.append( view->model()->data( index, TableItemModel::RowIdRole ).toInt() );
+            nodes.append( view->model()->data( index, RDB::TableItemModel::RowIdRole ).toInt() );
     }
 
     return nodes;
@@ -63,7 +61,7 @@ void TreeViewHelper::applyExpandedNodes( QTreeView* view, const QList<int>& node
 {
     for ( int i = 0; i < view->model()->rowCount(); i++ ) {
         QModelIndex index = view->model()->index( i, 0 );
-        int id = view->model()->data( index, TableItemModel::RowIdRole ).toInt();
+        int id = view->model()->data( index, RDB::TableItemModel::RowIdRole ).toInt();
         if ( nodes.contains( id ) )
             view->setExpanded( index, true );
     }
