@@ -14,13 +14,8 @@
 
 #include <QMap>
 
-#include "abstracttablemodel.h"
-
 class QTreeView;
 
-namespace WebIssues
-{
-
 /**
 * Functions for reading and applying settings of a tree view.
 */
@@ -30,12 +25,12 @@ public:
     /**
     * Read column widths from the tree view.
     */
-    static QMap<Column, int> readColumnWidths( QTreeView* view );
+    static QMap<int, int> readColumnWidths( QTreeView* view );
 
     /**
     * Apply column widths to the tree view.
     */
-    static void applyColumnWidths( QTreeView* view, const QMap<Column, int>& widths );
+    static void applyColumnWidths( QTreeView* view, const QMap<int, int>& widths );
 
     /**
     * Read expanded nodes from the tree view.
@@ -48,6 +43,4 @@ public:
     static void applyExpandedNodes( QTreeView* view, const QList<int>& nodes );
 };
 
-}
-
 #endif
