@@ -17,11 +17,10 @@
 #include "attributes/definitionparser.h"
 #include "data/datamanager.h"
 #include "data/datarows.h"
-#include "data/rdb/tableiterators.h"
+#include "rdb/utilities.h"
+#include "tablemodels.h"
 #include "connectionmanager.h"
 
-using namespace WebIssues;
-
 TreeViewSettings::TreeViewSettings() :
     m_typeId( 0 ),
     m_longName( false )
@@ -114,7 +113,7 @@ void TreeViewSettings::openAttachmentsList()
     m_longName = false;
 }
 
-QList<Column> TreeViewSettings::loadColumns()
+QList<int> TreeViewSettings::loadColumns()
 {
     QSettings* settings = connectionManager->serverSettings();
 
@@ -130,7 +129,7 @@ QList<Column> TreeViewSettings::loadColumns()
     return deserializeColumns( list );
 }
 
-void TreeViewSettings::saveColumns( const QList<Column>& columns )
+void TreeViewSettings::saveColumns( const QList<int>& columns )
 {
     QSettings* settings = connectionManager->serverSettings();
 
@@ -141,27 +140,28 @@ void TreeViewSettings::saveColumns( const QList<Column>& columns )
     settings->endGroup();
 }
 
-QList<Column> TreeViewSettings::availableColumns()
+QList<int> TreeViewSettings::availableColumns()
 {
-    QList<Column> columns = m_columns;
+    QList<int> columns = m_columns;
 
-    if ( m_group == "IssuesList" ) {
+    if ( m_group == QLatin1String( "IssuesList" ) ) {
         columns.append( Column_CreatedDate );
         columns.append( Column_CreatedBy );
     }
 
     if ( m_typeId != 0 ) {
         RDB::ForeignConstIterator<AttributeRow> it( dataManager->attributes()->parentIndex(), m_typeId );
-        while ( it.next() )
-            columns.append( (Column)( Column_UserDefined + it.get()->attributeId() ) );
+        QList<const AttributeRow*> list = RDB::localeAwareSortRows( it, &AttributeRow::name );
+        for ( int i = 0; i < list.count(); i++ )
+            columns.append( Column_UserDefined + list.at( i )->attributeId() );
     }
 
     return columns;
 }
 
-QList<Column> TreeViewSettings::fixedColumns()
+QList<int> TreeViewSettings::fixedColumns()
 {
-    QList<Column> columns;
+    QList<int> columns;
 
     columns.append( Column_ID );
     columns.append( Column_Name );
@@ -169,17 +169,17 @@ QList<Column> TreeViewSettings::fixedColumns()
     return columns;
 }
 
-QMap<Column, int> TreeViewSettings::loadColumnWidths()
+QMap<int, int> TreeViewSettings::loadColumnWidths()
 {
-    QList<Column> usedColumns = loadColumns();
-    QMap<Column, int> widths;
+    QList<int> usedColumns = loadColumns();
+    QMap<int, int> widths;
 
     QSettings* settings = connectionManager->serverSettings();
 
     settings->beginGroup( QString( "%1/Widths" ).arg( m_group ) );
 
     for ( int i = 0; i < usedColumns.count(); i++ ) {
-        Column column = usedColumns.at( i );
+        int column = usedColumns.at( i );
         int width = settings->value( QString( "Column%1" ).arg( (int)column ), defaultColumnWidth( column ) ).toInt();
         widths.insert( column, width );
     }
@@ -189,18 +189,18 @@ QMap<Column, int> TreeViewSettings::loadColumnWidths()
     return widths;
 }
 
-void TreeViewSettings::saveColumnWidths( const QMap<Column, int>& widths )
+void TreeViewSettings::saveColumnWidths( const QMap<int, int>& widths )
 {
-    QList<Column> usedColumns = widths.keys();
+    QList<int> usedColumns = widths.keys();
 
     QSettings* settings = connectionManager->serverSettings();
 
     settings->beginGroup( QString( "%1/Widths" ).arg( m_group ) );
 
     for ( int i = 0; i < usedColumns.count(); i++ ) {
-        Column column = usedColumns.at( i );
+        int column = usedColumns.at( i );
         int width = widths.value( column );
-        settings->setValue( QString( "Column%1" ).arg( (int)column ), width );
+        settings->setValue( QString( "Column%1" ).arg( column ), width );
     }
 
     settings->endGroup();
@@ -239,7 +239,7 @@ void TreeViewSettings::saveExpandedNodes( const QList<int>& nodes )
     settings->endGroup();
 }
 
-QStringList TreeViewSettings::serializeColumns( const QList<Column>& columns )
+QStringList TreeViewSettings::serializeColumns( const QList<int>& columns )
 {
     QStringList list;
 
@@ -249,9 +249,9 @@ QStringList TreeViewSettings::serializeColumns( const QList<Column>& columns )
     return list;
 }
 
-QList<Column> TreeViewSettings::deserializeColumns( const QStringList& list )
+QList<int> TreeViewSettings::deserializeColumns( const QStringList& list )
 {
-    QList<Column> columns;
+    QList<int> columns;
 
     for ( int i = 0; i < list.count(); i++ ) {
         int column = list.at( i ).toInt();
@@ -260,7 +260,7 @@ QList<Column> TreeViewSettings::deserializeColumns( const QStringList& list )
             if ( !dataManager->attributes()->find( attributeId ) )
                 continue;
         }
-        columns.append( (Column)column );
+        columns.append( column );
     }
 
     if ( columns.count() == 0 )
@@ -269,7 +269,7 @@ QList<Column> TreeViewSettings::deserializeColumns( const QStringList& list )
     return columns;
 }
 
-int TreeViewSettings::defaultColumnWidth( Column column )
+int TreeViewSettings::defaultColumnWidth( int column )
 {
     switch ( column ) {
         case Column_Name:
