@@ -15,13 +15,8 @@
 #include <QObject>
 #include <QMap>
 
-#include "abstracttablemodel.h"
-
 class QSettings;
 
-namespace WebIssues
-{
-
 class DefinitionInfo;
 
 /**
@@ -77,37 +72,37 @@ public:
     /**
     * Return a list of columns in the view.
     */
-    QList<Column> loadColumns();
+    QList<int> loadColumns();
 
     /**
     * Set the list of columns for the view.
     */
-    void saveColumns( const QList<Column>& columns );
+    void saveColumns( const QList<int>& columns );
 
     /**
     * Return the default list of columns for the view.
     */
-    QList<Column> defaultColumns() { return m_columns; }
+    QList<int> defaultColumns() { return m_columns; }
 
     /**
     * Return all available columns for the view.
     */
-    QList<Column> availableColumns();
+    QList<int> availableColumns();
 
     /**
     * Return columns which cannot be removed from the view.
     */
-    QList<Column> fixedColumns();
+    QList<int> fixedColumns();
 
     /**
     * Return column widths in the view.
     */
-    QMap<Column, int> loadColumnWidths();
+    QMap<int, int> loadColumnWidths();
 
     /**
     * Set column widths for the view.
     */
-    void saveColumnWidths( const QMap<Column, int>& widths );
+    void saveColumnWidths( const QMap<int, int>& widths );
 
     /**
     * Return identifiers of expanded nodes.
@@ -120,21 +115,19 @@ public:
     void saveExpandedNodes( const QList<int>& nodes );
 
 private:
-    QStringList serializeColumns( const QList<Column>& columns );
-    QList<Column> deserializeColumns( const QStringList& list );
+    QStringList serializeColumns( const QList<int>& columns );
+    QList<int> deserializeColumns( const QStringList& list );
 
-    int defaultColumnWidth( Column column );
+    int defaultColumnWidth( int column );
     int defaultColumnWidth( const DefinitionInfo& info );
 
 private:
     QString m_group;
     int m_typeId;
 
-    QList<Column> m_columns;
+    QList<int> m_columns;
 
     bool m_longName;
 };
 
-}
-
 #endif
