@@ -14,8 +14,8 @@
 
 #include <QtCore>
 #include <QtGui>
+#include <QtNetwork>
 
-#include <QHttp>
 #include <QDomDocument>
 
 #endif
