@@ -15,6 +15,7 @@
 #include <QCloseEvent>
 #include <QApplication>
 #include <QSettings>
+#include <QToolBar>
 
 #include "widgets/statusbar.h"
 #include "dialogs/settingsdialog.h"
@@ -23,10 +24,6 @@
 #include "configdata.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::ViewerWindow */
-
 ViewerWindow::ViewerWindow() :
     m_view( NULL )
 {
@@ -60,12 +57,14 @@ ViewerWindow::ViewerWindow() :
     setTitle( "menuTools", tr( "&Tools" ) );
     setTitle( "menuHelp", tr( "&Help" ) );
 
-    loadXmlFile( ":/resources/viewerwindow.xml" );
+    loadXmlUiFile( ":/resources/viewerwindow.xml" );
 
     m_builder = new XmlUi::Builder( this );
+    connect( m_builder, SIGNAL( toolBarCreated( QToolBar* ) ), this, SLOT( toolBarCreated( QToolBar* ) ) );
+
     m_builder->addClient( this );
 
-    setStatusBar( new WebIssues::StatusBar( this ) );
+    setStatusBar( new ::StatusBar( this ) );
 }
 
 ViewerWindow::~ViewerWindow()
@@ -74,7 +73,7 @@ ViewerWindow::~ViewerWindow()
         return;
 
     QSettings* settings = configData->settings();
-    settings->beginGroup( QString( "ViewerWindow/%1" ).arg( m_view->metaObject()->className() ) );
+    settings->beginGroup( QString( "ViewerWindow/WebIssues::%1" ).arg( m_view->metaObject()->className() ) );
     settings->setValue( "Size", size() );
     settings->endGroup();
 }
@@ -98,7 +97,7 @@ void ViewerWindow::setView( View* view )
     enabledChanged( view->isEnabled() );
 
     QSettings* settings = configData->settings();
-    settings->beginGroup( QString( "ViewerWindow/%1" ).arg( m_view->metaObject()->className() ) );
+    settings->beginGroup( QString( "ViewerWindow/WebIssues::%1" ).arg( m_view->metaObject()->className() ) );
     resize( settings->value( "Size", view->viewerSizeHint() ).toSize() );
     settings->endGroup();
 
@@ -138,3 +137,8 @@ void ViewerWindow::captionChanged( const QString& caption )
 {
     setWindowTitle( tr( "%1 - WebIssues" ).arg( caption ) );
 }
+
+void ViewerWindow::toolBarCreated( QToolBar* toolBar )
+{
+    toolBar->setIconSize( QSize( 22, 22 ) );
+}
