@@ -21,9 +21,6 @@ namespace XmlUi
 class Builder;
 }
 
-namespace WebIssues
-{
-
 class View;
 
 /**
@@ -74,12 +71,12 @@ private slots:
 
     void enabledChanged( bool enabled );
 
+    void toolBarCreated( QToolBar* toolBar );
+
 private:
     XmlUi::Builder* m_builder;
 
     View* m_view;
 };
 
-}
-
 #endif
