@@ -19,9 +19,7 @@
 #include "views/viewfactory.h"
 #include "viewerwindow.h"
 
-using namespace WebIssues;
-
-ViewManager* WebIssues::viewManager = NULL;
+ViewManager* viewManager = NULL;
 
 ViewManager::ViewManager()
 {
@@ -31,7 +29,7 @@ ViewManager::~ViewManager()
 {
     QList<ViewerWindow*> windows = m_views.values();
 
-    for ( uint i = 0; i < windows.count(); i++ ) {
+    for ( int i = 0; i < windows.count(); i++ ) {
         ViewerWindow* window = windows.at( i );
         delete window;
     }
@@ -39,47 +37,47 @@ ViewManager::~ViewManager()
 
 void ViewManager::openTypesView()
 {
-    openView( "WebIssues::TypesView", 0 );
+    openView( "TypesView", 0 );
 }
 
 void ViewManager::openUsersView()
 {
-    openView( "WebIssues::UsersView", 0 );
+    openView( "UsersView", 0 );
 }
 
 void ViewManager::openFolderView( int folderId )
 {
-    openView( "WebIssues::FolderView", folderId );
+    openView( "FolderView", folderId );
 }
 
 void ViewManager::openFolderView( int folderId, const QString& filter )
 {
-    FolderView* view = (FolderView*)openView( "WebIssues::FolderView", folderId );
+    FolderView* view = (FolderView*)openView( "FolderView", folderId );
     view->selectFilter( filter );
 }
 
 void ViewManager::openIssueView( int issueId, int itemId )
 {
-    IssueView* view = (IssueView*)openView( "WebIssues::IssueView", issueId );
+    IssueView* view = (IssueView*)openView( "IssueView", issueId );
     if ( itemId != 0 )
         view->gotoItem( itemId );
 }
 
 void ViewManager::openMembersView( int projectId )
 {
-    openView( "WebIssues::MembersView", projectId );
+    openView( "MembersView", projectId );
 }
 
 void ViewManager::openCommentView( int issueId )
 {
-    openView( "WebIssues::CommentView", issueId );
+    openView( "CommentView", issueId );
 }
 
 bool ViewManager::queryCloseViews()
 {
     QList<View*> views = m_views.keys();
 
-    for ( uint i = 0; i < views.count(); i++ ) {
+    for ( int i = 0; i < views.count(); i++ ) {
         View* view = views.at( i );
         if ( !view->queryClose() )
             return false;
@@ -92,7 +90,7 @@ void ViewManager::postViewEvent( const char* className, ViewEvent::Action action
 {
     QList<View*> views = m_views.keys();
 
-    for ( uint i = 0; i < views.count(); i++ ) {
+    for ( int i = 0; i < views.count(); i++ ) {
         View* view = views.at( i );
         if ( !className || view->inherits( className ) ) {
             ViewEvent* viewEvent = new ViewEvent( action, id );
@@ -134,7 +132,7 @@ View* ViewManager::findView( const char* className, int id )
 {
     QList<View*> views = m_views.keys();
 
-    for ( uint i = 0; i < views.count(); i++ ) {
+    for ( int i = 0; i < views.count(); i++ ) {
         View* view = views.at( i );
         if ( view->inherits( className ) ) {
             if ( id == 0 || view->id() == id )
