@@ -17,9 +17,6 @@
 
 #include "views/viewevent.h"
 
-namespace WebIssues
-{
-
 class View;
 class ViewerWindow;
 
@@ -150,6 +147,4 @@ private:
 */
 extern ViewManager* viewManager;
 
-}
-
 #endif
