@@ -27,10 +27,6 @@
 #include "viewmanager.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::CommentView */
-
 CommentView::CommentView( QObject* parent, QWidget* parentWidget ) : View( parent ),
     m_sending( false )
 {
@@ -90,7 +86,7 @@ CommentView::CommentView( QObject* parent, QWidget* parentWidget ) : View( paren
     setTitle( "menuMain", tr( "&Comment" ) );
     setTitle( "menuEdit", tr( "&Edit" ) );
 
-    loadXmlFile( ":/resources/commentview.xml" );
+    loadXmlUiFile( ":/resources/commentview.xml" );
 
     connect( m_edit, SIGNAL( textChanged() ), this, SLOT( updateActions() ) );
 
@@ -168,7 +164,7 @@ bool CommentView::queryClose()
     return true;
 }
 
-void CommentView::updateEvent( UpdateEvent* e )
+void CommentView::updateEvent( UpdateEvent* /*e*/ )
 {
 }
 
