@@ -16,9 +16,6 @@
 
 class QTextEdit;
 
-namespace WebIssues
-{
-
 /**
 * View for adding comments to issues.
 */
@@ -64,6 +61,4 @@ private:
     bool m_sending;
 };
 
-}
-
 #endif
