@@ -17,9 +17,6 @@
 class QTextBrowser;
 class QUrl;
 
-namespace WebIssues
-{
-
 class FolderWatchProvider;
 
 /**
@@ -66,6 +63,4 @@ private:
     FolderWatchProvider* m_provider;
 };
 
-}
-
 #endif
