@@ -18,7 +18,6 @@
 #include <QAction>
 #include <QMenu>
 
-#include "models/tableitemmodel.h"
 #include "models/tablemodels.h"
 #include "models/rowfilters.h"
 #include "models/columnconditionsettings.h"
@@ -36,15 +35,12 @@
 #include "dialogs/columnsettingsdialog.h"
 #include "dialogs/managefiltersdialog.h"
 #include "dialogs/savefilterdialog.h"
+#include "dialogs/reportdialog.h"
 #include "xmlui/builder.h"
 #include "connectionmanager.h"
 #include "viewmanager.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::FolderView */
-
 FolderView::FolderView( QObject* parent, QWidget* parentWidget ) : View( parent ),
     m_model( NULL ),
     m_filter( NULL ),
@@ -85,10 +81,28 @@ FolderView::FolderView( QObject* parent, QWidget* parentWidget ) : View( parent
     connect( action, SIGNAL( triggered() ), this, SLOT( configureColumns() ) );
     setAction( "configureColumns", action );
 
+    action = new QAction( IconLoader::icon( "file-print" ), tr( "&Print List..." ), this );
+    action->setShortcut( QKeySequence::Print );
+    connect( action, SIGNAL( triggered() ), this, SLOT( printReport() ) );
+    setAction( "printReport", action );
+
+    action = new QAction( IconLoader::icon( "export-csv" ), tr( "To &CSV..." ), this );
+    connect( action, SIGNAL( triggered() ), this, SLOT( exportCsv() ) );
+    setAction( "exportCsv", action );
+
+    action = new QAction( IconLoader::icon( "export-html" ), tr( "To &HTML..." ), this );
+    connect( action, SIGNAL( triggered() ), this, SLOT( exportHtml() ) );
+    setAction( "exportHtml", action );
+
+    action = new QAction( IconLoader::icon( "export-pdf" ), tr( "To &PDF..." ), this );
+    connect( action, SIGNAL( triggered() ), this, SLOT( exportPdf() ) );
+    setAction( "exportPdf", action );
+
     setTitle( "menuMain", tr( "&Folder" ) );
     setTitle( "menuEdit", tr( "&Edit" ) );
+    setTitle( "menuExport", tr( "&Export List" ) );
 
-    loadXmlFile( ":/resources/folderview.xml" );
+    loadXmlUiFile( ":/resources/folderview.xml" );
 
     QWidget* main = new QWidget( parentWidget );
 
@@ -173,9 +187,10 @@ void FolderView::initialUpdate()
 {
     m_filter = new IssueRowFilter( this );
 
-    m_model = new TableItemModel( this );
+    m_model = new RDB::TableItemModel( this );
     m_model->setRowFilter( m_filter );
-    m_model->setRootTableModel( new IssuesTableModel( id(), m_model ), dataManager->issues()->parentIndex(), id() );
+    m_model->setRootTableModel( new IssuesTableModel( id(), m_model ),
+        dataManager->issues()->index(), dataManager->issues()->parentIndex(), id() );
 
     connect( m_model, SIGNAL( layoutChanged() ), this, SLOT( updateActions() ) );
     connect( m_model, SIGNAL( layoutChanged() ), this, SLOT( updateSummary() ) );
@@ -218,7 +233,7 @@ void FolderView::enableView()
     TreeViewSettings settings;
     settings.openIssuesList( m_typeId );
 
-    QList<Column> columns = settings.loadColumns();
+    QList<int> columns = settings.loadColumns();
 
     m_model->setColumns( columns );
 
@@ -265,7 +280,7 @@ void FolderView::updateActions()
 
     QModelIndex index = selectedIndex();
     if ( index.isValid() )
-        m_selectedIssueId = m_model->data( index, TableItemModel::RowIdRole ).toInt();
+        m_selectedIssueId = m_model->data( index, RDB::TableItemModel::RowIdRole ).toInt();
 
     action( "openIssue" )->setEnabled( m_selectedIssueId != 0 );
     action( "saveFilterAs" )->setEnabled( m_filterType == NewFilter );
@@ -394,6 +409,34 @@ void FolderView::applyColumns()
     }
 }
 
+void FolderView::printReport()
+{
+    ReportDialog dialog( HtmlReportGenerator::Folder, ReportDialog::Print, mainWidget() );
+    dialog.setFolder( id(), visibleIssues(), m_filterCombo->currentText() );
+    dialog.exec();
+}
+
+void FolderView::exportCsv()
+{
+    ReportDialog dialog( HtmlReportGenerator::Folder, ReportDialog::ExportCsv, mainWidget() );
+    dialog.setFolder( id(), visibleIssues(), m_filterCombo->currentText() );
+    dialog.exec();
+}
+
+void FolderView::exportHtml()
+{
+    ReportDialog dialog( HtmlReportGenerator::Folder, ReportDialog::ExportHtml, mainWidget() );
+    dialog.setFolder( id(), visibleIssues(), m_filterCombo->currentText() );
+    dialog.exec();
+}
+
+void FolderView::exportPdf()
+{
+    ReportDialog dialog( HtmlReportGenerator::Folder, ReportDialog::ExportPdf, mainWidget() );
+    dialog.setFolder( id(), visibleIssues(), m_filterCombo->currentText() );
+    dialog.exec();
+}
+
 void FolderView::updateEvent( UpdateEvent* e )
 {
     setAccess( checkDataAccess() );
@@ -436,6 +479,9 @@ void FolderView::viewEvent( ViewEvent* e )
                 if ( e->id() == id() )
                     updateColumnList();
                 break;
+
+            default:
+                break;
         }
     }
     View::viewEvent( e );
@@ -466,7 +512,7 @@ void FolderView::listContextMenu( const QPoint& pos )
 void FolderView::activated( const QModelIndex& index )
 {
     if ( index.isValid() ) {
-        int issueId = m_model->data( index, TableItemModel::RowIdRole ).toInt();
+        int issueId = m_model->data( index, RDB::TableItemModel::RowIdRole ).toInt();
         viewManager->openIssueView( issueId, 0 );
     }
 }
@@ -478,10 +524,10 @@ void FolderView::updateColumnList()
 
     settings.saveColumnWidths( TreeViewHelper::readColumnWidths( m_list ) );
 
-    Column sortColumn = m_model->sortColumn();
+    int sortColumn = m_model->sortColumn();
     Qt::SortOrder sortOrder = m_model->sortOrder();
 
-    QList<Column> columns = settings.loadColumns();
+    QList<int> columns = settings.loadColumns();
 
     m_model->setColumns( columns );
 
@@ -507,10 +553,10 @@ void FolderView::updateSearchOptions()
 
     for ( int i = 0; i < m_model->columns().count(); i++ )
     {
-        Column column = m_model->columns().at( i );
+        int column = m_model->columns().at( i );
         QString name = TableModelsHelper::columnName( column );
         QAction* action = m_searchMenu->addAction( name );
-        action->setData( (int)column );
+        action->setData( column );
         action->setCheckable( true );
         if ( column == m_searchColumn )
             action->setChecked( true );
@@ -649,3 +695,16 @@ QModelIndex FolderView::selectedIndex()
 
     return selection.at( 0 );
 }
+
+QList<int> FolderView::visibleIssues()
+{
+    QList<int> list;
+
+    int rows = m_model->rowCount( QModelIndex() );
+    for ( int i = 0; i < rows; i++ ) {
+        int issueId = m_model->data( m_model->index( i, 0, QModelIndex() ), RDB::TableItemModel::RowIdRole ).toInt();
+        list.append( issueId );
+    }
+
+    return list;
+}
