@@ -13,17 +13,13 @@
 #define FOLDERVIEW_H
 
 #include "view.h"
-#include "models/abstracttablemodel.h"
+#include "rdb/tableitemmodel.h"
 
 class QTreeView;
 class QModelIndex;
 class QMenu;
 class QActionGroup;
 
-namespace WebIssues
-{
-
-class TableItemModel;
 class IssueRowFilter;
 class SearchEditBox;
 class SeparatorComboBox;
@@ -51,6 +47,9 @@ public:
     ~FolderView();
 
 public:
+    /**
+    * Activate the filter with given name.
+    */
     void selectFilter( const QString& filter );
 
 public: // overrides
@@ -76,6 +75,11 @@ private slots:
     void manageFilters();
     void configureColumns();
 
+    void printReport();
+    void exportCsv();
+    void exportHtml();
+    void exportPdf();
+
     void headerContextMenu( const QPoint& pos );
     void listContextMenu( const QPoint& pos );
 
@@ -101,6 +105,8 @@ private:
 
     QModelIndex selectedIndex();
 
+    QList<int> visibleIssues();
+
 private:
     enum FilterType
     {
@@ -111,7 +117,7 @@ private:
 
 private:
     QTreeView* m_list;
-    TableItemModel* m_model;
+    RDB::TableItemModel* m_model;
 
     IssueRowFilter* m_filter;
 
@@ -127,7 +133,7 @@ private:
 
     QList<ColumnCondition> m_newConditions;
 
-    Column m_searchColumn;
+    int m_searchColumn;
 
     int m_typeId;
     int m_projectId;
@@ -135,6 +141,4 @@ private:
     int m_selectedIssueId;
 };
 
-}
-
 #endif
