@@ -30,22 +30,20 @@
 #include <QSettings>
 
 #include "attributes/datetimehelper.h"
-#include "models/tableitemmodel.h"
 #include "models/tablemodels.h"
 #include "models/tablemodelshelper.h"
 #include "models/linklocator.h"
-#include "models/htmlhistorywriter.h"
 #include "models/issuehistoryprovider.h"
+#include "models/issuehistorywriter.h"
 #include "models/treeviewsettings.h"
 #include "models/treeviewhelper.h"
 #include "models/issueviewsettings.h"
-#include "data/rdb/tableiterators.h"
 #include "data/datamanager.h"
 #include "data/updateevent.h"
 #include "data/updatebatch.h"
-#include "data/rowhelpers.h"
 #include "data/connectioninfo.h"
 #include "data/attachmentscache.h"
+#include "rdb/utilities.h"
 #include "widgets/propertypanel.h"
 #include "widgets/popeditpanel.h"
 #include "widgets/popeditbox.h"
@@ -54,16 +52,13 @@
 #include "dialogs/findbar.h"
 #include "dialogs/checkmessagebox.h"
 #include "dialogs/attributesettingsdialog.h"
+#include "dialogs/reportdialog.h"
 #include "xmlui/builder.h"
 #include "connectionmanager.h"
 #include "viewmanager.h"
 #include "configdata.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::IssueView */
-
 IssueView::IssueView( QObject* parent, QWidget* parentWidget ) : View( parent ),
     m_model( NULL ),
     m_gotoItemId( 0 )
@@ -146,12 +141,31 @@ IssueView::IssueView( QObject* parent, QWidget* parentWidget ) : View( parent ),
     connect( action, SIGNAL( triggered() ), this, SLOT( selectAll() ) );
     setAction( "editSelectAll", action );
 
+    action = new QAction( IconLoader::icon( "file-print" ), tr( "&Print Issue..." ), this );
+    action->setShortcut( QKeySequence::Print );
+    connect( action, SIGNAL( triggered() ), this, SLOT( printReport() ) );
+    setAction( "printReport", action );
+
+    action = new QAction( IconLoader::icon( "export-html" ), tr( "To &HTML..." ), this );
+    connect( action, SIGNAL( triggered() ), this, SLOT( exportHtml() ) );
+    setAction( "exportHtml", action );
+
+    action = new QAction( IconLoader::icon( "export-pdf" ), tr( "To &PDF..." ), this );
+    connect( action, SIGNAL( triggered() ), this, SLOT( exportPdf() ) );
+    setAction( "exportPdf", action );
+
     setTitle( "menuMain", tr( "&Issue" ) );
     setTitle( "menuEdit", tr( "&Edit" ) );
+    setTitle( "menuExport", tr( "&Export Issue" ) );
 
-    loadXmlFile( ":/resources/issueview.xml" );
+    loadXmlUiFile( ":/resources/issueview.xml" );
 
-    m_tabWidget = new QTabWidget( parentWidget );
+    QWidget* widget = new QWidget( parentWidget );
+    m_tabWidget = new QTabWidget( widget );
+
+    QVBoxLayout* layout = new QVBoxLayout( widget );
+    layout->setContentsMargins( 0, 1, 0, 0 );
+    layout->addWidget( m_tabWidget );
 
     connect( m_tabWidget, SIGNAL( currentChanged( int ) ), this, SLOT( tabChanged( int ) ) );
 
@@ -258,7 +272,7 @@ IssueView::IssueView( QObject* parent, QWidget* parentWidget ) : View( parent ),
     m_tabWidget->addTab( historyTab, IconLoader::icon( "view-history" ), tr( "Issue History" ) );
     m_tabWidget->addTab( attachmentsTab, IconLoader::icon( "file-attach" ), tr( "Attachments" ) );
 
-    setMainWidget( m_tabWidget );
+    setMainWidget( widget );
 
     setViewerSizeHint( QSize( 700, 500 ) );
 }
@@ -278,9 +292,9 @@ IssueView::~IssueView()
 
 void IssueView::initialUpdate()
 {
-    m_model = new TableItemModel( this );
+    m_model = new RDB::TableItemModel( this );
     m_model->setRootTableModel( new AttachmentsTableModel( id(), m_model ),
-        dataManager->attachments()->parentIndex(), id() );
+        dataManager->attachments()->index(), dataManager->attachments()->parentIndex(), id() );
 
     connect( m_model, SIGNAL( layoutChanged() ), this, SLOT( updateActions() ) );
 
@@ -409,7 +423,7 @@ void IssueView::updateActions()
 
     QModelIndex index = selectedIndex();
     if ( index.isValid() )
-        m_selectedAttachmentId = m_model->data( index, TableItemModel::RowIdRole ).toInt();
+        m_selectedAttachmentId = m_model->data( index, RDB::TableItemModel::RowIdRole ).toInt();
 
     m_currentPage = m_tabWidget->currentIndex();
 
@@ -424,8 +438,8 @@ void IssueView::updateActions()
     action( "find" )->setEnabled( m_currentPage == 1 );
     action( "findNext" )->setEnabled( m_currentPage == 1 && m_isFindEnabled );
     action( "findPrevious" )->setEnabled( m_currentPage == 1 && m_isFindEnabled );
-    action( "openAttachment" )->setEnabled( m_currentPage == 2 && m_selectedAttachmentId != 0 || linkNotEmpty );
-    action( "saveAttachment" )->setEnabled( m_currentPage == 2 && m_selectedAttachmentId != 0 || linkNotEmpty );
+    action( "openAttachment" )->setEnabled( ( m_currentPage == 2 && m_selectedAttachmentId != 0 ) || linkNotEmpty );
+    action( "saveAttachment" )->setEnabled( ( m_currentPage == 2 && m_selectedAttachmentId != 0 ) || linkNotEmpty );
     action( "findItem" )->setEnabled( linkNotEmpty );
     action( "sendEmail" )->setEnabled( linkNotEmpty );
     action( "openLink" )->setEnabled( linkNotEmpty );
@@ -624,6 +638,27 @@ void IssueView::copyLink()
     }
 }
 
+void IssueView::printReport()
+{
+    ReportDialog dialog( HtmlReportGenerator::Issue, ReportDialog::Print, mainWidget() );
+    dialog.setIssue( id() );
+    dialog.exec();
+}
+
+void IssueView::exportHtml()
+{
+    ReportDialog dialog( HtmlReportGenerator::Issue, ReportDialog::ExportHtml, mainWidget() );
+    dialog.setIssue( id() );
+    dialog.exec();
+}
+
+void IssueView::exportPdf()
+{
+    ReportDialog dialog( HtmlReportGenerator::Issue, ReportDialog::ExportPdf, mainWidget() );
+    dialog.setIssue( id() );
+    dialog.exec();
+}
+
 void IssueView::updateEvent( UpdateEvent* e )
 {
     setAccess( checkDataAccess() );
@@ -683,6 +718,9 @@ void IssueView::viewEvent( ViewEvent* e )
             case ViewEvent::UpdateSettings:
                 populateAttributes();
                 break;
+
+            default:
+                break;
         }
     }
     View::viewEvent( e );
@@ -791,7 +829,7 @@ void IssueView::updateAttributes()
 {
     m_attributePanel->clearValues();
 
-    RDB::ForeignConstIterator<ValueRow> it( dataManager->values()->otherIndex(), id() );
+    RDB::ForeignConstIterator<ValueRow> it( dataManager->values()->index().second(), id() );
     while ( it.next() ) {
         const ValueRow* value = it.get();
         m_attributePanel->setValue( value->attributeId(), LinkLocator::convertToHtml( value->value(), 0 ) );
@@ -803,8 +841,10 @@ void IssueView::populateComments()
     IssueHistoryProvider provider;
     provider.extractIssueHistory( id() );
 
-    HTMLHistoryWriter writer( m_browser );
+    IssueHistoryWriter writer( IssueHistoryWriter::HistoryView );
     provider.write( &writer );
+
+    m_browser->setHtml( writer.result() );
 }
 
 void IssueView::linkContextMenu( const QString& link, const QPoint& pos )
@@ -815,11 +855,11 @@ void IssueView::linkContextMenu( const QString& link, const QPoint& pos )
     QUrl url( link );
 
     QString menuName;
-    if ( url.scheme() == "id" )
+    if ( url.scheme() == QLatin1String( "id" ) )
         menuName = "contextLinkItem";
-    else if ( url.scheme() == "attachment" )
+    else if ( url.scheme() == QLatin1String( "attachment" ) )
         menuName = "contextLinkAttachment";
-    else if ( url.scheme() == "mailto" )
+    else if ( url.scheme() == QLatin1String( "mailto" ) )
         menuName = "contextLinkEmail";
     else
         menuName = "contextLink";
@@ -869,7 +909,7 @@ void IssueView::attachmentsContextMenu( const QPoint& pos )
 void IssueView::activated( const QModelIndex& index )
 {
     if ( index.isValid() ) {
-        int attachmenId = m_model->data( index, TableItemModel::RowIdRole ).toInt();
+        int attachmenId = m_model->data( index, RDB::TableItemModel::RowIdRole ).toInt();
         handleAttachment( attachmenId );
     }
 }
@@ -885,10 +925,10 @@ void IssueView::anchorClicked( const QUrl& url )
     m_browser->setSource( QUrl() );
     m_browser->verticalScrollBar()->setSliderPosition( pos );
 
-    if ( url.scheme() == "id" ) {
+    if ( url.scheme() == QLatin1String( "id" ) ) {
         int itemId = url.host().toInt();
         findItem( itemId );
-    } else if ( url.scheme() == "attachment" ) {
+    } else if ( url.scheme() == QLatin1String( "attachment" ) ) {
         int attachmentId = url.host().toInt();
         handleAttachment( attachmentId );
     } else {
