@@ -15,6 +15,7 @@
 #include <QTextDocument>
 
 #include "view.h"
+#include "rdb/tableitemmodel.h"
 #include "configdata.h"
 
 class QTabWidget;
@@ -23,13 +24,9 @@ class QTreeView;
 class QModelIndex;
 class QUrl;
 
-namespace WebIssues
-{
-
 class PropertyPanel;
 class PopEditPanel;
 class PopEditBox;
-class TableItemModel;
 class RowIndex;
 class FindBar;
 
@@ -55,6 +52,9 @@ public:
     ~IssueView();
 
 public:
+    /**
+    * Navigate to the given comment, attachment or change.
+    */
     void gotoItem( int itemId );
 
 public: // overrides
@@ -94,6 +94,10 @@ private slots:
     void openLink();
     void copyLink();
 
+    void printReport();
+    void exportHtml();
+    void exportPdf();
+
     void linkContextMenu( const QString& link, const QPoint& pos );
     void historyContextMenu( const QPoint& pos );
     void attachmentsContextMenu( const QPoint& pos );
@@ -136,7 +140,7 @@ private:
     QTextBrowser* m_browser;
 
     QTreeView* m_list;
-    TableItemModel* m_model;
+    RDB::TableItemModel* m_model;
 
     FindBar* m_findBar;
 
@@ -154,6 +158,4 @@ private:
     bool m_isFindEnabled;
 };
 
-}
-
 #endif
