@@ -15,7 +15,6 @@
 #include <QAction>
 #include <QMenu>
 
-#include "models/tableitemmodel.h"
 #include "models/tablemodels.h"
 #include "models/treeviewsettings.h"
 #include "models/treeviewhelper.h"
@@ -27,10 +26,6 @@
 #include "connectionmanager.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::MembersView */
-
 MembersView::MembersView( QObject* parent, QWidget* parentWidget ) : View( parent ),
     m_model( NULL )
 {
@@ -58,7 +53,7 @@ MembersView::MembersView( QObject* parent, QWidget* parentWidget ) : View( paren
     setTitle( "menuMain", tr( "&Members" ) );
     setTitle( "menuEdit", tr( "&Edit" ) );
 
-    loadXmlFile( ":/resources/membersview.xml" );
+    loadXmlUiFile( ":/resources/membersview.xml" );
 
     m_list = new QTreeView( parentWidget );
     m_list->setSortingEnabled( true );
@@ -88,8 +83,9 @@ MembersView::~MembersView()
 
 void MembersView::initialUpdate()
 {
-    m_model = new TableItemModel( this );
-    m_model->setRootTableModel( new MembersTableModel( id(), m_model ), dataManager->members()->otherIndex(), id() );
+    m_model = new RDB::TableItemModel( this );
+    m_model->setRootTableModel( new MembersTableModel( id(), m_model ),
+        dataManager->members()->index().first(), dataManager->members()->index().second(), id() );
 
     connect( m_model, SIGNAL( layoutChanged() ), this, SLOT( updateActions() ) );
 
@@ -147,7 +143,7 @@ void MembersView::disableView()
     updateCaption();
 }
 
-void MembersView::updateAccess( Access access )
+void MembersView::updateAccess( Access /*access*/ )
 {
     action( "addMember" )->setVisible( m_projectAdmin );
     action( "changeAccess" )->setVisible( m_projectAdmin );
@@ -171,7 +167,7 @@ void MembersView::updateActions()
 
     QModelIndexList indexes = selectedIndexes();
     for ( int i = 0; i < indexes.count(); i++ )
-        m_selectedUsers.append( m_model->data( indexes.at( i ), TableItemModel::RowIdRole ).toInt() );
+        m_selectedUsers.append( m_model->data( indexes.at( i ), RDB::TableItemModel::RowIdRole ).toInt() );
 
     action( "changeAccess" )->setEnabled( !m_selectedUsers.isEmpty() );
     action( "removeMember" )->setEnabled( !m_selectedUsers.isEmpty() );
@@ -237,7 +233,7 @@ void MembersView::contextMenu( const QPoint& pos )
 void MembersView::activated( const QModelIndex& index )
 {
     if ( index.isValid() && m_projectAdmin ) {
-        int userId = m_model->data( index, TableItemModel::RowIdRole ).toInt();
+        int userId = m_model->data( index, RDB::TableItemModel::RowIdRole ).toInt();
 
         QList<int> users;
         users.append( userId );
