@@ -13,16 +13,11 @@
 #define MEMBERSVIEW_H
 
 #include "view.h"
+#include "rdb/tableitemmodel.h"
 
 class QTreeView;
 class QModelIndex;
 
-namespace WebIssues
-{
-
-class TableItemModel;
-class RowIndex;
-
 /**
 * View for displaying and managing members of a project.
 */
@@ -75,13 +70,11 @@ private:
 
 private:
     QTreeView* m_list;
-    TableItemModel* m_model;
+    RDB::TableItemModel* m_model;
 
     QList<int> m_selectedUsers;
 
     bool m_projectAdmin;
 };
 
-}
-
 #endif
