@@ -17,11 +17,9 @@
 #include <QTimer>
 #include <QMessageBox>
 
-#include "models/tableitemmodel.h"
 #include "models/tablemodels.h"
 #include "models/treeviewsettings.h"
 #include "models/treeviewhelper.h"
-#include "data/rdb/tableiterators.h"
 #include "data/datamanager.h"
 #include "data/connectioninfo.h"
 #include "data/updatebatch.h"
@@ -35,10 +33,6 @@
 #include "viewmanager.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::ProjectsView */
-
 ProjectsView::ProjectsView( QObject* parent, QWidget* parentWidget ) : View( parent ),
     m_firstUpdateDone( false ),
     m_updateCounter( 0 ),
@@ -107,7 +101,7 @@ ProjectsView::ProjectsView( QObject* parent, QWidget* parentWidget ) : View( par
     setTitle( "menuProjects", tr( "&Projects" ) );
     setTitle( "menuEdit", tr( "&Edit" ) );
 
-    loadXmlFile( ":/resources/projectsview.xml" );
+    loadXmlUiFile( ":/resources/projectsview.xml" );
 
     m_list = new QTreeView( parentWidget );
     m_list->setRootIsDecorated( true );
@@ -134,9 +128,10 @@ ProjectsView::~ProjectsView()
 
 void ProjectsView::initialUpdate()
 {
-    m_model = new TableItemModel( this );
+    m_model = new RDB::TableItemModel( this );
     m_model->setRootTableModel( new ProjectsTableModel( m_model ), dataManager->projects()->index() );
-    m_model->addChildTableModel( new FoldersTableModel( m_model ), dataManager->folders()->parentIndex() );
+    m_model->addChildTableModel( new FoldersTableModel( m_model ),
+        dataManager->folders()->index(), dataManager->folders()->parentIndex() );
 
     TreeViewSettings settings;
     settings.openProjectsTree();
@@ -149,8 +144,6 @@ void ProjectsView::initialUpdate()
 
     TreeViewHelper::applyColumnWidths( m_list, settings.loadColumnWidths() );
 
-    connect( m_model->rootTableModel(), SIGNAL( tableChanged() ), this, SLOT( projectsTableChanged() ) );
-
     setCaption( connectionManager->connectionInfo()->serverName() );
 
     connect( m_list->selectionModel(), SIGNAL( selectionChanged( const QItemSelection&, const QItemSelection& ) ),
@@ -174,7 +167,7 @@ Access ProjectsView::checkDataAccess()
     m_anyProjectAdmin = m_systemAdmin;
 
     int userId = connectionManager->connectionInfo()->userId();
-    RDB::ForeignConstIterator<MemberRow> it( dataManager->members()->index(), userId );
+    RDB::ForeignConstIterator<MemberRow> it( dataManager->members()->index().first(), userId );
     while ( it.next() ) {
         const MemberRow* member = it.get();
         if ( member->access() == AdminAccess )
@@ -184,7 +177,7 @@ Access ProjectsView::checkDataAccess()
     return m_anyProjectAdmin ? AdminAccess : NormalAccess;
 }
 
-void ProjectsView::updateAccess( Access access )
+void ProjectsView::updateAccess( Access /*access*/ )
 {
     action( "addFolder" )->setVisible( m_pageActive && m_anyProjectAdmin );
     action( "editRename" )->setVisible( m_pageActive && ( m_systemAdmin || m_anyProjectAdmin ) );
@@ -238,8 +231,8 @@ void ProjectsView::updateActions()
     if ( m_pageActive ) {
         QModelIndex index = selectedIndex();
         if ( index.isValid() ) {
-            int level = m_model->data( index, TableItemModel::LevelRole ).toInt();
-            int rowId = m_model->data( index, TableItemModel::RowIdRole ).toInt();
+            int level = m_model->data( index, RDB::TableItemModel::LevelRole ).toInt();
+            int rowId = m_model->data( index, RDB::TableItemModel::RowIdRole ).toInt();
             if ( level == 0 ) {
                 m_selectedProjectId = rowId;
                 m_currentProjectId = rowId;
@@ -264,8 +257,8 @@ void ProjectsView::updateActions()
     action( "showMembers" )->setEnabled( m_currentProjectId != 0 );
     action( "openFolder" )->setEnabled( m_selectedFolderId != 0 );
     action( "addFolder" )->setEnabled( m_currentProjectId != 0 && m_currentProjectAdmin );
-    action( "editRename" )->setEnabled( m_selectedProjectId != 0 && m_systemAdmin || m_selectedFolderId != 0 && m_currentProjectAdmin );
-    action( "editDelete" )->setEnabled( m_selectedProjectId != 0 && m_systemAdmin || m_selectedFolderId != 0 && m_currentProjectAdmin );
+    action( "editRename" )->setEnabled( ( m_selectedProjectId != 0 && m_systemAdmin ) || ( m_selectedFolderId != 0 && m_currentProjectAdmin ) );
+    action( "editDelete" )->setEnabled( ( m_selectedProjectId != 0 && m_systemAdmin ) || ( m_selectedFolderId != 0 && m_currentProjectAdmin ) );
     action( "editWatches" )->setEnabled( m_selectedFolderId != 0 );
 }
 
@@ -393,26 +386,29 @@ void ProjectsView::updateEvent( UpdateEvent* e )
 
     if ( e->unit() == UpdateEvent::Users )
         updateSummary();
+
+    if ( e->unit() == UpdateEvent::Projects && !m_firstUpdateDone ) {
+        QTimer::singleShot( 0, this, SLOT( projectsPopulated() ) );
+        m_firstUpdateDone = true;
+    }
 }
 
 void ProjectsView::viewEvent( ViewEvent* e )
 {
     if ( e->action() == ViewEvent::UpdateWatches )
-        m_model->updateRows();
+        m_model->updateData();
     else
         View::viewEvent( e );
 }
 
-void ProjectsView::projectsTableChanged()
+void ProjectsView::projectsPopulated()
 {
-    if ( !m_firstUpdateDone ) {
-        TreeViewSettings settings;
-        settings.openProjectsTree();
+    TreeViewSettings settings;
+    settings.openProjectsTree();
 
-        TreeViewHelper::applyExpandedNodes( m_list, settings.loadExpandedNodes() );
+    TreeViewHelper::applyExpandedNodes( m_list, settings.loadExpandedNodes() );
 
-        m_firstUpdateDone = true;
-    }
+    mainWidget()->setFocus();
 }
 
 void ProjectsView::contextMenu( const QPoint& pos )
@@ -421,7 +417,7 @@ void ProjectsView::contextMenu( const QPoint& pos )
 
     QString menuName;
     if ( index.isValid() ) {
-        int level = m_model->data( index, TableItemModel::LevelRole ).toInt();
+        int level = m_model->data( index, RDB::TableItemModel::LevelRole ).toInt();
         if ( level == 0 )
             menuName = m_systemAdmin ? "contextProjectAdmin" : "contextProject";
         else
@@ -438,8 +434,8 @@ void ProjectsView::contextMenu( const QPoint& pos )
 void ProjectsView::activated( const QModelIndex& index )
 {
     if ( index.isValid() ) {
-        int level = m_model->data( index, TableItemModel::LevelRole ).toInt();
-        int rowId = m_model->data( index, TableItemModel::RowIdRole ).toInt();
+        int level = m_model->data( index, RDB::TableItemModel::LevelRole ).toInt();
+        int rowId = m_model->data( index, RDB::TableItemModel::RowIdRole ).toInt();
 
         if ( level == 1 )
             viewManager->openFolderView( rowId );
