@@ -13,16 +13,11 @@
 #define PROJECTSVIEW_H
 
 #include "view.h"
+#include "rdb/tableitemmodel.h"
 
 class QTreeView;
 class QModelIndex;
 
-namespace WebIssues
-{
-
-class TableItemModel;
-class RowIndex;
-
 /**
 * View for displaying the tree of projects and folders.
 */
@@ -81,7 +76,7 @@ private slots:
     void contextMenu( const QPoint& pos );
     void activated( const QModelIndex& index );
 
-    void projectsTableChanged();
+    void projectsPopulated();
 
 private:
     Access checkDataAccess();
@@ -94,7 +89,7 @@ private:
 
 private:
     QTreeView* m_list;
-    TableItemModel* m_model;
+    RDB::TableItemModel* m_model;
 
     bool m_firstUpdateDone;
 
@@ -112,6 +107,4 @@ private:
     bool m_pageActive;
 };
 
-}
-
 #endif
