@@ -16,11 +16,9 @@
 #include <QMenu>
 #include <QMessageBox>
 
-#include "models/tableitemmodel.h"
 #include "models/tablemodels.h"
 #include "models/treeviewsettings.h"
 #include "models/treeviewhelper.h"
-#include "data/rdb/tableiterators.h"
 #include "data/datamanager.h"
 #include "data/connectioninfo.h"
 #include "data/updatebatch.h"
@@ -29,10 +27,6 @@
 #include "connectionmanager.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::TypesView */
-
 TypesView::TypesView( QObject* parent, QWidget* parentWidget ) : View( parent )
 {
     m_systemAdmin = connectionManager->connectionInfo()->access() == AdminAccess;
@@ -72,7 +66,7 @@ TypesView::TypesView( QObject* parent, QWidget* parentWidget ) : View( parent )
     setTitle( "menuMain", tr( "Ty&pes" ) );
     setTitle( "menuEdit", tr( "&Edit" ) );
 
-    loadXmlFile( ":/resources/typesview.xml" );
+    loadXmlUiFile( ":/resources/typesview.xml" );
 
     m_list = new QTreeView( parentWidget );
     m_list->setRootIsDecorated( true );
@@ -102,9 +96,10 @@ TypesView::~TypesView()
 
 void TypesView::initialUpdate()
 {
-    m_model = new TableItemModel( this );
+    m_model = new RDB::TableItemModel( this );
     m_model->setRootTableModel( new TypesTableModel( m_model ), dataManager->types()->index() );
-    m_model->addChildTableModel( new AttributesTableModel( m_model ), dataManager->attributes()->parentIndex() );
+    m_model->addChildTableModel( new AttributesTableModel( m_model ),
+        dataManager->attributes()->index(), dataManager->attributes()->parentIndex() );
 
     TreeViewSettings settings;
     settings.openTypesTree();
@@ -135,8 +130,8 @@ void TypesView::updateActions()
 
     QModelIndex index = selectedIndex();
     if ( index.isValid() ) {
-        int level = m_model->data( index, TableItemModel::LevelRole ).toInt();
-        int rowId = m_model->data( index, TableItemModel::RowIdRole ).toInt();
+        int level = m_model->data( index, RDB::TableItemModel::LevelRole ).toInt();
+        int rowId = m_model->data( index, RDB::TableItemModel::RowIdRole ).toInt();
         if ( level == 0 ) {
             m_selectedTypeId = rowId;
             m_currentTypeId = rowId;
@@ -205,7 +200,7 @@ void TypesView::editModify()
 void TypesView::editDelete()
 {
     if ( m_selectedTypeId != 0 && m_systemAdmin ) {
-        RDB::TableConstIterator<FolderRow> it( dataManager->folders() );
+        RDB::IndexConstIterator<FolderRow> it( dataManager->folders()->index() );
         while ( it.next() ) {
             const FolderRow* folder = it.get();
             if ( folder->typeId() == m_selectedTypeId ) {
@@ -230,7 +225,7 @@ void TypesView::contextMenu( const QPoint& pos )
 
     QString menuName;
     if ( index.isValid() ) {
-        int level = m_model->data( index, TableItemModel::LevelRole ).toInt();
+        int level = m_model->data( index, RDB::TableItemModel::LevelRole ).toInt();
         if ( level == 0 )
             menuName = "contextType";
         else
@@ -247,8 +242,8 @@ void TypesView::contextMenu( const QPoint& pos )
 void TypesView::activated( const QModelIndex& index )
 {
     if ( index.isValid() && m_systemAdmin ) {
-        int level = m_model->data( index, TableItemModel::LevelRole ).toInt();
-        int rowId = m_model->data( index, TableItemModel::RowIdRole ).toInt();
+        int level = m_model->data( index, RDB::TableItemModel::LevelRole ).toInt();
+        int rowId = m_model->data( index, RDB::TableItemModel::RowIdRole ).toInt();
 
         if ( level == 1 ) {
             ModifyAttributeDialog dialog( rowId, mainWidget() );
