@@ -15,15 +15,10 @@
 #include <QModelIndex>
 
 #include "view.h"
+#include "rdb/tableitemmodel.h"
 
 class QTreeView;
 
-namespace WebIssues
-{
-
-class TableItemModel;
-class RowIndex;
-
 /**
 * View for displaying the tree of types and attributes.
 */
@@ -65,7 +60,7 @@ private slots:
 
 private:
     QTreeView* m_list;
-    TableItemModel* m_model;
+    RDB::TableItemModel* m_model;
 
     int m_selectedTypeId;
     int m_selectedAttributeId;
@@ -75,6 +70,4 @@ private:
     bool m_systemAdmin;
 };
 
-}
-
 #endif
