@@ -15,7 +15,6 @@
 #include <QAction>
 #include <QMenu>
 
-#include "models/tableitemmodel.h"
 #include "models/tablemodels.h"
 #include "models/treeviewsettings.h"
 #include "models/treeviewhelper.h"
@@ -27,10 +26,6 @@
 #include "connectionmanager.h"
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::UsersView */
-
 UsersView::UsersView( QObject* parent, QWidget* parentWidget ) : View( parent )
 {
     m_systemAdmin = connectionManager->connectionInfo()->access() == AdminAccess;
@@ -65,7 +60,7 @@ UsersView::UsersView( QObject* parent, QWidget* parentWidget ) : View( parent )
     setTitle( "menuMain", tr( "&Users" ) );
     setTitle( "menuEdit", tr( "&Edit" ) );
 
-    loadXmlFile( ":/resources/usersview.xml" );
+    loadXmlUiFile( ":/resources/usersview.xml" );
 
     m_list = new QTreeView( parentWidget );
     m_list->setSortingEnabled( true );
@@ -94,7 +89,7 @@ UsersView::~UsersView()
 
 void UsersView::initialUpdate()
 {
-    m_model = new TableItemModel( this );
+    m_model = new RDB::TableItemModel( this );
     m_model->setRootTableModel( new UsersTableModel( m_model ), dataManager->users()->index() );
 
     TreeViewSettings settings;
@@ -123,7 +118,7 @@ void UsersView::updateActions()
 
     QModelIndex index = selectedIndex();
     if ( index.isValid() )
-        m_selectedUserId = m_model->data( index, TableItemModel::RowIdRole ).toInt();
+        m_selectedUserId = m_model->data( index, RDB::TableItemModel::RowIdRole ).toInt();
 
     if ( m_systemAdmin ) {
         action( "editRename" )->setEnabled( m_selectedUserId != 0 );
@@ -192,7 +187,7 @@ void UsersView::contextMenu( const QPoint& pos )
 void UsersView::activated( const QModelIndex& index )
 {
     if ( index.isValid() && m_systemAdmin ) {
-        int userId = m_model->data( index, TableItemModel::RowIdRole ).toInt();
+        int userId = m_model->data( index, RDB::TableItemModel::RowIdRole ).toInt();
 
         if ( userId != 1 ) {
             ChangeUserAccessDialog dialog( userId, mainWidget() );
