@@ -13,16 +13,11 @@
 #define USERSVIEW_H
 
 #include "view.h"
+#include "rdb/tableitemmodel.h"
 
 class QTreeView;
 class QModelIndex;
 
-namespace WebIssues
-{
-
-class TableItemModel;
-class RowIndex;
-
 /**
 * View for displaying and managing users.
 */
@@ -64,13 +59,11 @@ private:
 
 private:
     QTreeView* m_list;
-    TableItemModel* m_model;
+    RDB::TableItemModel* m_model;
 
     int m_selectedUserId;
 
     bool m_systemAdmin;
 };
 
-}
-
 #endif
