@@ -17,10 +17,6 @@
 #include "xmlui/builder.h"
 #include "viewevent.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::View */
-
 View::View( QObject* parent ) : QObject( parent ),
     m_mainWidget( NULL ),
     m_id( 0 ),
@@ -87,15 +83,15 @@ void View::disableView()
 {
 }
 
-void View::updateAccess( Access access )
+void View::updateAccess( Access /*access*/ )
 {
 }
 
-void View::updateEvent( UpdateEvent* e )
+void View::updateEvent( UpdateEvent* /*e*/ )
 {
 }
 
-void View::viewEvent( ViewEvent* e )
+void View::viewEvent( ViewEvent* /*e*/ )
 {
 }
 
