@@ -19,9 +19,6 @@
 
 class KConfig;
 
-namespace WebIssues
-{
-
 class UpdateEvent;
 class UpdateBatch;
 class ViewEvent;
@@ -232,6 +229,9 @@ protected: // overrides
     void customEvent( QEvent* e );
 
 protected slots:
+    /**
+    * Set the caption of the view.
+    */
     void setCaption( const QString& text );
 
 private slots:
@@ -252,6 +252,4 @@ private:
     bool m_updating;
 };
 
-}
-
 #endif
