@@ -14,9 +14,6 @@
 
 #include <QEvent>
 
-namespace WebIssues
-{
-
 /**
 * Event for communication between views.
 *
@@ -108,6 +105,4 @@ private:
     int m_id;
 };
 
-}
-
 #endif
