@@ -15,9 +15,6 @@
 class QObject;
 class QWidget;
 
-namespace WebIssues
-{
-
 class View;
 
 /**
@@ -40,6 +37,4 @@ public:
     static View* createView( const char* className, QObject* parent, QWidget* parentWidget );
 };
 
-}
-
 #endif
