@@ -17,10 +17,6 @@
 #include <QPushButton>
 #include <QLayout>
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::EditListBox */
-
 EditListBox::EditListBox( QWidget* parent ) : QWidget( parent )
 {
     QHBoxLayout* mainLayout = new QHBoxLayout( this );
