@@ -20,9 +20,6 @@ class QModelIndex;
 class QLineEdit;
 class QPushButton;
 
-namespace WebIssues
-{
-
 /**
 * Widget for editing a list of strings.
 */
@@ -83,6 +80,4 @@ private:
     QPushButton* m_downButton;
 };
 
-}
-
 #endif
