@@ -14,30 +14,34 @@
 #include <QPainter>
 #include <QStyleOption>
 
-#include "dotnetstyle.h"
-
-using namespace WebIssues;
+#if defined( Q_WS_WIN )
+#include "windowsmodernstyle.h"
+#endif
 
 GradientWidget::GradientWidget( QWidget* parent ) : QWidget( parent )
 {
-#if defined( WI_NO_STYLE_DOTNET )
-    setPalette( QPalette( QColor( 255, 255, 255 ) ) );
-    setAutoFillBackground( true );
+#if defined( Q_WS_WIN ) && !defined( NO_STYLE_WINDOWSMODERN )
+    if ( !qobject_cast<WindowsModernStyle*>( style() ) ) {
+#else
+    if ( true ) {
 #endif
+        setPalette( QPalette( QColor( 255, 255, 255 ) ) );
+        setAutoFillBackground( true );
+    }
 }
 
 GradientWidget::~GradientWidget()
 {
 }
 
-void GradientWidget::paintEvent( QPaintEvent* e )
+void GradientWidget::paintEvent( QPaintEvent* /*e*/ )
 {
-#if !defined( WI_NO_STYLE_DOTNET )
-    QPainter painter( this );
-
-    QStyleOption option;
-    option.initFrom( this );
-
-    ( (DotNetStyle*)style() )->fillGradient( &option, &painter, this );
+#if defined( Q_WS_WIN ) && !defined( NO_STYLE_WINDOWSMODERN )
+    if ( qobject_cast<WindowsModernStyle*>( style() ) ) {
+        QPainter painter( this );
+        QStyleOption option;
+        option.initFrom( this );
+        style()->drawPrimitive( (QStyle::PrimitiveElement)WindowsModernStyle::PE_WindowGradient, &option, &painter, this );
+    }
 #endif
 }
