@@ -14,9 +14,6 @@
 
 #include <QWidget>
 
-namespace WebIssues
-{
-
 /**
 * Widget with styled gradient background.
 *
@@ -43,6 +40,4 @@ protected: // overrides
     void paintEvent( QPaintEvent* e );
 };
 
-}
-
 #endif
