@@ -15,10 +15,6 @@
 #include <QPushButton>
 #include <QLayout>
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::PopEditBox */
-
 PopEditBox::PopEditBox( QWidget* parent ) : QFrame( parent )
 {
     initialize();
