@@ -17,9 +17,6 @@
 class QLabel;
 class QPushButton;
 
-namespace WebIssues
-{
-
 class PopEditBrowser;
 
 /**
@@ -109,6 +106,4 @@ private:
     QString m_link;
 };
 
-}
-
 #endif
