@@ -18,9 +18,6 @@
 class QGridLayout;
 class QButtonGroup;
 
-namespace WebIssues
-{
-
 class PopEditBox;
 
 /**
@@ -106,6 +103,4 @@ private:
     QMap<int, PopEditBox*> m_editMap;
 };
 
-}
-
 #endif
