@@ -18,9 +18,6 @@
 class QGridLayout;
 class QLabel;
 
-namespace WebIssues
-{
-
 /**
 * A panel containing pairs of labels and values.
 *
@@ -88,6 +85,4 @@ private:
     QMap<QString, QLabel*> m_labelMap;
 };
 
-}
-
 #endif
