@@ -18,10 +18,6 @@
 
 #include "iconloader.h"
 
-using namespace WebIssues;
-
-/* TRANSLATOR WebIssues::SearchEditBox */
-
 SearchEditBox::SearchEditBox( QWidget* parent ) : QLineEdit( parent ),
     m_showPrompt( false )
 {
