@@ -16,9 +16,6 @@
 
 class QToolButton;
 
-namespace WebIssues
-{
-
 /**
 * An edit box with a clear button.
 *
@@ -72,6 +69,4 @@ private:
     QString m_promptText;
 };
 
-}
-
 #endif
