@@ -14,9 +14,6 @@
 
 #include <QComboBox>
 
-namespace WebIssues
-{
-
 /**
 * A combo box with separators between items.
 */
@@ -48,6 +45,4 @@ public: // overrides
     bool eventFilter( QObject* watched, QEvent* e );
 };
 
-}
-
 #endif
