@@ -16,9 +16,6 @@
 
 class QLabel;
 
-namespace WebIssues
-{
-
 /**
 * A status bar with status icon and label and an optional summary field.
 */
@@ -70,6 +67,4 @@ private:
     QLabel* m_summaryLabel;
 };
 
-}
-
 #endif
