@@ -1,12 +1,30 @@
-/**************************************************************************
-* Simple XML-based UI builder for Qt 4
-* Copyright (C) 2007 Michał Męciński
+/****************************************************************************
+* Simple XML-based UI builder for Qt4
+* Copyright (C) 2007-2008 Michał Męciński
 *
-* This program is free software; you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
-* (at your option) any later version.
-**************************************************************************/
+* Redistribution and use in source and binary forms, with or without
+* modification, are permitted provided that the following conditions are met:
+*   1. Redistributions of source code must retain the above copyright notice,
+*      this list of conditions and the following disclaimer.
+*   2. Redistributions in binary form must reproduce the above copyright
+*      notice, this list of conditions and the following disclaimer in the
+*      documentation and/or other materials provided with the distribution.
+*   3. Neither the name of the copyright holder nor the names of the
+*      contributors may be used to endorse or promote products derived from
+*      this software without specific prior written permission.
+*
+* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+* ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
+* LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+* POSSIBILITY OF SUCH DAMAGE.
+****************************************************************************/
 
 #include "builder.h"
 
@@ -18,7 +36,6 @@
 #include "node.h"
 #include "client.h"
 
-
 using namespace XmlUi;
 
 Builder::Builder( QMainWindow* window ) : QObject( window ),
@@ -28,28 +45,33 @@ Builder::Builder( QMainWindow* window ) : QObject( window ),
 
 Builder::~Builder()
 {
+    for ( int i = 0; i < m_clients.count(); i++ )
+        m_clients.at( i )->m_builder = NULL;
 }
 
 void Builder::addClient( Client* client )
 {
-    if ( !m_clients.contains( client ) ) {
-        m_clients.append( client );
+    if ( client->m_builder == this )
+        return;
 
-        client->setBuilder( this );
+    if ( client->m_builder )
+        client->m_builder->removeClient( client );
 
-        rebuildAll();
-    }
+    m_clients.append( client );
+    client->m_builder = this;
+
+    rebuildAll();
 }
 
 void Builder::removeClient( Client* client )
 {
-    if ( m_clients.contains( client ) ) {
-        m_clients.removeAt( m_clients.indexOf( client ) );
+    if ( client->m_builder != this )
+        return;
 
-        client->setBuilder( NULL );
+    m_clients.removeAt( m_clients.indexOf( client ) );
+    client->m_builder = NULL;
 
-        rebuildAll();
-    }
+    rebuildAll();
 }
 
 Node Builder::mergeNodes( const Node& node1, const Node& node2 )
@@ -63,24 +85,32 @@ Node Builder::mergeNodes( const Node& node1, const Node& node2 )
 
     int mergePos = -1;
 
-    // copy nodes from node1 and find the position of the empty <merge/> element
+    // copy nodes from node1 and find the position of the merge marker
     for ( int i = 0; i < node1.children().count(); i++ ) {
         Node child = node1.children().at( i );
 
-        if ( child.type() == Merge && child.id().isEmpty() )
+        if ( child.type() == Merge )
             mergePos = children.count();
         else
             children.append( child );
     }
 
-    // no <merge/> element, append node2 to the end
+    // no merge marker, append node2 at the end
     if ( mergePos < 0 )
         mergePos = children.count();
 
+    int newMergePos = -1;
+
     // process nodes from node2
     for ( int i = 0; i < node2.children().count(); i++ ) {
         Node child = node2.children().at( i );
 
+        // remember the position of the merge marker
+        if ( child.type() == Merge ) {
+            newMergePos = mergePos;
+            continue;
+        }
+
         bool merged = false;
 
         // find a matching node from node1
@@ -93,12 +123,22 @@ Node Builder::mergeNodes( const Node& node1, const Node& node2 )
             }
         }
 
-        // no matching node to merge with, insert into merge location
+        // no matching node to merge with, insert at merge location
         if ( !merged )
             children.insert( mergePos++, child );
     }
 
-    result.setChildren( children );
+    if ( !children.isEmpty() ) {
+        // no merge marker in node2, continue merging from current location
+        if ( newMergePos < 0 )
+            newMergePos = mergePos;
+
+        // insert new merge marker at appropriate position if needed
+        if ( newMergePos < children.count() )
+            children.insert( newMergePos, Node( Merge ) );
+
+        result.setChildren( children );
+    }
 
     return result;
 }
@@ -127,30 +167,17 @@ Node Builder::resolveGroups( const Node& node )
     for ( int i = 0; i < node.children().count(); i++ ) {
         Node child = node.children().at( i );
 
-        // do not copy groups
-        if ( child.type() == Group )
-            continue;
-
-        if ( child.type() == Merge ) {
-            // look for the matching group
-            for ( int j = 0; j < node.children().count(); j++ ) {
-                Node group = node.children().at( j );
-                if ( group.type() == Group && group.id() == child.id() ) {
-                    // process the group recursively and insert all its children
-                    group = resolveGroups( group );
-                    for ( int k = 0; k < group.children().count(); k++ )
-                        result.addChild( group.children().at( k ) );
-                    break;
-                }
-            }
-            continue;
-        }
-
         // process the element's groups recursively
         if ( child.children().count() > 0 )
             child = resolveGroups( child );
 
-        result.addChild( child );
+        if ( child.type() == Group ) {
+            // replace the group whith its children
+            for ( int k = 0; k < child.children().count(); k++ )
+                result.addChild( child.children().at( k ) );
+        } else {
+            result.addChild( child );
+        }
     }
 
     return result;
@@ -163,10 +190,10 @@ void Builder::rebuildAll()
 
     m_mainWindow->setUpdatesEnabled( false );
 
-    Node node = m_clients.at( 0 )->rootNode();
+    Node node = m_clients.at( 0 )->m_rootNode;
 
     for ( int i = 1; i < m_clients.count(); i++ )
-        node = mergeNodes( node, m_clients.at( i )->rootNode() );
+        node = mergeNodes( node, m_clients.at( i )->m_rootNode );
 
     m_rootNode = resolveGroups( node );
 
@@ -232,14 +259,13 @@ QToolBar* Builder::createToolBar( const Node& node )
         if ( child.type() == Action )
             action = findAction( child.id() );
 
-        if ( !action )
+        if ( !action || !action->isVisible() )
             continue;
 
         if ( !toolBar ) {
-            QString title = findTitle( node.id() );
             for ( int i = 0; i < m_oldToolBars.count(); i++ ) {
-                if ( m_oldToolBars[ i ]->windowTitle() == title ) {
-                    toolBar = m_oldToolBars[ i ];
+                if ( m_oldToolBars.at( i )->objectName() == node.id() ) {
+                    toolBar = m_oldToolBars.at( i );
                     m_oldToolBars.removeAt( i );
                     toolBar->setVisible( false );
                     toolBar->clear();
@@ -247,7 +273,9 @@ QToolBar* Builder::createToolBar( const Node& node )
                 }
             }
             if ( !toolBar ) {
-                toolBar = new QToolBar( title, m_mainWindow );
+                toolBar = new QToolBar( m_mainWindow );
+                toolBar->setObjectName( node.id() );
+                toolBar->setWindowTitle( findTitle( node.id() ) );
                 isNew = true;
             }
             m_toolBars.append( toolBar );
@@ -261,10 +289,12 @@ QToolBar* Builder::createToolBar( const Node& node )
         toolBar->addAction( action );
     }
 
-    if ( isNew )
+    if ( isNew ) {
+        emit toolBarCreated( toolBar );
         m_mainWindow->addToolBar( toolBar );
-    else if ( toolBar )
+    } else if ( toolBar ) {
         toolBar->setVisible( true );
+    }
 
     return toolBar;
 }
@@ -293,7 +323,7 @@ QMenu* Builder::createMenu( const Node& node )
                 action = subMenu->menuAction();
         }
 
-        if ( !action )
+        if ( !action || !action->isVisible() )
             continue;
 
         if ( !menu ) {
@@ -336,7 +366,7 @@ QAction* Builder::findAction( const QString& id )
 {
     for ( int i = m_clients.count() - 1; i >= 0; i-- ) {
         QAction* action = m_clients.at( i )->action( id );
-        if ( action && action->isVisible() )
+        if ( action )
             return action;
     }
 
